/*************************************************************************
 ANALYSIS FOR LOTTERY PROJECT: 8TH GRADERS ENROLLED IN CPS AT TIME OF APPL
 *************************************************************************/

capture log close
drop _all
program drop _all
macro drop _all
set more off
set mem 250m
set matsize 800
#delimit;

** set up global indicating which machine running program on;

global n=0;


*********************************************************;
********** PROGRAMS USED THROUGHOUT THE DO FILE **********;
*********************************************************;

/*** Calculating p-values for differences between winners/losers ***/

 ** from Fisher exact test for binary variables;
  * note: we cannot use the large sample formula (requires 5 observations in 
   each of the 4 cells in the 2x2 table that has 0,1 for select on one side 
   and 0,1 for the binary background variable in question on the other);
  
  program define getp_f;
   qui egen tmp1=sd(`1'), by(sublotto);
   qui gen p_`1'=.;
   qui egen tmp2=max(tmp1>0 & tmp1~=. & sampleL==1);
   if tmp2==1{;
   qui vallist sublotto if tmp1>0 & tmp1~=. & sampleL==1, global(list);
   for any $list, noheader: 
    qui tab `1' select if sublotto=="X" & `1'~=., exact \
    qui replace p_`1'=r(p_exact) if sublotto=="X";
   };
   drop tmp*;
  end; 
 
 ** from Probit for binary variables (based on z-statistic);
  
  * note: significance of Probit coefficient is the same as the significance
    of the marginal effect (same z-statistic) in our case;
  program define getp_p;
   qui egen tmp1=sd(`1'), by(sublotto);
   qui gen p_`1'=.;
   qui egen tmp2=max(tmp1>0 & tmp1~=. & sampleL==1);
   if tmp2==1{;
   qui vallist sublotto if tmp1>0 & tmp1~=. & sampleL==1, global(list);
   for any $list, noheader: 
    qui probit `1' select if sublotto=="X" & `1'~=., asis \
    matrix V=e(V) \ matrix V=V[1,1]^.5 \
    matrix B=e(b) \ matrix B=B[1,1]/V[1,1] \ 
    qui replace p_`1'=2*(1-norm(B[1,1])) if sublotto=="X" \
    qui replace p_`1'=2*norm(B[1,1]) if p_`1'>1 & sublotto=="X" \ 
    matrix drop _all;
   };
   drop tmp*;
  end;

 ** from linear regression for other variables;
  * note: this is equivalent to using an unpaired t-test that assumes
  the dependent variable in the two groups has the same variance (the
  pooled standard error estimate is the same as the OLS estimate);
  * if there is no variation within winners and none within losers, 
  the p-value will be missing; 

  program define getp;
   qui egen tmp1=sd(`1'), by(sublotto);
   qui gen p_`1'=.;
   qui egen tmp2=max(tmp1>0 & tmp1~=. & sampleL==1);
   if tmp2==1{;
   qui vallist sublotto if tmp1>0 & tmp1~=. & sampleL==1, global(list);
   for any $list, noheader: capture reg `1' select if sublotto=="X" \ 
    qui egen tmpnum=sum(e(sample)) if sublotto=="X" \
    qui replace p_`1'=e(F)^.5 if sublotto=="X" & tmpnum>0 & tmpnum~=. \
    qui replace p_`1'=ttail(tmpnum-2,p_`1')*2 if sublotto=="X" \ 
    drop tmpnum;
   };
   drop tmp*;
  end;

/*** Displaying marginal effects after dprobit estimation ***/

** Note: this is for models WITHOUT interactions;
* first global is the name of the control variable;

program define prme;
  qui summ `1' if e(sample) & select==0;
  local ybar=r(mean);
  local ysd=r(sd);
  matrix M=e(dfdx);
  matrix M=M["r1","`1'"];
  matrix S=e(se_dfdx);
  matrix S=S["r1","`1'"];
  local me=M[1,1];
  local se=S[1,1];
  if `me'>0{;
  local p=(1-norm(`me'/`se'))*2;
  };
  if `me'<0{;
  local p=norm(`me'/`se')*2;
  };
  qui gen tmplen=12-length("`1'");
  qui gen str9 tmpsp="";
  for num 1/9, noheader: qui replace tmpsp=tmpsp+" " if tmplen>=X;
  disp " cntrl: `1'" tmpsp " m.e.: " %5.3f `me' "  s.e.: " %5.3f `se'
   "   p-value: " %5.3f `p' "   N: " e(N);
  disp "  cntrl mean for loser's in reg smpl: " %5.3f `ybar'
   "  sd: " %5.3f `ysd';
  drop tmplen tmpsp;
  end;

/*** Displaying average marginal effect after probit estimation ***/

 ** designed to calculate this only for the variable "select"-- make 
  sure this is the first control variable listed!!;

 * first global is the name of the dependent variable;
 
 program define prmeavg;
  global y `1';

  ** mean of dependent variable among lottery losers in est sample;
  qui summ ${y} if e(sample) & select==0;
  local ybar=r(mean);
  local ysd=r(sd);

  ** create temporary variables;
  tempvar xb xb1 xb0 db1 dbcons me_select se_select;
  tempname V Vs matd VAR var;

  ** calculating marginal effect;
  qui predict `xb', xb;
  qui gen `xb1'=`xb'-_b[select]*select+_b[select];
  qui gen `xb0'=`xb'-_b[select]*select; 
  qui gen `me_select'=norm(`xb1')-norm(`xb0');

  ** standard error;
  qui gen `se_select'=.;

   * we use the delta method-- which is d * V * d', where d
    is the vector of derivatives dme/db, and V is the variance-
    covariance matrix for the coefficient estimates.  To find
    the standard error for the mean marginal effect, we 
    replace d with the average gradiant (d) across observations;

   * first find the derivative for "select" and the constant;
   qui gen `db1'=normd(`xb1');
   qui gen `dbcons'=normd(`xb1')-normd(`xb0');

   * next find derivatives for the other independent variables;
   mat `V'=e(V);
   local ntot=rowsof(`V')-1;
   if `ntot'>1{;
    mat `Vs'=`V'[2..`ntot',1];
    local vlist : rownames(`Vs');
    tokenize `vlist';
    local nd=1;
    while "`1'"~="" {;
     tempvar DB`nd';
     qui gen `DB`nd''=(normd(`xb1')-normd(`xb0'))*`1';
     local nd=`nd'+1;
     macro shift;
    };
    local nd=`nd'-1; 
   };
   
   * finding the standard error of the mean marginal effect;
   preserve;
   collapse (mean) `me_select' `db1' `DB1'-`DB`nd'' `dbcons' if e(sample);
   mkmat `db1' `DB1'-`DB`nd'' `dbcons', matrix(`matd');
   matrix `VAR'=`matd'*`V'*`matd'';
   scalar `var'=`VAR'[1,1];
   qui gen `se_select'=sqrt(`var');
   if `me_select'>0{;
    local p=(1-norm(`me_select'/`se_select'))*2;
   };
   if `me_select'<0{;
    local p=norm(`me_select'/`se_select')*2;
   };

  ** displaying results;
  disp " Avg ME for select: " %5.3f `me_select' "   se: " %5.3f `se_select'
   "   p-value: " %5.3f `p'; 
  disp "  dep var mean: " %5.3f `ybar' "   st dev: " %5.3f `ysd';

  qui restore;

 end;



*************************************************************;
************************** PART 1 ***************************;
********** CREATE H.S. SAMPLE AND NEEDED VARIABLES **********;
*************************************************************;

log using part1.log, replace;

******************************************;  
*** Create Base Sample of Applications ***;
******************************************;

if ${n}==0{; !gzip -d magbasevalid.dta; };
use magbasevalid;
if ${n}==0{; !gzip magbasevalid.dta; };

tab year;

** keep students enrolled in CPS at time of application;
 tab igradeS0 year, col;
 tabstat enrollS0 if igradeS0==8, by(year);
 keep if enrollS0==1;
 drop enrollS0;

** keep 8th graders;
 tab igradeS0 if gradeS0==8, miss;
 keep if gradeS0==8;
 drop gradeS0 ngradeS0;

** drop if imputed to be in grade earlier than 8th;
 tab year;
 tab igradeS0, miss;
 tab gr if sublotto~="" & igradeS0<8;
 drop if igradeS0<8;
 drop igradeS0;

** what grades are reported on applications?;
 tab gr, miss;
 tab dc if gr~="08"&gr~="09", miss;
 for any 01 02 04 05 06 07 08 09 KG: count if sublotto~="" & gr=="X"; 
 tab gradeF1 if gr=="09";
 * drop if reported grade isn't either 8th or 9th;
 drop if gr~="08"&gr~="09";
 tab ngradeap;
 drop ngradeap;

** exclude if applying to a school with 8th as the highest grade;
 egen tmp=count(cunit), by(cunit year);
 sort cunit year;
 list cunit cuname year tmp yysped if cunit>2000 & (cunit~=cunit[_n-1]|
  year~=year[_n-1]);
 * note: of these, only 4130, 6630, and 8070 go beyond 8th;
 drop if cunit>2000 & (cunit~=4130&cunit~=6630&cunit~=8070);

** exclude if fewer than 10 students applying to the same school;
 sort cunit year;
 summ tmp if cunit~=cunit[_n-1]|year~=year[_n-1], detail;
 summ tmp if tmp<30, detail;
 list cunit cuname year tmp if (cunit~=cunit[_n-1]|year~=year[_n-1])
  & tmp<10;
 drop if tmp<10;
 tab year;

** which schools are represented in the applications dataset?;
 sort cunit year;
 count if cunit~=cunit[_n-1];
 count if cunit~=cunit[_n-1]|year~=year[_n-1];
 list cunit cuname year tmp if cunit~=cunit[_n-1]|year~=year[_n-1];
 drop tmp;


***************************************************;  
*** Clean/Drop/Create Non-Achievement Variables ***;
***************************************************;

/** Application/lottery variables **/

 tab year, miss;
 count if newid=="";
 egen tmp=nvals(sid), by(newid);
 tab tmp, miss;
 drop tmp; 
 tab bad*, miss cell;
 summ napp*;
 count if napptot<napp;
 count if sx==""|rc==.|gr=="";
 drop individ pc lotto p comments sb;

 tab dc, miss;  
 summ insch if dc=="";
 summ insch if dc~="";
 * note: 20 waitlisted cases look more like rejects than accepts;
 summ insch if dc=="S" & sublotto~="";
 summ insch if dc=="R" & sublotto~="";
 summ insch if dc=="W" & sublotto~="";
 egen tmp=max(dc=="W") if sublotto=="", by(cunit);
 summ insch if (dc=="S"|dc=="A"|dc=="A^"|dc=="P") & tmp==1;
 summ insch if (dc=="R"|dc=="R^") & tmp==1;
 summ insch if dc=="W" & tmp==1;
 drop tmp;

 * note: treating our imputed accepts "A^" and rejects "R^" as valid data;
 * does not affect any of the students involved in lotteries-- useful only
   for describing the full set of applications;
  gen byte goodcode=dc=="R"|dc=="S"|dc=="W"|dc=="A"|dc=="P"|dc=="1"|dc=="3"|
   dc=="6"|dc=="A^"|dc=="R^";
   label var goodcode "valid disposition code";
  tab dc if goodcode~=1, miss;

 * replace invalid codes to missing;
  replace dc="" if dc~="" & goodcode==0;
  tab dc, miss;
  summ goodcode;

 * drop school classification variables for elementary schools;
  summ cu_* f_*;
  drop cu_clas cu_mag* cu_el* cu_acad cu_rgif cu_ibprep f_el*;

 * note: selective schools also use some of the lottery result codes; 
 * this means we cannot use dc codes as an indicator for being in a lottery;
  tab dc if cu_hstst==1;
  gen tmp=(sublotto=="");
  summ tmp if cu_hstst==1;
  summ tmp if cu_hsvoc==1;
 * share of missing lottery fields explained by school types;
  summ cu_* if tmp==1;
 * share of missing dc codes explained by school types;
  summ cu_* if goodcode==0;
  drop tmp;

 * application outcomes;
  gen byte select=(dc=="S" & sublotto~="");
  * treating waitlisted as rejects;
  gen byte reject=((dc=="R"|dc=="W") & sublotto~="");
  gen byte accept=(dc=="S"|dc=="A"|dc=="P"|dc=="A^");
  gen byte lottery=(sublotto~="");
  summ select reject accept lottery;
   label var select "selected in a lottery";
   label var reject "rejected in a lottery";
   label var accept "accepted by any means";
   label var lottery "in a lottery";

 * Indicator of outcome variation within lottery;
  egen tmp=sd(select) if lottery==1, by(sublotto);
  gen outvar=(tmp~=0 & tmp~=.) if lottery==1;
   label var outvar "lottery has winners and losers";
  summ outvar;
  drop tmp;

/** Demographic variables **/

 summ yy* xx*;
 gen tmp=xxwhi+xxblk+xxnatam+xxasian+xxhisp;
 tab tmp;
 drop tmp;

 * fix age entry that is clearly wrong-- set to mean for participants
   within that same lottery;
 summ xxage, detail;
 gen tmp1=(xxage==4);
 egen tmp2=max(tmp1), by(newid);
 list xxage if tmp2==1;
 egen tmp3=mean(xxage) if xxage~=4, by(sublotto);
 egen tmp4=max(tmp3), by(sublotto);
 replace tmp4=round(tmp4,.1);
 list newid sublotto xxage tmp4 if tmp2==1;
 replace xxage=tmp4 if tmp2==1;
 drop tmp*;

 tab xxmale, miss;
 gen byte xxfemale=xxmale==0;
  label var xxfemale "female";

 * Dropping closely correlated neighborhood variables;
 summ tractS0;
 summ latS0 longS0 pri_* nn*;
 descr nn*;
 summ nnpr*;
 corr nnpr*;
 drop nnprk8S0 nnprk12S0;
 corr nnpovS0 nnaidS0 nnmedyS0 nnfhdS0 nnunemS0 nnnilfS0;
 drop nnaidS0 nnmedyS0 nnfhdS0 nnunemS0;
 summ nnsmclS0 nnhsgdS0;
 corr nnsmclS0 nnhsgdS0;
 drop nnsmclS0;
 corr nnpovS0 nnownhS0 nnvacS0;
 drop nnvacS0;
 drop nnpopS0 nnpwhiS0;
 summ nn*;
 corr nn*;

 * create variable for moved between 8th and 9th;
 summ enrollF1 if tractF1~=.;
 gen moveF1=(tractF1~=tractS0) if tractF1~=. & tractS0~=.;
 summ moveF1;
  label var moveF1 "moved tracts between Spr 8th and Fall 9th";
 
/** Fix mis-classified grade levels **/

 summ gradeF1 ngradeF1;
 count if ngradeF1~=gradeF1;
 drop ngradeF1;

 * none should be below 8th in Fall Yr 1;

 summ gradeS* unitS*;
 for num 1/4: count if enrollSX==1 \ replace gradeSX=. if enrollSX==0 \
  replace unitSX=. if enrollSX==0;

 tab gradeF1 gradeS1, miss;
 tab uF1name if gradeF1==1;
  tab gradeF1 year if uF1name=="YNG WOMN LDRSHP CHRT";
  replace gradeF1=9 if gradeF1==1;
 list uF1name uF1type if gradeF1==0;
  replace gradeF1=8 if gradeF1==0;
 list uF1name uF1type if gradeF1==7;
 tab gradeF1 if uF1name=="EMMET";
 replace gradeF1=8 if gradeF1==7;

 * should never move back a grade relative to prior year;
 tab gradeF1 gradeS1, miss;
 tab uF1type if gradeF1==9 & gradeS1==8;
 replace gradeF1=8 if gradeS1==8 & gradeF1~=.;
 replace gradeF1=9 if gradeF1==10 & gradeS1==9;
 tab gradeF1 gradeS1, miss;

 tab gradeS1 gradeS2, miss;
 replace gradeS2=gradeS1 if gradeS2<gradeS1 & gradeS1~=.;
 
 tab gradeS2 gradeS3, miss;
 replace gradeS3=gradeS2 if gradeS3<gradeS2 & gradeS2~=.;

 tab year if gradeS4~=.;
 tab gradeS3 gradeS4 if year==2000, miss;
 replace gradeS4=gradeS3 if gradeS4<gradeS3 & gradeS3~=.;

 tab year if gradeF5~=.;
 tab gradeS4 gradeF5 if year==2000, miss;
 replace gradeF5=gradeS4 if gradeF5<gradeS4 & gradeS4~=.;

/** Attended AA school **/

 * note: this variable does not look very reliable;
 * it may be that this reflects the student's inside option in the 
   Spring--which includes the lottery school if student previously
   won lottery and attended;
 * in part for this reason, we will use characterization of the 
   "inside option" based on attendance patterns among losing lottery
   participants, as well as the AA school;
 summ aaS1 aunitS1;
 count if aunitS1==.;
 count if aunitS1==. & enrollF1==1;
 gen tmp1=(aunitS1==unitF1) if enrollF1==1;
 tabstat tmp1, by(dinsch);
 * can we use tract information to infer assigned school?;
 gen tmp2=(enrollS1==1 & enrollF1==1 & dinsch==0 & unitF1==unitS1);
 egen tmp3=sum(tmp2), by(tractF1);
 egen tmp4=sum(tmp2), by(tractF1 aunitS1);
 replace tmp4=tmp4/tmp3;
 summ tmp4, detail;
 gen aaF1=(aunitS1==unitF1) if aunitS1~=. & enrollF1==1;
 replace aaF1=0 if aaF1~=. & dinsch==1;
 replace aaF1=0 if aaF1==. & dinsch==1;
  label var aaF1 "attended AA school";
 drop tmp* aaS1 aaS2 aS1name aS1type aS1mnotaa aS1tract aS1miles*;

/** School-level variables **/

  summ unitS0 uS0*;
  gen uS0pmin=uS0pblk+uS0phisp;
   label var uS0pmin "% black + hispanic";

  summ cu*;
  gen tmp=cu_hsvoc+cu_hstst+cu_hsmag+cu_hsoth;  
  tab tmp, miss;
  drop tmp;
  gen cupmin=cupblk+cuphisp;
   label var cupmin "% black or hispanic";

  summ unitF1 f_hs* uF1*;
  gen tmp=f_hsvoc+f_hstst+f_hsmag+f_hschrt+f_hsoth;
  tab tmp;
  drop tmp;
  gen uF1pmin=uF1pblk+uF1phisp;
   label var uF1pmin "% black or hispanic";
  gen uF1lmedy=ln(uF1medy);
   label var uF1lmedy "ln median HH income in tract";
  summ uF1size, detail;
  gen byte uF1small=(uF1size<600) if uF1size!=.;
   label var uF1small "fewer than 600 students in sch";


*******************************************;
*** Clean Achievement/Outcome Variables ***;
*******************************************;

** unneeded scores;

 summ rdgeS0 mtxilS1 mtxilS2;
 drop rdgeS0 mtxilS1 mtxilS2;

** baseline ITBS test scores;

 for var rdxilS0 mtxilS0 mtxil_1 rdxil_1, noheader: qui gen zzX=X;

 * Create imputed 8th grade composite score for all students;
 for any zzrdxilS0 zzmtxilS0: impute X xx* yy* nn* zzmtxilS0 zzrdxilS0 
  mtxil_1 rdxil_1, generate(iX);
 count if zzrdxilS0==.;
 count if zzrdxilS0~=izzrdxilS0;
 corr izzrdxilS0 rdxil_1 if zzrdxilS0==.;
 corr izzmtxilS0 mtxil_1 if zzmtxilS0==.;
 egen iscore=rmean(izzrdxilS0 izzmtxilS0);
  label var izzrdxilS0 "reading score w/missings imputed";
  label var izzmtxilS0 "math score w/missings imputed";
  label var iscore "avg. of reading and math w/missings imputed";

 * Create indicators for missing prior scores;
 for any rdxilS0 mtxilS0 rdxil_1 mtxil_1, noheader: 
  qui gen byte zzmsX=zzX==. \ qui replace zzX=0 if zzX==.;
  label var zzmsrdxilS0 "reading score missing";
  label var zzmsmtxilS0 "math score missing";
  label var zzmsrdxil_1 "lagged reading score missing";
  label var zzmsmtxil_1 "lagged math score missing";
  label var zzrdxilS0 "reading score, missing set to 0";
  label var zzmtxilS0 "math score, missing set to 0";
  label var zzrdxil_1 "lagged reading score, missing=0";
  label var zzmtxil_1 "lagged math score, missing=0";
 summ zz*;

** high school TAPS scores;

 * replace percentile test-scores to missing if student is off-grade--
   appears that percentiles are based on status w/in existing grade, 
   so that this variable is not comparable across grades;
 tab gradeS1 if rdxilS1~=., miss;
 tab gradeS1 if rdgeS1~=., miss;
 reg rdxilS1 rdgeS1 gradeS1;
 tabstat rdgeS1, by(gradeS1);
 replace rdxilS1=. if gradeS1~=9;
 count if rdxilS1~=. & rdgeS1==.;
 gen tmp=(rdxilS1==. & rdgeS1~=.) if enrollS1==1;
 summ tmp;
 drop tmp;

 tab year if rdxilS2~=.;
 tab gradeS2 if rdxilS2~=., miss;
 tab gradeS2 if rdgeS2~=., miss;
 reg rdxilS2 rdgeS2 gradeS2;
 tabstat rdgeS2, by(gradeS2);
 replace rdxilS2=. if gradeS2~=10;
 count if rdxilS2~=. & rdgeS2==.;
 gen tmp=(rdxilS2==. & rdgeS2~=.) if enrollS2==1 & year==2000;
 summ tmp;
 drop tmp;

 for any 1 2, noheader:  
  qui gen byte rdq1SX=rdxilSX<.25 if rdxilSX!=. \ 
  qui gen byte rdq4SX=rdxilSX>=.75 if rdxilSX!=.;
  label var rdq1S1 "pctile reading score below .25";
  label var rdq4S1 "pctile reading score above .75";
  label var rdq1S2 "pctile reading score below .25";
  label var rdq4S2 "pctile reading score above .75";

 gen byte msrdxilS1=rdxilS1==.;
 gen byte msrdxilS2=rdxilS2==. if year==2000;
  label var msrdxilS1 "reading score missing";
  label var msrdxilS2 "reading score missing (2000 cohort)";

** Case Exams;

 * note: teachers scored the constructed response (CR) items for their own 
   students, while multiple choice (MC) were scanned by CPS. If only one 
   component (MC or CR) is available, the total is missing.  We keep
   only the MC scores;
  summ alg* eng1* wld* bio* his* geo* eng2*;
  for any alg eng1 wld bio his geo eng2: corr Xmp Xcp \ 
   gen tmp=(Xmp==.&Xcp~=.) \ summ tmp \ drop Xcp Xtp tmp;

 * in Year 1, most 9th graders took Algebra, Eng I, World Studies, and biology;
 * in Year 2, most 10th graders took history, geometry, and Eng II;
  for var algmpS1 eng1mpS1 wldmpS1 biompS1, noheader: qui gen byte msX=X==.;
  for var hismpS2 geompS2 eng2mpS2, noheader: 
   qui gen byte msX=X==. if year==2000;
  for any alg eng1 wld bio his geo eng2 \ any 1 1 1 1 2 2 2, noheader: 
   summ enrollSY if XmpSY~=. \ rename XmpSY XSY \ rename msXmpSY msXSY;
  summ msalg mseng1 mswld msbio mshis msgeo mseng2;
   label var msalgS1 "missing algebra score";
   label var mseng1S1 "missing English I score";
   label var mswldS1 "missing World Studies score";
   label var msbioS1 "missing biology score";
   label var mshisS2 "missing history score (2000 cohort)";
   label var msgeoS2 "missing geometry score (2000 cohort)";
   label var mseng2S2 "missing English II score (2000 cohort)";

 * use system-wide distribution to determine top and bottom quartile;
 * these #'s are calculated from case exam files;
  gen byte algS1bot=algS1<=.25 if algS1!=.;
  gen byte algS1top=algS1>=.54 if algS1!=.;
  summ algS1bot algS1top;
   label var algS1bot "algebra score in bottom 25%";
   label var algS1top "algebra score in top 25%";
 
** transcript outcome measures;

 summ drop* left* priv* die* preg* jail* gradF5;

 for num 1/2: 
  summ anyfSX gpaSX mabsSX tcrdSX anyfSX numfSX crankSX if enrollSX==0 \
  summ anyfSX gpaSX mabsSX tcrdSX anyfSX numfSX crankSX if enrollSX==1 \
  gen byte crd28SX=tcrdSX>=28 if tcrdSX!=.;
   label var crd28S1 "took at least 28 credits";
   label var crd28S2 "took at least 28 credits";
 gen byte mstranS1=(mabsS1==.|tcrdS1==.);
 gen byte mstranS2=(mabsS2==.|tcrdS2==.);
 summ mstran*;
  label var mstranS1 "absences or credits missing";
  label var mstranS2 "absences or credits missing";

 * create indicator missing any of key outcome variables;
 egen byte missoutS1=rmax(msrdxilS1 mstranS1 msalgS1 mseng1S1);
 egen byte missoutS2=rmax(msrdxilS2 mstranS2 mseng2S2 msgeoS2) if year==2000;
  label var missoutS1 "missing test score or transcript info";
  label var missoutS2 "missing test score or transcript info (2000 cohort)";

** retention rate;

 * How many kids were retained in 8th grade?;
 * some kids are labeled as 9th graders even though they were technically 
   retained. All of these kids were in transition centers (academic prep 
   centers) for kids too old to stay in elementary schools;
 tab gradeF1 if enrollF1==1, miss;
 * keep these children in the analysis because have valid h.s. outcomes;
 gen tmp=gradeF1>=9 & uF1type=="Academic Prep Center" if enrollF1==1;
 summ tmp;
 tab gradeS1 if tmp==1;
 tab gradeS2 if tmp==1;
 tabstat mstranS1, stats(mean n) by(tmp); 
 tabstat mstranS1 if enrollS1==1, stats(mean n) by(tmp); 
 drop tmp;

 tab gradeF1 gradeS1, miss;
 tab uF1type if gradeF1==8 & gradeS1==9;
 tab gradeS2 if gradeF1==8 & gradeS1==9, miss;
 * count as enrolled in 9th grade with class if in 9th grade by Spring when
   tests are taken;
 gen enrollF19=enrollF1==1&(gradeF1>=9|(gradeS1>=9&gradeS1~=.));
 gen retainF1=enrollF1==1&enrollF19==0;
  label var enrollF19 "enrolled in CPS in 9th grade (on-track)";
  label var retainF1 "retained in 8th grade";
 summ enrollF19 if enrollF1==1;
  
 * Also define retained for following years;
 tab gradeS2 if enrollF19==1, miss;
 tab gradeS2 if enrollF19==0, miss;
 gen retainS2=(gradeS2<10) if enrollS2==1;
  label var retainS2 "enrolled in Yr 2, but in grade below 10th";

 tab gradeS3 if retainS2==0, miss;
 tab gradeS3 if retainS2==1, miss;
 gen retainS3=(gradeS3<11) if enrollS3==1;
   label var retainS3 "enrolled in Yr 3, but in grade below 11th";

 tab year if gradeS4~=.;
 tab gradeS4 if retainS3==0, miss;
 tab gradeS4 if retainS3==1, miss;
 gen retainS4=(gradeS4~=12) if enrollS4==1 & year==2000;
  label var retainS4 "enrolled in Yr 4, but below 12th (2000 cohort)";

 * for Fall Yr 5 should have graduated, so determine whether in grade
  below 12th if still enrolled;
 tab year if gradeF5~=.;
 tab gradeF5 if retainS4==0, miss;
 tab gradeF5 if retainS4==1, miss;
 gen retainF5=(gradeF5~=12) if enrollF5==1 & year==2000;
  label var retainF5 "enrolled in Yr 5 below 12th (2000 cohort)";


*******************************************************;
*** Merge in 9th Grade Survey Items for 2000 Cohort ***;
*******************************************************;

*** Merge in Item-Level Survey Measures for each Student ***;

 if ${n}==0{; global src="SURVEY\"; !gzip -d ${src}\survey2001_hs.dta.gz; };
 if ${n}==1{; global src="c:\projects\magnet schools\surveys\"; }; 
 mmerge sid using "${src}survey2001_hs", type(n:1) unmatched(master) 
  missing(nomatch) ukeep(sid tch01* tch02q01 sch03* sch04q08 sch04q09
  sch05q01 sch06* fut07q01 fut08q01 eng41q04 eng41q05 saf07* saf08q01 
  saf09* saf10* jus17* tec27q01 tec27q02 tec29q01 tec30q04 tec30q05
  par12q* par11q*);
 if ${n}==0{; !gzip ${src}\survey2001_hs.dta; };
 tab _merge year;
 gen byte survey=(_merge==3) if year==2000;
 summ survey;
 tab enrollS1 if survey==1, miss;
 tab gradeS1 if survey==1, miss;
 replace survey=0 if survey==1 & gradeS1~=9;
  label var survey "in 9th grade Spring survey (2000 cohort)";

** rename survey items and replace to 0 if not 9th grader;
 for var tch01* tch02* sch03* sch04* sch05* sch06* fut* eng41* saf* jus17* 
  tec* par*, noheader: rename X ss_X \ qui replace ss_X=. if survey==0;
 qui compress;

** check response rates; 
 * systemwide response rates for 9th and 10th grades were about 50%;
 sum survey if enrollF1==1;
 sum survey if enrollF19==1;

** recode individual survey items (in most cases, create binary vars);

* for these variables, the fields range from 1-4:
  1=strongly disagree 2=disagree 3=agree 4=strongly agree 
   (tch01* sch03* sch04* tec30*)
  1=not safe 2=somewhat safe 3=mostly safe 4=very safe (saf07*)
  1=almost none 2=about 1/4 3=about 1/2 4=more than 1/2 (saf08*)
  1=nothing 2=not much 3=some 4=a lot (tec29q01)
  1=never 2=1-2x 3=3-5x 4=more than 5x (saf09* saf10* jus17* par11*)
  1=never 2=once in a while 3=most of time 4=all of time (par12*);

 gen byte ss_saf08q01b=(ss_saf08q01==1) if ss_saf08q01~=.;
  label var ss_saf08q01b "almost no students in gangs";
 for var ss_par11*, noheader: qui gen byte Xb=(X==4) if X!=.;
  label var ss_par11q01b "discussed selecting course w/pars >5x";
  label var ss_par11q02b "discussed sch activities w/ pars >5x";
  label var ss_par11q03b "discussed thing you studied w/pars >5x";
  label var ss_par11q04b "discussed homework w/pars >5x";
  label var ss_par11q05b "discussed going to college w/pars >5x";
  label var ss_par11q06b "discussed your grades w/pars >5x";
 for var ss_tch01* ss_sch03* ss_sch04* ss_tec30* ss_saf07* ss_saf08q01
  ss_tec29* ss_par12*, noheader: qui recode X 1/2=0 3/4=1;
 for num 1/6, noheader: qui recode ss_par11q0X 1/2=0 3/4=1;
 summ ss_tch01* ss_sch03* ss_sch04* ss_tec30* ss_saf07* ss_saf08* 
   ss_tec29* ss_par*;
 descr ss_tch01* ss_sch03* ss_sch04* ss_tec30* ss_saf07* ss_saf08* 
   ss_tec29* ss_par*;
  label var ss_saf07q01 "mostly/very safe outside around sch";
  label var ss_saf07q02 "mostly/very safe between home and sch";
  label var ss_saf07q03 "mostly/very safe in hallways & bathrooms";
  label var ss_saf07q04 "mostly/very safe in classes";
  label var ss_saf08q01 "1/2 or more of ss are in gangs";
  label var ss_tec29q01 "learned some/a lot from ts about computers";
  label var ss_par11q01 "discussed selecting course w/pars >2x";
  label var ss_par11q02 "discussed sch activities w/ pars >2x";
  label var ss_par11q03 "discussed thing you studied w/pars >2x";
  label var ss_par11q04 "discussed homework w/pars >2x";
  label var ss_par11q05 "discussed going to college w/pars >2x";
  label var ss_par11q06 "discussed your grades w/pars >2x";
  label var ss_par12q01 "par help w/hwk most/all of time";
  label var ss_par12q02 "par check if hwk done most/all of time";
  label var ss_par12q03 "par praise s for sch work most/all of time";
  label var ss_par12q04 "par enc responsibility most/all of time";
  label var ss_par12q05 "par enc hard work most/all of time";
  label var ss_par12q06 "par insure school on time most/all of time";
  label var ss_par12q07 "par know where I am most/all of time";
  label var ss_par12q08 "par in easy contact most/all of time";
  label var ss_par12q09 "par at home after sch most/all of time";

 for var ss_saf09* ss_saf10* ss_jus17*, noheader: qui recode X 1=0 2/4=1;
 summ ss_saf09* ss_saf10* ss_jus17*;
 descr ss_saf09* ss_saf10* ss_jus17*;
  label var ss_saf09q01 "s got into trouble";
  label var ss_saf09q02 "s got into physical fight w/s";
  label var ss_saf09q03 "s sent to office";
  label var ss_saf09q04 "s put on in-schl suspension";
  label var ss_saf09q05 "s suspended from school";
  label var ss_saf10q01 "pars contacted b/c of trouble";
  label var ss_saf10q02 "pars came to school b/c of trouble";

* for this variable, the fields range from 1-2:
  1=yes, 2=no;
  tab ss_fut08q01;
  recode ss_fut08q01 2=0;
   label var ss_fut08q01 "closest adult encourages educ after hs";
  
* for these variables, the fields range from 1-5:
  1=none 2=a few 3=about half 4=most 5=all (tch02q01 eng41q04 eng41q05)
  1=<1 hour 2=1-3 hrs 3=3-5 hrs 4=5-10 hrs 5=more than 10 hrs (sch05q01)
  1=never 2=once in while 3=1x/week 4=almost every day 5=every day (sch06*)
  1=never 2=1-2x/sem 3=1-2x/month 4=1-2x/week 5=almost every day (tec27*);

 for var ss_tch02* ss_eng41* ss_sch06q04 ss_tec27q01 ss_tec27q02, noheader: 
  qui recode X 1/3=0 4/5=1;
 summ ss_tch02* ss_sch06q04 ss_tec27*;
 descr ss_tch02* ss_sch06q04 ss_tec27*;
  label var ss_tch02q01 "most teachers know s by name";
  label var ss_sch06q04 "regularly hangs out w/friends w/o adult prsnt";
  label var ss_tec27q01 "regularly use computer in class";
  label var ss_tec27q02 "regularly use computer in sch";
  label var ss_eng41q04 "most kids in Eng try get good grades";
  label var ss_eng41q05 "most kids in Eng think good grades are cool";
  
 for var ss_sch06q01 ss_sch06q02 ss_sch06q03 ss_sch06q05, noheader: 
  qui recode X 1/2=0 3/5=1;
 summ ss_sch06q01 ss_sch06q02 ss_sch06q03 ss_sch06q05;
 descr ss_sch06q01 ss_sch06q02 ss_sch06q03 ss_sch06q05;
  label var ss_sch06q01 "regularly attend after-sch progs for sch work";
  label var ss_sch06q02 "regularly participate in sch clubs/orgs";
  label var ss_sch06q03 "regularly participate in grps outside sch";
  label var ss_sch06q05 "regularly work at job";

 tab ss_sch05q01;
 recode ss_sch05q01 1/2=0 3/5=1;
 summ ss_sch05q01;
 descr ss_sch05q01;
  label var ss_sch05q01 ">3 hrs studying out of school";
  
* for this variable, the fields range from 1-6:
  1=10th grade 2=graduate h.s. 3=trade sch 4=2-yr coll 5=4-yr coll 6=post coll;
  recode ss_fut07q01 1/4=0 5/6=1;
  summ ss_fut07q01;
  descr ss_fut07q01;
   label var ss_fut07q01 "expects to complete 4-yr college";

** create some composite measures;
 descr ss_saf07*;
 egen mm_safe=rmin(ss_saf07q03 ss_saf07q04);
  label var mm_safe "reports being safe in school";
 drop ss_saf07*;
 descr ss_jus17*;
 summ ss_jus17*;
 egen mm_police=rmax(ss_jus17q01 ss_jus17q02 ss_jus17q03);
  label var mm_police "reports involvement w/police (excl arrest)";
 drop ss_jus17q01 ss_jus17q02 ss_jus17q03;
 descr ss_saf09* ss_saf10*;
 summ ss_saf09* ss_saf10*;
 corr ss_saf09* ss_saf10*;
 * physical fight seems different from others so excluded;
 egen mm_trob=rmax(ss_saf09q01 ss_saf09q03 ss_saf09q04 ss_saf09q05 
  ss_saf10q01 ss_saf10q02);
  label var mm_trob "reports getting in trb in sch";
 drop ss_saf09* ss_saf10*;
 summ mm_*;

*** Merge in Consortium-Created Survey Measures ***;

** For documentation: see the file "high school About the 2001 survey.doc";

if ${n}==0{; !gzip -d SURVEY\survey2001_meas.dta.gz; };
capture label drop __MERGE;
mmerge sid using "${src}survey2001_meas", type(n:1) unmatched(master) 
 missing(nomatch) ukeep(sid perc like trts acno acad engg peer safe diso 
 sxav sxcu sxsu sxho pars psup self comp cons);
 tab _merge year;
 tab _merge survey;
 for var perc like trts acno acad engg peer safe diso sxav sxcu sxsu sxho
  pars psup self comp cons, noheader: rename X cc_X;

** Only keep information for students who took high school surveys;
* The data file includes all elementary and hs students and 
 we do not want info on kids who took the 8th grade survey (i.e. 
 students from the 2000 cohort who were retained in 8th grade)-- 
 or students from the 2001 cohort;
 for var cc_*, noheader: qui replace X=. if survey~=1;

** exploring how composites relate to underlying variables we pulled;
* keep only individual items that are individually useful;

 descr cc_trts ss_tch*;
  corr cc_trts ss_tch*;
 drop ss_tch01q02 ss_tch01q03 ss_tch01q04 ss_tch01q05 ss_tch01q06 
 ss_tch01q07 ss_tch01q08 ss_tch01q09;

 descr cc_like cc_engg cc_comp cc_self ss_sch03* ss_sch04*;
 corr cc_like ss_sch03*;
 corr cc_engg ss_sch03q04;
 corr cc_comp ss_sch03q01 ss_sch04q08;
 corr cc_self ss_sch03q02 ss_sch03q05 ss_sch04q08;
 drop ss_sch03q02 ss_sch03q04 ss_sch03q05;

 descr cc_cons ss_sch04*;
 corr cc_cons ss_sch04*;
 drop ss_sch04q09;

 descr cc_peer cc_perc cc_acno ss_eng*;
 corr cc_peer cc_perc cc_acno ss_eng*;
 drop ss_eng41q04;

 descr cc_diso mm_trob;
 corr cc_diso mm_trob;
 
 descr cc_sx* ss_tec*;
 drop cc_sx* ss_tec29q01 ss_tec30q05;

 descr ss_fut08* ss_par11q05;
 corr ss_fut08* ss_par11q05;
 drop ss_fut08*;

 descr cc_pars ss_par11* ss_par12*;
 drop ss_par11q06* ss_par12q03 ss_par12q04 ss_par12q08;

*** Add information on school-level response rates ***;

 * merge in high school survey response rates to Fall Yr 1 school;
 if ${n}==0{; !gzip -d SURVEY\responserates.dta.gz; };
 capture label drop __MERGE;
 mmerge unitF1 using "${src}responserates.dta", t(n:1) unmatched(master) 
  missing(nomatch) ukeep(num610 num9b msurv610 msurv9b) umatch(unit);
 tab unitF1 uF1name if unitF1~=. & _merge~=3;
 tab year if unitF1~=. & _merge~=3;
 for var num610 num9b msurv610 msurv9b: replace X=. if year==2001;
 
 * calculate fraction of 9th graders taking the survey;
 count if enrollF1==1 & year==2000;
 descr num610 num9b msurv610 msurv9b; 
 summ num610 num9b msurv610 msurv9b;
 tab gradeF1 if num610~=. & num9b==.;
 gen uF1msurv=msurv9b;
 tab unitF1 if enrollF19==1 & year==2000 & uF1msurv==. & unitF1<2000;
 replace uF1msurv=msurv610 if uF1msurv==. & msurv610!=.;
  label var uF1msurv "fraction of peers taking survey";
 drop num610 num9b msurv610 msurv9b;

 * examine the distribution of survey response rates;
 egen tmp1=tag(unitF1) if year==2000;
 egen tmp2=max(enrollF19), by(unitF1 year);
 summ uF1msurv if tmp2==0;
 replace tmp1=0 if tmp2==0;
 summ uF1msurv if tmp1==1, d;
 count if tmp1==1 & uF1msurv==0;
 count if tmp1==1 & uF1msurv>0 & uF1msurv<0.25;
 count if tmp1==1 & uF1msurv>=0.25 & uF1msurv!=.;

 * are response rates correlated with observable school characteristics 
 within our sample?;
 * yes = schools with higher achieving students have higher response rates;
 corr uF1msurv uF1pnorms if tmp1==1;
 corr uF1msurv uF1pnorms if tmp1==1 & uF1msurv~=0;
 
 * look carefully at response rates in all of the application schools;
 * Von Steuben (1610), Roosevelt (1520), Lake View (1430), and Robeson (1320)
  all had zero response rates;
 sort unitF1;
 list unitF1 uF1name uF1msurv uF1pnorms if tmp1==1 & 
  (unitF1==1210|unitF1==1230|unitF1==1320|unitF1==1360|unitF1==1380|
   unitF1==1390|unitF1==1420|unitF1==1430|unitF1==1520|unitF1==1540|
   unitF1==1580|unitF1==1610|unitF1==1630|unitF1==1640|unitF1==1790|
   unitF1==1820|unitF1==1830|unitF1==1860|unitF1==1890);
 drop tmp*;
 
 * merge in survey response rates to choice school;
 capture label drop __MERGE;
 mmerge cunit using "${src}responserates.dta", t(n:1) unmatched(master) 
  missing(nomatch) ukeep(msurv610 msurv9b) umatch(unit);
 if ${n}==0{; !gzip SURVEY\responserates.dta; };
 tab cunit if year==2000 & _merge~=3;
 for var msurv610 msurv9b: replace X=. if year==2001;
 gen cumsurv=msurv9b;
  label var cumsurv "fraction of 9th graders taking survey";
 replace cumsurv=msurv610 if cumsurv==. & msurv610!=.;
 tab cunit if cumsurv==. & year==2000;
 drop msurv610 msurv9b;


*******************************************************;
*** Merge in 8th Grade Survey Items for 2001 Cohort ***;
*******************************************************;

** these are pre-lottery items from Spring of their 8th grade year;

*** Merge in Item-Level Survey Measures for each Student ***;

 if ${n}==0{; !gzip -d SURVEY\survey2001_el.dta.gz; };
 capture label drop __MERGE;
 mmerge sid using "${src}survey2001_el", type(n:1) unmatched(master) 
  missing(nomatch) ukeep(sid sch03* sch05* sch06* saf09* saf10* par11* 
  par12* par13* par14* par15* sbk* com25* );
 if ${n}==0{; !gzip SURVEY\survey2001_el.dta; };
 tab _merge year;
 gen byte surveyel=_merge==3 if year==2001;
 summ surveyel;
  label var surveyel "in 8th grade Spring survey (2001 cohort only)";

 * rename survey items;
 for var sch03* sch05* sch06* saf09* saf10* par11* par12* par13* par14* 
  par15* sbk* com25*, noheader: qui replace X=. if surveyel!=1 \ 
  rename X vv_X;
 qui compress;

*** Merge in Consortium-Created Survey Measures ***;

 capture label drop __MERGE;
 mmerge sid using "${src}survey2001_meas", type(n:1) unmatched(master) 
  missing(nomatch) ukeep(sid comp cons diso humr like pars psup self);
 if ${n}==0{; !gzip SURVEY\survey2001_meas.dta; };
 tab _merge year;
 tab _merge surveyel;
 
* The file "survey2001_meas.dta" includes all elementary and hs students, 
  which will include both the 2000 and 2001 cohorts.  For this exercise
  of examining pre-lottery characteristics to explore non-random attrition,
  we only want to focus on the 2001 cohort who took the 2001 survey as 8th 
  graders.  Hence we set the variables to missing for other students;
 for var comp cons diso humr like pars psup self, noheader: 
  qui replace X=. if surveyel==. \ rename X vv_X;

** Recode Survey Items (and drop unneeded variables);

 * We didn't pull the individual items on social competence, social
   conscience, and self-efficacy since they did not seem individually very
   compelling; 
  summ vv_comp vv_cons vv_self;
  descr vv_comp vv_cons vv_self;	

 * Attitude toward school (0 vs 1, where 1=agree or strongly agree);
  for var vv_sch03*: tab X \ recode X 1/2=0 3/4=1;
  * like is the composite created from these underlying variables;
  summ vv_sch03* vv_like;
  descr vv_like;
   label var vv_sch03q01 "look forward to sch";
   label var vv_sch03q02 "wish didn't have to go to sch"; 
   label var vv_sch03q03 "wish could go to diff sch";
   label var vv_sch03q04 "bored in sch";
   label var vv_sch03q05 "glad to return from summer vacation";
  drop vv_sch03q02 vv_sch03q04 vv_sch03q05;

 * Homework (hours studying outside school);
  tab vv_sch05q01; 
  recode vv_sch05q01 1/2=0 3/4=1;
  summ vv_sch05q01;
   label var vv_sch05q01 "3+ hrs studying out of school";

 * Afterschool activities;
  for var vv_sch06q01 vv_sch06q02 vv_sch06q03 vv_sch06q04: 
   tab X \ recode X 1/2=0 3/5=1;
  summ vv_sch06q01 vv_sch06q02 vv_sch06q03 vv_sch06q04;
   label var vv_sch06q01 "regularly attend after-sch progs for sch work";
   label var vv_sch06q02 "regularly participate in sch clubs/orgs";
   label var vv_sch06q03 "regularly participate in grps outside sch";
   label var vv_sch06q04 "hung out with friends without adult present";

 * Disciplinary Problems;
  for var vv_saf09* vv_saf10*: tab X \ recode X 1=0 2/4=1;
  * "diso" is the composite created from the individual variables;
  summ vv_saf09* vv_saf10* vv_diso;
  descr vv_diso;
   label var vv_saf09q01 "s got into trouble";
   label var vv_saf09q02 "s got into physical fight w/s";
   label var vv_saf09q03 "s sent to office";
   label var vv_saf09q04 "s put on in-schl suspension";
   label var vv_saf09q05 "s suspended from school";
   label var vv_saf10q01 "pars contacted b/c of trouble";
   label var vv_saf10q02 "pars came to school b/c of trouble";
  egen byte vv_trob=rmax(vv_saf09q01 vv_saf09q03 vv_saf09q04 vv_saf09q05
   vv_saf10q01 vv_saf10q02);
   label var vv_trob "got into trouble at school";
  drop vv_saf09* vv_saf10*;
 
 * Discussing things with parents more; 
  for var vv_par11*: tab X \ recode X 1/2=0 3/4=1;
  summ vv_par11*;
   label var vv_par11q01 "talk w/par about courses >2x";
   label var vv_par11q02 "talk w/par about activities >2x";
   label var vv_par11q03 "talk w/par about topics >2x";
   label var vv_par11q04 "talk w/par about homework >2x";
   label var vv_par11q05 "talk w/par about going to coll >2x";
   label var vv_par11q06 "talk w/par about grades >2x";
  drop vv_par11q01 vv_par11q06;

 * How often parents do the following; 
  for var vv_par12*: tab X \ recode X 1/2=0 3/4=1;
  * the items in 11 and 12 are used to create composites "psup" and "pars";
  summ vv_par12* vv_psup vv_pars;
  descr vv_psup vv_pars;
   label var vv_par12q01 "par help w/hwk most/all of time";
   label var vv_par12q02 "par check hwk most/all of time";
   label var vv_par12q03 "par praise good work most/all of time";
   label var vv_par12q04 "par enc respon. most/all of time";
   label var vv_par12q05 "par enc hard work most/all of time";
   label var vv_par12q06 "par make sure to sch on time most/all of time";
   label var vv_par12q07 "par know where r is after sch most/all of time";
   label var vv_par12q08 "par can be reached most/all of time";
   label var vv_par12q09 "par at home after sch most/all of time";
  drop vv_par12q03 vv_par12q04 vv_par12q08;

 * Household Composition;
  tab vv_par13q01;
  tab vv_par13q02;
  gen byte vv_bothpar=(vv_par13q01==1&vv_par13q02==1) 
   if vv_par13q01!=. & vv_par13q02!=.;
   label var vv_bothpar "lives with both parents";
  sum vv_bothpar vv_par13q01 vv_par13q02;
  tab yypar vv_bothpar, cell;
  drop vv_par13*;
 
 * Other Family Background Variables;
  
  * mother's education;
  tab vv_par14q01;
  gen byte vv_momsc=(vv_par14q01==4) 
   if vv_par14q01!=. & vv_par14q01!=7;
  gen byte vv_momba=(vv_par14q01>=5&vv_par14q01<=6) 
   if vv_par14q01!=. & vv_par14q01!=7;
  replace vv_momsc=vv_momsc+vv_momba;
   label var vv_momsc "mother completed some college+";
   label var vv_momba "mother completed BA+";
  summ vv_mom* vv_par14*;
  drop vv_par14* vv_momba;
 
  * educational resources;
  * the variables vv_par15q01-10 indicate whether students has a 
   variety of books and other resources at home.  There are no 
   missing values and no recoding seems necessary;
  summ vv_par15*;
  descr vv_par15*;
  replace vv_par15q04=1 if vv_par15q05==1|vv_par15q06==1;
   label var vv_par15q04 "encyclopedia,atlas, or dictionary";
  drop vv_par15q03 vv_par15q05 vv_par15q06;

  * student' background;
  tab vv_sbk16q01;
  recode vv_sbk16q01 2=0;
   label var vv_sbk16q01 "stud born in U.S.";
  tab vv_sbk18q01;
  recode vv_sbk18q01 2=0;
   label var vv_sbk18q01 "speak language other than English";
  tab vv_sbk23q01;
  recode vv_sbk23q01 3/6=0 1/2=1;
   label var vv_sbk23q01 "attend relig services 1x or more/week";
  tab vv_sbk24q01;
  recode vv_sbk24q01 2/3=0;
   label var vv_sbk24q01 "stud considers herself very religious";
  summ vv_sbk16q01 vv_sbk18q01 vv_sbk23q01 vv_sbk24q01;
  descr vv_sbk*;
  drop vv_sbk17q01 vv_sbk19q01 vv_sbk20q01 vv_sbk21q01; 

 * Community/neighborhood Characteristics;
  * 0 vs. 1, where 1 = agree or strongly agree;
  for var vv_com25*: tab X \ recode X 1/2=0 3/4=1;
  * the composite created from these variables is "humr";
  summ vv_com25* vv_humr;
  descr vv_humr;
   label var vv_com25q01 "if comm. has problem, nghbors deal w/it";
   label var vv_com25q02 "no one in nbhood cares what happens here";
   label var vv_com25q03 "adults in nbhood kids can look up to";
   label var vv_com25q04 "adults in nbhood know who local kids are";
   label var vv_com25q05 "adults make sure kids in nbhood are safe";
   label var vv_com25q06 "during day, safe for kids in parks";
   label var vv_com25q07 "people in nbhood can be trusted";
   label var vv_com25q08 "equipment in nbhood park well kept";
  drop vv_com25q01 vv_com25q04 vv_com25q07 vv_com25q08;

*** Check school-level response rates ***;

 egen uS0msurv=mean(surveyel) if year==2001, by(unitS0);
 summ uS0msurv, detail;
 egen tmp=tag(unitS0) if year==2001;
 summ uS0msurv if tmp==1, detail;
  label var uS0msurv "fraction of applicants from same sch taking survey";
 drop tmp;


******************************************************;
*** Merge in class-level achievement/race measures ***;
******************************************************;

  * These measure the quality and race/ethnicity of peers in the student's 
   9th grade classroom.  Data created in classpeers2.do, stored in 
   classpeers2.dta;
 * We use the English-class measures since they have less missing data 
   and are easier to interpret, but we use the first period measure if 
   the English measure is missing or the number tested is very small;
 if ${n}==0{; global src="CLASSPEERS\"; !gzip -d ${src}classpeers2.dta; };
 if ${n}==1{; global src="c:\projects\magnet schools\data\"; };
 capture label drop __MERGE;
 mmerge sid year using "${src}classpeers2", type(n:1) unmatched(master) 
 ukeep(cmp1xil cmp1nsid cmp1notest cmp1gr9 cmengxil cmengnsid cmengnotest
  cmenggr9 cmengpblack cmengphisp cmp1pblack cmp1phisp);
 if ${n}==0{; !gzip ${src}classpeers2.dta; };
 tab gradeF1 if _merge==1;
 * note: the notest measures are actually the fraction NOT taking prior exams;
 descr cmp1* cmeng*;
 summ cmp1* cmeng*;
 gen ntstp1=round((1-cmp1notest)*cmp1nsid,1);
 gen ntsteng=round((1-cmengnotest)*cmengnsid,1);
 gen uF1clmn8=cmengxil;
 replace uF1clmn8=cmp1xil if uF1clmn8==.|
  (uF1clmn8~=. & ntsteng<10 & cmp1xil~=. & ntstp1>=10 & ntstp1~=.);
  label var uF1clmn8 "mean composite 8th gr scores for Eng class";
 pwcorr uF1clmn8 cmengnotest cmenggr9;
 
 * create racial composition variables;

  gen cmengpmin=cmengphisp+cmengpblack;
  gen cmengpdiff=cmengpmin if xxblk==0&xxhisp==0;
  replace cmengpdiff=1-cmengpblack if xxblk==1;
  replace cmengpdiff=1-cmengphisp if xxhisp==1;
  gen cmengmaj=0 if cmengpmin~=. & xxblk~=.;
  replace cmengmaj=1 if xxblk==1&(cmengpblack>cmengphisp)
   &(cmengpblack>1-cmengpmin) & cmengpmin~=.;
  replace cmengmaj=1 if xxhisp==1&(cmengphisp>cmengpblack)
   &(cmengphisp>1-cmengpmin) & cmengpmin~=.;
  replace cmengmaj=1 if (xxblk==0&xxhisp==0)&((1-cmengpmin)>cmengpblack)
   &((1-cmengpmin)>cmengphisp) & cmengpmin~=.;
  
  gen cmp1pmin=cmp1phisp+cmp1pblack;
  gen cmp1pdiff=cmp1pmin if xxblk==0&xxhisp==0;
  replace cmp1pdiff=1-cmp1pblack if xxblk==1;
  replace cmp1pdiff=1-cmp1phisp if xxhisp==1;
  gen cmp1maj=0 if cmp1pmin~=. & xxblk~=.;
  replace cmp1maj=1 if xxblk==1&(cmp1pblack>cmp1phisp)
   &(cmp1pblack>1-cmp1pmin) & cmp1pmin~=.;
  replace cmp1maj=1 if xxhisp==1&(cmp1phisp>cmp1pblack)
   &(cmp1phisp>1-cmp1pmin) & cmp1pmin~=.;
  replace cmp1maj=1 if (xxblk==0&xxhisp==0)&((1-cmp1pmin)>cmp1pblack)
   &((1-cmp1pmin)>cmp1phisp) & cmp1pmin~=.;
  
  gen uF1clpblack=cmengpblack;
  gen uF1clphisp=cmengphisp;
  gen uF1clpmin=cmengpmin;
  gen uF1clpdiff=cmengpdiff;
  gen uF1clmaj=cmengmaj;
  for any pblack phisp pmin pdiff maj:
   replace uF1clX=cmp1X if uF1clX==.| 
   (uF1clX~=. & ntsteng<10 & cmp1X~=. & ntstp1>=10 & ntstp1~=.);
  rename uF1clpblack uF1clpblk;
   label var uF1clpblk "% black in English class";
   label var uF1clphisp "% hispanic in English class";
   label var uF1clpmin "% minority in English class";
   label var uF1clpdiff "% not own race/ethnic group in English class"; 
   label var uF1clmaj "in majority race/ethnic group in English class";

 * Now create comparable measures at the school level;

  gen uF1pdiff=uF1pmin if xxblk==0&xxhisp==0;
  replace uF1pdiff=1-uF1pblk if xxblk==1;
  replace uF1pdiff=1-uF1phisp if xxhisp==1;
  gen uF1maj=0 if uF1pwhi~=. & xxwhi~=.;
  replace uF1maj=1 if xxblk==1&(uF1pblk>uF1phisp)&(uF1pblk>1-uF1pmin)
   & uF1pwhi~=.;
  replace uF1maj=1 if xxhisp==1&(uF1phisp>uF1pblk)&(uF1phisp>1-uF1pmin)
   & uF1pwhi~=.;
  replace uF1maj=1 if (xxblk==0&xxhisp==0)&((1-uF1pmin)>uF1pblk)
   &((1-uF1pmin)>uF1phisp) & uF1pwhi~=.;
   label var uF1pdiff "% not own race/ethnic group"; 
   label var uF1maj "in majority race/ethnic group";

 qui compress;
 drop cmp1* cmeng* ntst*;


*************************************************;
*** Merge in information on program offerings ***;
*************************************************;

 * Note: If a student attends a school that is not in the options for 
  knowledge booklet, these variables will all be zero;
 
 * First merge info onto Fall 9th grade schools;
 if ${n}==0{; global src="MAGLIST\"; !gzip -d ${src}maglistmaster.dta; };
 if ${n}==1{; global src="c:\projects\magnet schools\maglist\"; }; 
 capture label drop __MERGE;
 mmerge year unitF1 using "${src}maglistmaster", type(n:1) umatch(year unit)
  unmatched(master) missing(nomatch)
  ukeep(tech mst ap ib arts lang jrotc law env voc med cprep);
 descr tech mst ap ib arts lang jrotc law env voc med cprep;
 summ tech mst ap ib arts lang jrotc law env voc med cprep;
 tab _merge if enrollF1==1;
 gen byte uF1acd=(ap==1|ib==1|cprep==1) if enrollF1==1;
   label var uF1acd "offers AP/IB/coll prep programs";
 * tech==1 often refers to whether school has a computer studies program;
 gen byte uF1tech=(tech==1|mst==1) if enrollF1==1;
  label var uF1tech "offers technical/math program";
 gen byte uF1lang=(arts==1|lang==1) if enrollF1==1;
  label var uF1lang "offers arts/language program";
 gen byte uF1prof=(jrotc==1|law==1|env==1|voc==1|med==1) if enrollF1==1;
  label var uF1prof "offers vocational/professional program";
 summ uF1acd uF1tech uF1lang uF1prof;
 drop tech mst ap ib arts lang jrotc law env voc med cprep;
  
* Next merge info onto choice school; 
 capture label drop __MERGE;
 mmerge year cunit using "${src}maglistmaster", type(n:1) umatch(year unit)
 unmatched(master) missing(nomatch)
 ukeep(tech mst ap ib arts lang jrotc law env voc med cprep);
 if ${n}==0{; !gzip ${src}maglistmaster.dta; };
 tab _merge;
 egen tmp=max(outvar), by(cunit year);
 egen tag=tag(cunit year);
 replace tag=0 if tag==1 & tmp==0|tmp==.;
 sort cuname year;
 * Note: program avail is described in maganal_hs_schs.xls for analysis schs;
 list cunit cuname year 
  tech mst ap ib arts lang jrotc law env voc med cprep if tag==1;
 summ tech mst ap ib arts lang jrotc law env voc med cprep if tag==1;
 gen byte cuacd=(ap==1|ib==1|cprep==1);
  label var cuacd "offers AP/IB/coll prep programs";
 gen cutech=(tech==1|mst==1);
  label var cutech "offers technical/math program";
 gen culang=(arts==1|lang==1);
  label var culang "offers arts/language program";
 gen cuprof=(jrotc==1|law==1|env==1|voc==1|med==1);
  label var cuprof "offers vocational/professional program";
 summ cuacd cutech culang cuprof;
 drop tmp tag tech mst ap ib arts lang jrotc law env voc med cprep;

save maganal_hs, replace;


**************************************************;
*** Add share of middle school peers in own hs ***;
**************************************************;

** This is to capture the impact of mobility/transition costs;

/*** This first program calculates the % of students in each 
     9th grade class who attended various 8th grade schools ***/
 
program define wherefrom;

 ** find all schools serving 9th graders in Fall;
  if ${n}==0{; global src=""; !gzip -d allm9`2'full.dta; };
  if ${n}==1{; global src="e:\fullmasterfiles\"; };
  * note: unit 2490 reported grade 1 for 9th graders in 2000, as
    discovered above;
  use sid statu granu cursc if (statu==1|statu==2) & 
   (granu==9|(granu==1&cursc==2490)) using "${src}allm9`2'full";
  if ${n}==0{; !gzip allm9`2'full.dta; };
  tab granu if cursc==2490;
  drop statu granu;
  rename cursc unitF1;
  replace unitF1=(int(unitF1/10))*10;
  count if unitF1==.|sid==.;
  keep sid unitF1;
    
 ** find the schools attended by these 9th graders the prior spring;
 ** note: this only includes students who were active 8th graders the 
    prior spring, so it will not count kids who had been retained in 9th
    grade, or who happened to skip from 7th to 9th, or other anomalies;
  if ${n}==0{; !gzip -d allm`3'.dta; };
  if ${n}==1 & `1'==2000{; global src="e:\data\masterfiles\"; };
  if ${n}==1 & `1'==2001{; global src="e:\fullmasterfiles\"; };
  mmerge sid using "${src}allm`3'", type(1:1) unmatched(master)
   uif(granu==8&(statu==1|statu==2)) ukeep(granu statu cursc);
  if ${n}==0{; !gzip allm`3'.dta; };
  drop granu statu;
  gen unitS0=(int(cursc/10))*10;
  * note: unitS0 will be missing for the kids described in the note above;
  vallist unitS0, global(sch);
  for any ${sch}, noheader: qui gen byte unitS0_X=(unitS0==X);
 
 ** collapse by 9th grade school to create indicators of % kids attended 
    each 8th grade school;
  collapse (mean) unitS0_*, by(unitF1);
  qui reshape long unitS0_, i(unitF1) j(unitS0);
  rename unitS0_ mfromu8; 
   label var mfromu8 "% in unitF1 from student's 8th gr school";
  * note that the percentages will not add up to 100 for each unitF1 b/c 
    of the kids who were not enrolled in grade 8;
  egen tmp=sum(mfromu8), by(unitF1);
  summ tmp, detail;
  disp "** which Fall 9th grade schs have no studs from 8th prior yr **";
  tab unitF1 if tmp==0;
  drop tmp;

 gen year=`1';
 summ;
 if `1'==2001{;
 append using wherefrom;
 };
 qui compress;
 save wherefrom, replace;
 macro drop sch;
  
end;

wherefrom 2000 00 500;
wherefrom 2001 01 501full;

/*** This second program calculates the % of students from a 
     student's 8th gr sch that went to his/her 9th grade sch ***/
   
program define whereto;

 ** find all schools serving 8th graders in Spring;
  if ${n}==0{; !gzip -d allm`2'.dta; };
  if ${n}==1 & `1'==2000{; global src="e:\data\masterfiles\"; };
  if ${n}==1 & `1'==2001{; global src="e:\fullmasterfiles\"; };
  use sid statu granu cursc if (statu==1|statu==2) & granu==8
   using "${src}allm`2'";
  if ${n}==0{; !gzip allm`2'.dta; };
  drop statu granu;
  rename cursc unitS0;
  replace unitS0=(int(unitS0/10))*10;
  count if unitS0==.|sid==.;
  keep sid unitS0;
    
 ** find the schools attended by these 8th graders the following fall;
 ** note that here we do not restrict the sample to kids in the 9th grade, 
    so the % will be calculated using all kids as the denominator.;
  if ${n}==0{; !gzip -d allm9`3'full.dta; };
  if ${n}==1{; global src="e:\fullmasterfiles\"; };
  mmerge sid using "${src}allm9`3'full", type(1:1) unmatched(master)
   uif(statu==1|statu==2) ukeep(statu cursc);
  if ${n}==0{; !gzip allm9`3'full.dta; };
  label drop __MERGE;
  drop statu;
  gen unitF1=(int(cursc/10))*10;
  * note: kids who were not enrolled this fall will have unitF1==.;
  vallist unitF1, global(sch);
  for any ${sch}, noheader: qui gen byte unitF1_X=(unitF1==X);
  
 ** collapse by 8th grade school;
  collapse (mean) unitF1_* , by(unitS0);
  qui reshape long unitF1_, i(unitS0) j(unitF1);
  rename unitF1_ mtou9;
   label var mtou9 "% from stud's unitS0 at unitF1 the next year";
  * note that the percentages will not add up to 100 for each unitS0 b/c 
    of the kids who were not enrolled in grade 9;
  egen tmp=sum(mtou9), by(unitS0);
  summ tmp, detail;
  display "** Spring 8th grade schs w/no students in 9th next year **";
  tab unitS0 if tmp==0;
  drop tmp;

  gen year=`1';
  summ;
  if `1'==2001{;
  append using whereto;
  };
  qui compress;
  save whereto, replace;
  macro drop sch;
  
end;

whereto 2000 500 00;
whereto 2001 501full 01;

/*** merging these variables to our applications data ***/

use maganal_hs;

** Fall school;

capture label drop __MERGE;
mmerge year unitF1 unitS0 using wherefrom.dta, t(n:1)
 unmatch(master) ukeep(mfromu8);
* not defined for a few retained/skipping to 10th;
tab gradeF1 if _merge==1;

capture label drop __MERGE;
mmerge year unitF1 unitS0 using whereto.dta, t(n:1)
 unmatch(master) ukeep(mtou9);

count if enrollF1==1;
summ mfromu8 mtou9;
corr mfromu8 mtou9;

** choice school;

capture label drop __MERGE;
mmerge year cunit unitS0 using wherefrom.dta, t(n:1)
 umatch(year unitF1 unitS0) unmatch(master) ukeep(mfromu8)
 urename(mfromu8 cumfromu8);
tab cunit if _merge==1 & cunit<2000;
 label var cumfromu8 "% in cunit from student's 8th gr school";

capture label drop __MERGE;
mmerge year cunit unitS0 using whereto.dta, t(n:1)
 umatch(year unitF1 unitS0) unmatch(master) ukeep(mtou9)
 urename(mtou9 cumtou9);
tab cunit if _merge==1 & cunit<2000;
 label var cumtou9 "% from stud's unitS0 at cunit the next year";

summ cumfromu8 cumtou9;

save maganal_hs, replace;
!del whereto.dta;
!del wherefrom.dta;


************************************;
*** Create School-level Data Set ***;
************************************;

* note: we use the 1999 9th grade cohort to provide a lagged 
 value-added measure-- this cohort is dropped below;

*** ALL 9TH GRADE SCHOOLS ***;

if ${n}==0{; 
global src="";
!gzip -d allm599.dta.gz;
!gzip -d allm500.dta.gz;
!gzip -d allm501full.dta.gz;
!gzip -d allm900full.dta.gz;
!gzip -d allm901full.dta.gz;
!gzip -d itbs*b.dta.gz;
!gzip -d tap*.dta.gz;
!gzip -d schl01.dta.gz;
!gzip -d schselectivity.dta.gz;
};

program define geths;  

 disp "** find all schools serving 9th graders in Fall **";
  * using Spring 2000 for 1999 Fall cohort since I do not have the 1999
    Fall masterfile (just interested in test scores for this yr anyway);
  if ${n}==1 & `1'==1999{; global src="e:\data\masterfiles\"; };
  if ${n}==1 & `1'~=1999{; global src="e:\fullmasterfiles\"; };
  * note: unit 2490 reported grade 1 for 9th graders in 2000, as
    discovered above;
  use sid statu granu cursc sped ethni gend guard bdate 
   if (statu==1|statu==2) & (granu==9|(granu==1&cursc==2490&`1'==2000))
   using ${src}allm`2';
  tab granu if cursc==2490;
  drop statu granu;
  rename cursc unit;
  replace unit=(int(unit/10))*10;
  count if unit==.;
  disp "** Dyett Middle (8070) became Dyett Academic Center (1600) **";
  count if unit==1600;
  count if unit==8070;
  replace unit=8070 if unit==1600;
  gen pctsped=(sped~="");
  drop sped;
  tab ethni, m;
  gen pctblack=(ethni==2);
  gen pcthisp=(ethni==5);

 disp "** create add'l vars for value-added regressions **";
  gen zznatam=(ethni==3);
  gen zzasian=(ethni==4);
  drop ethni;
  tab gend, m;
  gen zzmale=(gend==1);
  drop gend;
  tab guard, m;
  gen zzpar=(guard=="1"|guard=="2");
  drop guard;
  summ bdate;
  gen str6 tmpvar=string(bdate);
  replace tmpvar="0"+substr(tmpvar,1,5) if bdate<100000;
  gen str8 tmpvar2=substr(tmpvar,1,2)+"/"+substr(tmpvar,3,2)+"/"+
     substr(tmpvar,5,2);
  gen tmpbdate=date(tmpvar2,"md19y") if tmpvar2~="";
  gen tmp=mdy(1,1,`1');
  gen zzage=round(((tmp-tmpbdate)/365),.1);
  sum zzage, detail;
  egen tmp1=pctile(zzage), p(1);
  egen tmp2=pctile(zzage), p(99);
  replace zzage=tmp1 if zzage<tmp1;
  replace zzage=tmp2 if zzage>tmp2 & zzage~=.;
  drop tmp* bdate;
  
 disp "** add 8th grade test scores for incoming students **";
  if ${n}==1{; global src="e:\data\itbs\"; };
  mmerge sid using "${src}itbs`1'b", type(1:1) unmatched(master)
   ukeep(readxil mathtxil) 
   urename(readxil mnrd8th \ mathtxil mnmth8th);
  for var mnrd8th mnmth8th: summ X \ replace X=X/100;

 disp "** get 8th grade campus and demographics **";
  if ${n}==1 & `1'~=2001{; global src="e:\data\masterfiles\"; };
  if ${n}==1 & `1'==2001{; global src="e:\fullmasterfiles\"; };
  capture label drop __MERGE;
  mmerge sid using "${src}allm`3'", type(1:1) unmatched(master)
   uif ((statu==1|statu==2)&granu==8) 
   ukeep(granu statu cursc lunch bcat sped) 
   urename(statu statu8 \ cursc unit8 \ lunch lunch8 \ 
    bcat bcat8 \ sped sped8);
  drop granu;
  replace unit8=(int(unit8/10))*10;
  for var mnrd8th mnmth8th: replace X=. if statu8~=1 & statu8~=2;
  tab lunch8, m;
  gen zzflunch=lunch8=="F" if (statu8==1|statu8==2);
  gen zzrlunch=lunch8=="R" if (statu8==1|statu8==2);
  drop lunch8;
  capture gen temp=real(bcat8);
  capture gen temp=bcat8;
  drop bcat8;
  rename temp bcat8;
  tab bcat8, m;
  gen byte zzbil=(bcat8>=1&bcat8<=4) if (statu8==1|statu8==2);
  drop bcat8;
  tab sped8, m;
  gen zzsped=sped8~="" if (statu8==1|statu8==2);
  drop sped8 statu8;

 disp "** add 9th grade test scores for incoming students **";
 * note: this is used to calculate a crude measure of value-added; 
  if ${n}==1{; global src="e:\data\tap\"; };
  capture label drop __MERGE;
  mmerge sid using "${src}tap`4'", type(1:1) unmatched(master)
   ukeep(readxil);
  summ readxil;
  replace readxil=(readxil/100);

 disp "** create value-added measures **";
 disp "*** TABLE B1 ***";
  count if unit==.;
  for var pctblack pcthisp: gen zzX=X;
  xtile tmp1=mnrd8th, nq(20);
  qui tab tmp1, gen(zz);
  drop zz1;
  * regression without 8th grade campus fixed effects;
  reg readxil zz*;
  predict mnrdva1, resid;
  egen tmp2=count(mnrdva1), by(unit);
  replace mnrdva1=. if tmp2<10;
  * with 8th grade campus fixed effects;
  * first check that 8th grade campuses serve a number of high 
   schools, and that high schools receive students from a
   number of campuses;
  egen tmp3=nvals(unit) if readxil~=., by(unit8);
  egen tmp4=min(tmp3) if readxil~=., by(unit);
  egen tmp5=nvals(unit8) if readxil~=., by(unit);
  sort unit;
  summ tmp4 tmp5 if unit~=unit[_n-1], detail;
  tab unit if tmp4==1 & tmp5==1;
  tab tmp4 if tmp5==1;
  tab tmp5 if tmp4==1;
  * use areg in order to get overall R-squared (xtreg calculates
   the R-squared after de-meaning);
  areg readxil zz*, absorb(unit8);
  predict mnrdva2, residuals;
  egen tmp6=count(mnrdva2), by(unit);
  replace mnrdva2=. if tmp6<10;
  summ mnrdva*;
  * note: low valued-added schools have fewer students taking 
   the 9th grade exams-- this explains why later our measure when
   weighted by 9th grade enrollment has a mean less than 0;
  gen tmp7=(mnrdva2==.);
  egen tmp8=mean(tmp7), by(unit);
  corr tmp8 mnrdva2;
  drop tmp* zz* unit8;

 disp "** collapse to create school-level data set **";
  gen enr9th=1;
  collapse (sum) enr9th (mean) mnrd8th mnmth8th mnrdva*
  pctsped pctblack pcthisp, by(unit);
   label var enr9th "9th grade enrollment";
   label var mnrd8th "mean 8th gr ITBS reading pctile for entrants";
   label var mnmth8th "mean 8th gr ITBS math pctile for entrants";
   label var mnrdva1 "value added based on resid for entrants";
   label var mnrdva2 "value added from specif incl. 8th gr campus FE";
   label var pctsped "fraction 9th graders special ed";
   label var pctblack "fraction 9th graders black";
   label var pcthisp "fraction 9th graders hispanic";

 disp "** add school characteristics **";
  if ${n}==1{; global src="e:\data\school_level\misc\"; };
  capture label drop __MERGE;
  mmerge unit using "${src}schl01", type(1:1) unmatched(master)
   ukeep(schlname schltype);
  disp "** which 9th grade schools are missing in schl01.dta? **";
  tab unit if schlname=="";
  * 450 = Sp Ed Dual Enroll;
  replace schlname="Sp Ed Dual Enroll" if unit==450 & schlname=="";
  replace schltype="Special Education" if unit==450 & schltype=="";
  * 950 = Specialized/Alt School;
  replace schlname="Specialized/Alt School" if unit==950 & schlname=="";
  replace schltype="Alternative" if unit==950 & schltype=="";
  * 1770 = Healy South, an alternative school;
  replace schlname="Healy South" if unit==1770 & schlname=="";
  replace schltype="Alternative" if unit==1770 & schltype=="";

 disp "** identify non-regular high schools **";
  gen reghs=1;
   label var reghs "regular high school";
  disp "** unit>=2000 with <=10 9th graders **";
  list unit schlname schltype enr9th if enr9th<=10 & unit>=2000;
  replace reghs=0 if enr9th<=10 & unit>=2000;
  disp "** check schools with unit>=2000 with >10 9th graders **";
  list unit schlname schltype enr9th if enr9th>10 & unit>=2000;
  disp "** alternative and special ed schools **";
  tab schltype;
  for any "Academic Prep Center" "Alt-Pregnant Girls" "Alternative"
   "Jail/Juv Detention" "Special Education": 
   replace reghs=0 if schltype=="X";
  display "** which have no students w/prior year 8th grade scores? **";
  list unit schlname schltype enr9th if mnrd8th==. & reghs==1;
  replace reghs=0 if mnrd8th==. & reghs==1;
  disp "** which are special ed schools classified as general? **";
  list unit schlname schltype enr9th pctsped if pctsped>.5 & pctsped~=.
   & reghs==1;
  replace schltype="Special Education" if pctsped>.5 & pctsped~=. 
   & reghs==1;
  replace reghs=0 if pctsped>.5 & pctsped~=. & reghs==1;
  disp "** schools with unit<2000 that serve <=10 9th graders **";
  list unit schlname schltype enr9th if unit<2000 & enr9th<=10 
   & reghs==1;
  replace reghs=0 if unit<2000 & enr9th<=10 & reghs==1;

 disp "** append years **"; 
 gen year=`1';
 if `1'~=1999{;
 append using maganal_hs_schs;
 };

 qui compress;
 sort unit year;
 save maganal_hs_schs, replace;

end;

** running program;
 geths 1999 500 599 00;
 geths 2000 900full 500 01;
 geths 2001 901full 501full 2002b;
 summ;

** create value-added measures based on enrollment-weighted 
 average from other years (i.e. 1999 and 2001 for 2000, and 1999 and 
 2000 for 2001) and weighted average across all years;
 * note: we do this to avoid introducing endogeneity and reduce
 the amount of noise in the measure;
 sort unit year;
 for var mnrdva*: 
  gen X_1=X[_n-1] if unit==unit[_n-1] & year==year[_n-1]+1 \
  gen X_2=X[_n-2] if unit==unit[_n-2] & year==year[_n-2]+2;
 corr mnrdva1 mnrdva1_1 mnrdva2 mnrdva2_1 if reghs==1;
 corr mnrdva1* mnrdva2* if reghs==1;

 ** we use the measure that includes campus FE;
 egen tmp1=sum(enr9th) if mnrdva2~=. & reghs==1 & year~=2000, by(unit);
 egen tmp2=sum(enr9th*mnrdva2/tmp1) if tmp1~=. & tmp1~=0, by(unit);
 egen mnrdva_exog=max(tmp2), by(unit);
 replace mnrdva_exog=. if year~=2000;
 egen tmp3=sum(enr9th) if mnrdva2~=. & reghs==1 & year~=2001, by(unit);
 egen tmp4=sum(enr9th*mnrdva2/tmp3) if tmp3~=. & tmp3~=0, by(unit);
 egen tmp5=max(tmp4), by(unit);
 replace mnrdva_exog=tmp5 if year==2001;
 egen tmp6=sum(enr9th) if mnrdva2~=. & reghs==1, by(unit);
 egen tmp7=sum(enr9th*mnrdva2/tmp6) if tmp6~=. & tmp6~=0, by(unit);
 egen mnrdva=max(tmp7), by(unit);
 summ mnrdva [aw=enr9th], detail;
 summ mnrdva mnrdva_exog if year>1999;
 list if reghs==1 & mnrdva==. & year>1999;
 list if reghs==1 & mnrdva_exog==. & year>1999;
  label var mnrdva_exog "value-added avg. over other yrs"; 
  label var mnrdva "value-added avg. 1999-2001";
 drop mnrdva1* mnrdva2* tmp*;

** drop 1999 cohort;
 drop if year==1999;

 qui compress;
 sort unit year;
 save maganal_hs_schs, replace;

if ${n}==0{; 
!gzip allm599.dta;
!gzip allm500.dta;
!gzip allm501full.dta;
!gzip allm900full.dta;
!gzip allm901full.dta;
!gzip itbs*b.dta;
!gzip tap*.dta;
!gzip schl01.dta;
};

*** ADD APPLICATION SCHOOLS TO SCHOOL-LEVEL DATA SET ***;

use cunit year insch select sublotto outvar lottery 
 goodcode accept xxhisp xxmale using maganal_hs;

* make changes to sublottery variables motivated below due to
 differences in selection rates by race or sex within lotteries;
 descr sublotto;
 gen str8 tmp=sublotto;
 drop sublotto;
 rename tmp sublotto;
  label var sublotto "admin lottery code";
 replace sublotto="1390AE0H" if sublotto=="1390AE0" & xxhisp==1;
 replace sublotto="1640AA0M" if sublotto=="1640AA0" & xxmale==1;
 replace sublotto="1790AA0M" if sublotto=="1790AA0" & xxmale==1;
 * make sure each of these still have variation in whether selected;
 egen tmp=sd(select) if sublotto~="", by(sublotto);
 for any 1390AE0 1390AE0H 1640AA0 1640AA0M 1790AA0 1790AA0M:
  summ tmp if sublotto=="X";
 drop tmp;

* define needed variables;
 * # of applications: total, in lotteries, & in analysis lotteries;
 gen appl=1;
 rename lottery appl_l;
 gen appl_a=outvar;
 gen attend=insch if accept==1;
 gen attend_l=insch if sublotto~="" & select==1;
 gen attend_a=insch if sublotto~="" & select==1 & outvar==1;
 * analysis lotteries are those w/variation;
 egen numlot_a=tag(sublotto);
 replace numlot_a=. if sublotto==""|outvar==0;
 gen select_l=select if sublotto~="";
 gen select_a=select if sublotto~="" & outvar==1;

collapse (sum) appl appl_l appl_a numlot_a
 (mean) goodcode attend attend_l attend_a accept select_l select_a, 
  by(cunit year);
 count;
 summ;
 label var appl "# of applications";
 label var appl_l "# appl in lotteries";
 label var appl_a "# appl in lottery w/variation";
 label var numlot_a "# of lotteries w/variation";
 label var goodcode "share w/non-missing dc codes";
 label var attend "share of accepted appl that attend sch";
 label var attend_l "share of lottery winners that attend sch";
 label var attend_a "share of analysis lott winners that attend sch";
 label var accept "share accepted by any means";
 label var select_l "avg share selected in lotteries";
 label var select_a "avg share selected in analysis lotteries";

 rename cunit unit;
 capture label drop __MERGE;
 mmerge unit year using maganal_hs_schs, type(1:1) unmatched(both)
 ukeep(enr9th mn* pctsped pctblack pcthisp schlname schltype reghs);
 list if _merge==1;
 replace schlname="KING HIGH" if unit==1760;
 replace schltype="Not open yet" if unit==1760;
 replace reghs=0 if unit==1760;
 replace enr9th=0 if unit==1760;
 drop _merge;

** how many application schools are regular schools?;
 summ reghs if appl~=.;
 * only non-regular schools are Spalding and King;
 list unit schlname schltype if appl~=. & reghs==0; 

** position w/in distr of ability of entering class;
 count if reghs==1 & (mnrd8th==.|mnmth8th==.);
 * the set of schools for this includes the 70 regular non-charter high 
  schools plus charters;
 tab year if reghs==1;
 tab year if reghs==1 & schltype~="Charter";
 tab year if appl~=. & reghs==1;
 summ mnrd8th mnmth8th if reghs==1;
 gen mncomp8th=(mnrd8th+mnmth8th)/2 if reghs==1;
  label var mncomp8th "mean composite 8th grade math & reading pctile";
 * standardize to have mean 0 and standard deviation of 1;
 egen tmp1=sum(enr9th) if reghs==1, by(year);
 egen tmp2=sum(mncomp8th*enr9th/tmp1) if reghs==1, by(year);
 egen tmp3=sum(enr9th*(mncomp8th-tmp2)^2) if reghs==1, by(year);
 replace tmp3=(tmp3/(tmp1-1))^.5;
 gen ach_norm=(mncomp8th-tmp2)/tmp3 if reghs==1;
 summ ach_norm [aw=enr9th], detail;
 * because this is skewed, recenter around the median;
 xtile tmp4=ach_norm [aw=enr9th] if year==2000, nq(2);
 xtile tmp5=ach_norm [aw=enr9th] if year==2001, nq(2);
 replace tmp4=tmp5 if year==2001;
 tabstat ach_norm, by(tmp4);
 egen tmp6=max(ach_norm) if tmp4==1, by(year);
 egen tmp7=max(tmp6), by(year);
 tab tmp7 year;
 replace ach_norm=ach_norm-tmp7;
 summ ach_norm [aw=enr9th], detail;
 drop tmp*;
   label var ach_norm "std dev w/in distr of entering peer ach";

** standardized percentile w/in distr. of value-added;
 * use measure that is constant across years;
 egen tmp1=sum(enr9th) if reghs==1 & mnrdva~=., by(year);
 egen tmp2=sum(mnrdva*enr9th/tmp1) if reghs==1, by(year);
 egen tmp3=sum(enr9th*(mnrdva-tmp2)^2) if reghs==1, by(year);
 replace tmp3=(tmp3/(tmp1-1))^.5;
 gen va_norm=(mnrdva-tmp2)/tmp3 if reghs==1;
 summ va_norm [aw=enr9th], detail;
 xtile tmp4=va_norm [aw=enr9th] if year==2000, nq(2);
 xtile tmp5=va_norm [aw=enr9th] if year==2001, nq(2);
 replace tmp4=tmp5 if year==2001;
 tabstat va_norm, by(tmp4);
 egen tmp6=max(va_norm) if tmp4==1, by(year);
 egen tmp7=max(tmp6), by(year);
 tab tmp7 year;
 replace va_norm=va_norm-tmp7;
 summ va_norm [aw=enr9th], detail;
 drop tmp*;
   label var va_norm "std dev w/in distr of value added (mnrdva)";

** add fraction opting in;
 if ${n}==1{; global src="c:\projects\magnet schools\data\"; };
 capture label drop __MERGE;
 mmerge unit using "${src}schselectivity", type(n:1) unmatched(master)
  ukeep(mnotaa);
 if ${n}==0{; !gzip schselectivity.dta; };

** add fraction testing at or above norms on TAPS;
 if ${n}==0{; !gzip -d tap19912002.dta.gz; };
 if ${n}==1{; global src="e:\data\school_level\tests\"; }; 
 capture label drop __MERGE;
 mmerge unit year using "${src}tap19912002.dta", type(n:n) 
  unmatched(master) uif(subject=="read") ukeep(subject pnorms);
 if ${n}==0{; !gzip tap19912002.dta; };
 sort unit year;
 list unit schlname year if unit<2000 & _merge==1 & 
  (unit~=unit[_n-1]|year~=year[_n-1]);
 summ pnorms;
 replace pnorms=pnorms/100;

** add teacher quality index;
 if ${n}==0{; !gzip -d tchrs99.dta.gz; };
 if ${n}==1{; global src="c:\projects\magnet schools\data\"; }; 
 capture label drop __MERGE;
 mmerge unit using "${src}tchrs99.dta", type(n:1)
  unmatched(master) ukeep(univmeas97 scrtsub) urename(univmeas97 univmeas);
 if ${n}==0{; !gzip tchrs99.dta; };
 sort unit year;
 list unit schlname year if unit<2000 & _merge==1 &
  (unit~=unit[_n-1]|year~=year[_n-1]);
 corr univmeas scrtsub if reghs==1;

 * create standardized percentile w/in distr. of teacher quality;
 egen tmp1=sum(enr9th) if reghs==1 & univmeas~=., by(year);
 egen tmp2=sum(univmeas*enr9th/tmp1) if reghs==1, by(year);
 egen tmp3=sum(enr9th*(univmeas-tmp2)^2) if reghs==1, by(year);
 replace tmp3=(tmp3/(tmp1-1))^.5;
 summ tmp2 tmp3 if reghs==1;
 gen univnorm=(univmeas-tmp2)/tmp3 if reghs==1;
 summ univnorm [aw=enr9th], detail;
 xtile tmp4=univnorm [aw=enr9th] if year==2000, nq(2);
 xtile tmp5=univnorm [aw=enr9th] if year==2001, nq(2);
 replace tmp4=tmp5 if year==2001;
 tabstat univnorm, by(tmp4);
 egen tmp6=max(univnorm) if tmp4==1, by(year);
 egen tmp7=max(tmp6), by(year);
 tab tmp7 year;
 replace univnorm=univnorm-tmp7;
 summ univnorm [aw=enr9th], detail;
 drop tmp*;
   label var univnorm "std dev w/in distr of tchr quality";

drop _merge;
qui compress;
save maganal_hs_schs, replace;

*** SCHOOL-LEVEL SUMMARY STATISTICS ***;

use maganal_hs_schs;

** what share of 9th grade enrollment is in non-regular schools?;
 * note: this includes any school with <=10 9th graders;
 tab schltype if reghs==0 [aw=enr9th], miss;
 sort unit;
 count if unit~=unit[_n-1] & reghs==0;
 egen tmp1=sum(enr9th), by(year);
 egen tmp2=sum(enr9th*(reghs==0)/tmp1), by(year);
 tabstat tmp2, by(year);

** what share of enrollment is in charters?;
 tab schltype if reghs==1, miss;
 count if appl~=. & schltype=="Charter";
 tab year reghs if schltype=="Charter";
 egen tmp3=sum(enr9th*(schltype=="Charter")*reghs/tmp1), by(year);
 tabstat tmp3, by(year);

** what share of enrollment is in our refined sample of appl schools?;
 gen tmp4=(appl~=.);
 replace tmp4=0 if (unit==1760|unit==1650)|goodcode<0.95;
 * these only appear in one year;
 for num 1060 1440 1450 1740 1500 1090 1810: replace tmp4=0 if unit==X;
 tab year if tmp4==1;
 sort unit tmp4;
 count if unit~=unit[_n+1] & tmp4==1;
 egen tmp5=sum(enr9th*tmp4/tmp1), by(year);
 tabstat tmp5, by(year);

** what share of enrollment is in our analysis schools?;
 egen tmp6=max(appl_a>0 & appl_a~=.), by(unit year);
 replace tmp6=0 if unit==1650;
 tab year if tmp6==1;
 sort unit tmp6;
 count if unit~=unit[_n+1] & tmp6==1;
 egen tmp7=sum(enr9th*tmp6/tmp1), by(year);
 tabstat tmp7, by(year);
 * ratio of applicants to 9th grade enrollment in analysis schools;
 egen tmp8=sum(appl*tmp6), by(year);
 egen tmp9=sum(enr9th*tmp6), by(year);
 replace tmp8=tmp8/tmp9;
 tabstat tmp8, by(year);
 * ratio of analysis applicants to 9th grade enr in these schools;
 egen tmp10=sum(appl_a*tmp6), by(year);
 replace tmp10=tmp10/tmp9;
 tabstat tmp10, by(year);
 drop tmp*;

** only keep reg non-charter schools (other than 2 special appl schs);
 count if appl~=. & ((reghs==0 & unit~=1760 & unit~=1650)|
  schltype=="Charter");
 drop if (reghs==0 & unit~=1760 & unit~=1650)|schltype=="Charter";

*** CHARACTERISTICS OF ALL REGULAR AND APPLICATION HIGH SCHOOLS;
*** compiled in maganal_hs_schs.doc;

 sort unit;
 count if unit~=unit[_n-1];
 tab schltype year, miss;
 sort schlname year;
 list schlname unit year mncomp8th appl goodcode appl_l appl_a if 
  schltype=="Magnet"|schltype=="Magnet/Career Acad";
 list schlname unit year mncomp8th appl goodcode appl_l appl_a if 
  schltype=="College Prep" & unit~=4130;
 list schlname unit year mncomp8th appl goodcode appl_l appl_a if 
  schltype=="Career Academy";
 list schlname unit year mncomp8th appl goodcode appl_l appl_a if 
  schltype=="Military Academy";
 list schlname unit year mncomp8th appl goodcode appl_l appl_a if
  schltype=="General"|schltype=="Year Round"|unit==4130;
 list schlname unit year mncomp8th appl goodcode appl_l appl_a if 
  schltype=="Special Education"|schltype=="Not open yet";

** determine how our measures of "good" schools measure up with the
 system as a whole;

** create an indicator for our analysis schools;
gen byte culott=0;
for num 1210 1230 1320 1360 1380 1390 1420 1430 1520 1540 1580 1610
 1630 1640 1790 1820 1830 1860 1890: replace culott=1 if unit==X;
 label var culott "one of our analysis schools";

** high-achieving;
* finding top 5 analysis schools;
egen tmp0=rank(mncomp8th) if culott==1, field by(year);
tab unit year if tmp0<=5;
* look at weighted average of peer ability across years;
egen tmp1=sum(enr9th) if reghs==1, by(unit);
egen tmp2=sum(mncomp8th*enr9th/tmp1) if reghs==1, by(unit);
egen tmp3=rank(tmp2) if culott==1, field by(year);
tab unit year if tmp3<=5;
* find where this cut-point falls in the overall distribution;
egen tmp4=min(tmp2) if tmp3<=5, by(year);
egen tmp5=max(tmp4), by(year);
gen tmp6=(tmp2<=tmp5) if tmp2~=. & tmp5~=.;
summ tmp6;
summ tmp6 [aw=enr9th];
drop tmp*;

** value-added;
* finding top 5 analysis schools;
* note: this measure is constant across years by construction;
egen tmp1=rank(mnrdva) if culott==1, field by(year);
tab unit year if tmp1<=5;
* find where this cut-point falls in the overall distribution;
egen tmp2=min(mnrdva) if culott==1 & tmp1<=5, by(year);
egen tmp3=max(tmp2), by(year);
gen tmp4=mnrdva<=tmp3 if mnrdva~=. & tmp3~=. & reghs==1;
summ tmp4;
summ tmp4 [aw=enr9th];
drop tmp*;

** high-resource;
* finding top 5 analysis schools;
* note: this measure is constant across years b/c of availability;
egen tmp1=rank(univnorm) if culott==1, field by(year);
tab unit year if tmp1<=5;
* find where this cut-point falls in the overall distribution;
egen tmp2=min(univnorm) if culott==1 & tmp1<=5, by(year);
egen tmp3=max(tmp2), by(year);
gen tmp4=univnorm<=tmp3 if univnorm~=. & tmp3~=. & reghs==1;
summ tmp4;
summ tmp4 [aw=enr9th];
drop tmp*;

*** CHARACTERISTICS OF SCHOOLS IN LOTTERY SAMPLE;

* keep schools with variation in outcomes w/in lotteries;
 egen totappl_a=sum(appl_a), by(unit);
 tab culott if totappl_a>0 & totappl_a~=.;
 tab unit if culott==0 & totappl_a>0 & totappl_a~=.;
 tab culott if totappl_a==0|totappl_a==.;
 keep if totappl_a>0 & totappl_a~=.;
 gen pctmin=pctblack+pcthisp;

 disp "*** TABLE 1 ***";
 * weight by applicants included in the analysis;
 egen totappl=sum(appl), by(unit);
 egen totappl_l=sum(appl_l), by(unit);
 egen totnumlot=sum(numlot_a), by(unit);
 sort unit;
 replace schlname=schlname[_n-1] if unit==unit[_n-1] 
  & schlname~=schlname[_n-1];
 collapse (mean) ach_norm mncomp8th pnorms va_norm mnrdva univnorm
  scrtsub pctmin accept totnumlot totappl_a select* attend* [aw=appl_a],
  by(unit schlname);
 corr accept select*;
 corr attend*;
 corr accept attend;
 egen raccept=rank(accept) if unit~=1650;
 egen rattend=rank(attend) if unit~=1650, field;
 corr mncomp8th mnrdva accept attend;
 gen tmp=ach_norm*-1;
 sort tmp;
 list unit schlname mncomp8th mnrdva accept attend totnumlot totappl_a 
  raccept rattend ach_norm va_norm univnorm scrtsub pctmin pnorms;

drop _all;


*********************************************;  
*** Add Additional School-level Variables ***;
*********************************************;

use maganal_hs;

** add variables needed from school-level data set created above;

 * Fall yr 1 school;
 * adjust Dyett to match unit number in school-level file;
 gen tmpunit=unitF1;
 replace tmpunit=8070 if tmpunit==1600;
 capture label drop __MERGE;
 mmerge tmpunit year using maganal_hs_schs, type(n:1) unmatched(master) 
  missing(nomatch) umatch(unit year) 
  ukeep(mncomp8th ach_norm mnrdva va_norm univnorm)  
  urename(mncomp8th uF1comp8 \ ach_norm uF1ach8 \ 
   mnrdva uF1va8 \ va_norm uF1vanorm \ univnorm uF1univnorm);
  label var uF1comp8 "mean 8th gr composite scores for entrants";
  label var uF1ach8 "std. dev. from median achievement for entrants";
  label var uF1va8 "mean value added for entrants";
  label var uF1vanorm "std. dev. from median value added for entrants";
  label var uF1univnorm "std. dev. from median tchr quality";
 count if uF1univmeas~=. & uF1univnorm==.;
 tab unitF1 if _merge==1 & unitF1<2000;
 tab gradeF1 if _merge==1;
 * students with missing data were generally retained, so not in h.s.;
 drop tmpunit;

 * choice school;
 capture label drop __MERGE;
 mmerge cunit year using maganal_hs_schs, type(n:1) unmatched(master) 
  missing(nomatch) umatch(unit year) 
  ukeep(mncomp8th ach_norm mnrdva va_norm univnorm)  
  urename(mncomp8th cucomp8 \ ach_norm cuach8 \ mnrdva cuva8 \ 
   va_norm cuvanorm \ univnorm cuunivnorm);
  label var cucomp8 "mean 8th gr composite scores for entrants";
  label var cuach8 "std. dev. from median achievement for entrants";
  label var cuva8 "mean value added for entrants";
  label var cuvanorm "std. dev. from median value added for entrants";
  label var cuunivnorm "std. dev. from median tchr quality";
 count if cuunivmeas~=. & cuunivnorm==.;
 tab cuname if cuunivmeas~=. & cuunivnorm==.;
 tab cunit if _merge==1;

 * attendance area school;
 * note: be careful using these-- seem to have been udpated for those
   who gained access through lotteries.  Should be useful for capturing
   options of the losers either way.  We drop these variables after
   recalculating AA quality using only losers below.;
 gen tmpunit=aunitS1;
 replace tmpunit=8070 if tmpunit==1600;
 capture label drop __MERGE;
 mmerge tmpunit year using maganal_hs_schs, type(n:1) unmatched(master) 
  missing(nomatch) umatch(unit year) 
  ukeep(mncomp8th ach_norm mnrdva va_norm univnorm)  
  urename(mncomp8th aaS1comp8 \ ach_norm aaS1ach8 \ mnrdva aaS1va8 \ 
   va_norm aaS1vanorm \ univnorm aaS1univnorm);
  label var aaS1comp8 "mean 8th gr composite scores for entrants";
  label var aaS1ach8 "std. dev. from median achievement for entrants";
  label var aaS1va8 "mean value added for entrants";
  label var aaS1vanorm "std. dev. from median value added for entrants";
  label var aaS1univnorm "std. dev. from median tchr quality";
 tab aunitS1 if _merge==1 & aunitS1<2000;
 drop tmpunit;

** quality of inside option;
 
 * use quality of Fall schools for similarly able students attending 
  the same 8th grade school (or living in the same tract);
 * identify quintiles of 8th grade achievement in this sample;
 xtile tmp1=iscore if year==2000, nq(5);
 xtile tmp2=iscore if year==2001, nq(5);
 replace tmp1=tmp2 if year==2001;
 egen tmp3=max(select), by(newid);
 replace tmp3=. if tmp3==1|enrollF1==0;
 replace tmp3=1 if tmp3==0;
 tab tmp3, miss;
 * same 8th grade campus;
 egen inscomp8=mean(uF1comp8*tmp3), by(tmp1 unitS0 year);
 egen insva8=mean(uF1va8*tmp3), by(tmp1 unitS0 year);
 egen insach8=mean(uF1ach8*tmp3), by(tmp1 unitS0 year);
 egen insvanorm=mean(uF1vanorm*tmp3), by(tmp1 unitS0 year);
 egen insunivnorm=mean(uF1univnorm*tmp3), by(tmp1 unitS0 year);
 egen insmtou9=mean(mtou9*tmp3), by(tmp1 unitS0 year);
 egen insmfromu8=mean(mfromu8*tmp3), by(tmp1 unitS0 year);
 
 * same 9th grade tract;
 gen tmp4=tmp3;
 replace tmp4=. if tractF1==.;
 egen comp=mean(uF1comp8*tmp4), by(tmp1 tractF1 year);
 egen va=mean(uF1va8*tmp4), by(tmp1 tractF1 year);
 egen ach=mean(uF1ach8*tmp4), by(tmp1 tractF1 year);
 egen vanorm=mean(uF1vanorm*tmp4), by(tmp1 tractF1 year);
 egen univnorm=mean(uF1univnorm*tmp4), by(tmp1 tractF1 year);
 egen tmtou9=mean(mtou9*tmp4), by(tmp1 tractF1 year);
 egen tmfromu8=mean(mfromu8*tmp4), by(tmp1 tractF1 year);
 replace inscomp8=comp if inscomp8==.;
 replace insva8=va if insva8==.;
 replace insach8=ach if insach8==.;
 replace insvanorm=vanorm if insvanorm==.;
 replace insunivnorm=univnorm if insunivnorm==.;
 replace insmtou9=tmtou9 if insmtou9==.;
 replace insmfromu8=tmfromu8 if insmfromu8==.;
 
 for var inscomp8 insva8 insach8 insvanorm insunivnorm insmtou9 insmfromu8: 
  count if X==. & enrollF1==1;
 summ inscomp8 insva8 insach8 insvanorm insunivnorm insmtou9 insmfromu8 
  uF1comp8 uF1va8 uF1ach8 uF1vanorm uF1univnorm if inscomp8~=.;
 corr inscomp8 uF1comp8;
 corr insva8 uF1va8;
 corr insunivnorm uF1univnorm;
  label var inscomp8 "mean achievement of entrants at inside option";
  label var insva8 "mean value added at inside option";
  label var insach8 "normalized peer ach at inside option";
  label var insvanorm "normalized value added at inside option";
  label var insunivnorm "normalized tchr quality at inside option";
  label var insmtou9 "% from stud's unitS0 at unitF1 at inside option";
  label var insmfromu8 "% in unitF1 from unitS0 at inside option";

 drop tmp2 tmp4 va comp ach vanorm univnorm tmtou9 tmfromu8;

** quality of second-best option based on lottery losers;
 
 * compare to students of similar achievement levels applying unsuccessfully
  to same choice unit;
 * note: this will vary by lottery for the same student;
 gen tmp2=1 if select==0 & enrollF1==1;
 egen sbcomp8=mean(uF1comp8*tmp2), by(tmp1 cunit year);
 egen sbva8=mean(uF1va8*tmp2), by(tmp1 cunit year);
 egen sbach8=mean(uF1ach8*tmp2), by(tmp1 cunit year);
 egen sbvanorm=mean(uF1vanorm*tmp2), by(tmp1 cunit year);
 egen sbunivnorm=mean(uF1univnorm*tmp2), by(tmp1 cunit year);
 for var sbcomp8 sbva8 sbach8 sbvanorm sbunivnorm: 
  count if X==. & enrollF1==1;
 tab outvar if sbcomp8==.;
 corr sb* ins*;
  label var sbcomp8 "mean achievement of entrants at 2nd-best alt";
  label var sbva8 "mean value added at 2nd-best alt";
  label var sbach8 "normalized peer ach at 2nd-best alt";
  label var sbvanorm "normalized value added at 2nd-best alt";
  label var sbunivnorm "normalized tchr quality at 2nd-best alt";
 drop tmp*;

** quality of AA school derived from AA for losers;

 * exclude students who are successful in any application;
 egen tmp1=max(accept), by(newid);
 replace tmp1=. if tmp1==1|enrollF1==0;
 replace tmp1=1 if tmp1==0;
 tab tmp1;
 * same 8th grade campus;
 egen aacomp8=mean(aaS1comp8*tmp1), by(unitS0 year);
 egen aava8=mean(aaS1va8*tmp1), by(unitS0 year);
 egen aaach8=mean(aaS1ach8*tmp1), by(unitS0 year);
 egen aavanorm=mean(aaS1vanorm*tmp1), by(unitS0 year);
 egen aaunivnorm=mean(aaS1univnorm*tmp1), by(unitS0 year);
 
 * use same 9th grade tract instead if information exists;
 gen tmp2=tmp1;
 replace tmp2=. if tractF1==.;
 egen comp=mean(aaS1comp8*tmp2), by(tractF1 year);
 egen va=mean(aaS1va8*tmp2), by(tractF1 year);
 egen ach=mean(aaS1ach8*tmp2), by(tractF1 year);
 egen vanorm=mean(aaS1vanorm*tmp2), by(tractF1 year);
 egen univnorm=mean(aaS1univnorm*tmp2), by(tractF1 year);
 replace aacomp8=comp if comp~=.;
 replace aava8=va if va~=.;
 replace aaach8=ach if ach~=.;
 replace aavanorm=vanorm if vanorm~=.;
 replace aaunivnorm=univnorm if univnorm~=.;
 for var aacomp8 aava8 aaach8 aavanorm aaunivnorm: 
  count if X==. & enrollF1==1;
 summ aacomp8 aava8 aaach8 aavanorm aaunivnorm
  uF1comp8 uF1va8 uF1ach8 uF1vanorm uF1univnorm if aacomp8~=.;
 corr aacomp8 uF1comp8;
 corr aava8 uF1va8;
 corr aaunivnorm uF1univnorm;
  label var aacomp8 "mean achievement of entrants at AA";
  label var aava8 "mean value added at AA";
  label var aaach8 "normalized peer ach at AA";
  label var aavanorm "normalized value added at AA";
  label var aaunivnorm "noramlized tchr quality at AA";
 drop tmp* va comp ach vanorm univnorm aaS1comp8 aaS1va* 
  aaS1univ aunitS1;

** classify Fall schools;

 * Note: Important notes from Jack Harnedy. Explains why test scores at 
  Chi Ag and Von Steuben are so high.  Ag School uses stanine 5 R-M.  
  Von Steuben has 2 programs.  The regular lottery program with no criteria 
  which takes 80% of the kids and the gifted scholars program which takes 100
  kids.  The gifted scholars program requires stanine 7 R-M and a written
  essay.  Both programs adhere to racial guidelines (that is, they have 
  lotteries).  Curie has no criteria for their lotteries, and is also
  a neighborhood school;

 * attended a choice school;
 gen byte cschF1=(aaF1==0) if enrollF1==1;
  label var cschF1 "attended school other than AA";

 * attended one of our analysis schools;
 gen byte lottF1=0 if enrollF1==1;
 for num 1210 1230 1320 1360 1380 1390 1420 1430 1520 1540 1580 1610
  1630 1640 1790 1820 1830 1860 1890: 
  replace lottF1=1 if unitF1==X & enrollF1==1;
   label var lottF1 "attended one of our analysis schools";
 tab lottF1 year, col;
 summ cschF1 select accept insch if lottF1==1;

 * attended one of our analysis magnet schools;
 gen byte magF1=0 if enrollF1==1;
 replace uF1name="CHICAGO AG SC HIGH" if uF1name=="CHICAGO AGR SCI HIGH"; 
 tab uF1name if unitF1==1610|unitF1==1790|unitF1==1820;
 for num 1610 1790 1820: replace magF1=1 if unitF1==X & enrollF1==1;
  label var magF1 "analysis magnet school";
 tab magF1 year, col;
 summ cschF1 if magF1==1;
 * Curie is also an attendance area school;
 tab unitF1 if magF1==1 & cschF1==0;
 
 * attended a good/bad school;
 * classified by identifying the top 5 schools in our analysis sample--
   we showed above that these fall in the top quartile of all schools
   (in a student-weighted distribution);
 * note: if information is missing, is not a regular h.s. so not in top
   quartile.  Make sure schools always classified in the same way;
 replace uF1name="WELLS HIGH" if uF1name=="WELLS COMMTY ACAD HS";
 egen tmp1=max(uF1comp8), by(unitF1);
 summ tmp1 if (unitF1==1390|unitF1==1420|unitF1==1610|unitF1==1790|
  unitF1==1820);
 gen tmp2=(uF1comp8>=.51&uF1comp8~=.) if enrollF1==1;
 egen byte gdF1=max(tmp2) if enrollF1==1, by(unitF1);
 gen byte badF1=1-gdF1;
 tab unitF1 year if gdF1==1 & lottF1==1;
  label var gdF1 "school in top 25% in peer entering ach";
  label var badF1 "school NOT in top 25% in peer entering ach";
 drop tmp*;

 * attended a high and low value-added school;
 * classified by identifying the top 5 schools in our analysis sample--
   we showed above that these also fall in the top quartile of all schools 
  (in a student-weighted distribution);
 * we do not place those with missing information in either group;
 summ uF1va8 if unitF1==1380|unitF1==1420|unitF1==1430|unitF1==1610|
  unitF1==1860;
 gen tmp=(uF1va8>=.0028) if uF1va8~=. & enrollF1==1;
 egen byte hivaF1=max(tmp) if enrollF1==1, by(unitF1);
 gen byte lovaF1=1-hivaF1;
 tab unitF1 if hivaF1==1 & lottF1==1;
 tab unitF1 if hivaF1==. & lottF1==1;
  label var hivaF1 "high value-added school";
  label var lovaF1 "low value-added school";
 tabstat lovaF1 hivaF1, by(gdF1);
 drop tmp;

 * attended a high resource school;
 corr uF1univmeas uF1univ1 uF1ppe uF1psped uF1ptr uF1mstpls
  uF1scrths uF1scrtsub uF1tcrt uF1educmjr;
 summ uF1univnorm if unitF1==1210|unitF1==1430|unitF1==1540|
  unitF1==1580|unitF1==1610;
 gen tmp=(uF1univnorm>=.75) if uF1univnorm~=. & enrollF1==1;
 egen byte hirsF1=max(tmp) if enrollF1==1, by(unitF1);
 gen byte lorsF1=1-hirsF1;
 tab unitF1 if hirsF1==1 & lottF1==1;
 tab unitF1 if hirsF1==. & lottF1==.;
  label var hirsF1 "high avg univ quality for teachers";
  label var lorsF1 "low avg univ quality for teachers";
 drop tmp;

 summ cschF1 lottF1 magF1 gdF1 badF1 hivaF1 lovaF1 hirsF1 lorsF1;
 descr cschF1 lottF1 magF1 gdF1 badF1 hivaF1 lovaF1 hirsF1 lorsF1;

*** classify choice schools ***;

 * one of our analysis schools;
 gen byte culott=0;
 for num 1210 1230 1320 1360 1380 1390 1420 1430 1520 1540 1580 1610
  1630 1640 1790 1820 1830 1860 1890: replace culott=1 if cunit==X;
   label var culott "one of our analysis schools";
 
 * magnet school;
 tab cunit if cu_hsmag==1;
 rename cu_hsmag cumag;
  label var cumag "magnet school";

 * good/bad, high/low value-added, & high/low resource choice schools;
 gen tmp1=(cucomp8>=.51) if cucomp8~=.;
 egen byte cugd=max(tmp1), by(cunit);
 tab cunit if culott==1 & cugd==1;
 gen byte cubad=1-cugd;
  label var cugd "sch in top 25% in peer ach";
  label var cubad "sch NOT in top 25% in peer ach";
 gen tmp2=(cuva8>=.0028) if cuva8~=.;
 egen cuhiva=max(tmp2), by(cunit);
 tab cunit if culott==1 & cuhiva==1;
 gen byte culova=1-cuhiva;
  label var cuhiva "high value-added sch";
  label var culova "low value-added sch";
 gen tmp3=(cuunivnorm>=.75) if cuunivnorm~=.;
 egen cuhirs=max(tmp3), by(cunit);
 tab cunit if culott==1 & cuhirs==1;
 gen byte culors=1-cuhirs;
  label var cuhirs "high % teachers from top tier univ";
  label var culors "low % teachers from top tier univ";
 drop tmp*;

 * popular school based on acceptance rates;
 * find top 5 among our analysis schools;
 egen tmp1=mean(accept) if goodcode==1, by(cunit);
 egen cumnacc=max(tmp1), by(cunit);
  label var cumnacc "avg % accepted by any means";
 sort cunit;
 egen tmp2=rank(cumnacc) if culott==1 & cunit~=cunit[_n-1];
 tab cunit if tmp2<=5;
 summ cumnacc if tmp2<=5;
 summ cumnacc if tmp2>5 & tmp2~=.;
 * defined as popular if below 13%;
 gen byte cuhipop=(cumnacc<=.13) if cumnacc~=.;
 tab cunit if culott==1 & cuhipop==1;
 gen byte culopop=1-cuhipop;
  label var cuhipop "popular school- low % accepted";
  label var culopop "less popular school- high % accepted";
 drop tmp*;

 * popular school based on enrollment among accepted;
 * find top 5 among our analysis schools;
 egen tmp1=mean(insch) if goodcode==1 & accept==1, by(cunit);
 egen cumnenr=max(tmp1), by(cunit);
  label var cumnenr "avg % enrolling among accepted";
 sort cunit;
 egen tmp2=rank(cumnenr) if culott==1 & cunit~=cunit[_n-1], field;
 tab cunit if tmp2<=5;
 summ cumnenr if tmp2<=5;
 summ cumnenr if tmp2>5 & tmp2~=.;
 * note: do not create separate indicator for high popularity on this
  measure since overlaps perfectly with the other measure;
 drop tmp*;

 summ culott cumag cugd cubad cuhiva culova cuhirs culors cuhipop culopop;
 descr culott cumag cugd cubad cuhiva culova cuhirs culors cuhipop culopop;

 * where did kids who applied to magnet/good schools end up going?;
 replace uF1name="PROSSER CAREER ACAD" if uF1name=="PROSSER CAREER AC HS";
 replace uF1name="SIMEON CAREER ACAD H" if uF1name=="SIMEON VOC HIGH";
 egen tmp1=count(cunit) if enrollF1==1;
 egen tmp2=count(cunit) if enrollF1==1, by(unitF1);
 replace tmp2=tmp2/tmp1;
 tab uF1name if tmp2>.025 & tmp2~=., miss;
 drop tmp*;
 egen tmp1=sum(cumag) if enrollF1==1;
 egen tmp2=sum(cumag) if enrollF1==1, by(unitF1);
 replace tmp2=tmp2/tmp1;
 tab uF1name if cumag==1 & tmp2>.025 & tmp2~=., miss;
 drop tmp*;
 egen tmp1=sum(cugd==1&cumag==0) if enrollF1==1;
 egen tmp2=sum(cugd==1&cumag==0) if enrollF1==1, by(unitF1);
 replace tmp2=tmp2/tmp1;
 tab uF1name if cugd==1&cumag==0 & tmp2>.025 & tmp2~=., miss;
 drop tmp*;

*** classify inside option and AA schools ***;

 * Quality of inside option;
   gen byte ins_gd=(inscomp8>=.51) if inscomp8~=.;
   gen byte ins_bad=1-ins_gd;
    label var ins_bad "low achievement at inside option";
    label var ins_gd "high achievement at inside option";
   gen byte ins_hiva=(insva8>=.0028) if insva8~=.;
   gen byte ins_lova=1-ins_hiva;
    label var ins_lova "low value-added at inside option";
    label var ins_hiva "high value-added at inside option";
   gen byte ins_hirs=(insunivnorm>=.75) if insunivnorm~=.;
   gen byte ins_lors=1-ins_hirs;
    label var ins_hirs "high tchr quality at inside option";
    label var ins_lors "low tchr quality at inside option";

 * Quality of 2nd-best alternative;
   gen byte sb_gd=(sbcomp8>=.51) if sbcomp8~=.;
   gen byte sb_bad=1-sb_gd;
    label var sb_bad "low achievement at 2nd-best alt";
    label var sb_gd "high achievement at 2nd-best alt";
   gen byte sb_hiva=(sbva8>=.0028) if sbva8~=.;
   gen byte sb_lova=1-sb_hiva;
    label var sb_lova "low value-added at 2nd-best alt";
    label var sb_hiva "high value-added at 2nd-best alt";
   gen byte sb_hirs=(sbunivnorm>=.75) if sbunivnorm~=.;
   gen byte sb_lors=1-sb_hirs;
    label var sb_hirs "high tchr quality at 2nd-best alt";
    label var sb_lors "low tchr quality at 2nd-best alt";

 * Quality of AA;
   gen byte aa_gd=(aacomp8>=.51) if aacomp8~=.;
   gen byte aa_bad=1-aa_gd;
    label var aa_bad "low achievement at AA";
    label var aa_gd "high achievement at AA";
   gen byte aa_hiva=(aava8>=.0028) if aava8~=.;
   gen byte aa_lova=1-aa_hiva;
    label var aa_lova "low value-added at AA";
    label var aa_hiva "high value-added at AA";
   gen byte aa_hirs=(aaunivnorm>=.75) if aaunivnorm~=.;
   gen byte aa_lors=1-aa_hirs;
    label var aa_hirs "high tchr quality at AA";
    label var aa_lors "low tchr quality at AA";


*******************************************;  
*** Keep Refined Sample of Applications ***;
*******************************************;

** keep subset of all applications for descriptive statistics;

 * drop the two schools that were not regular schools in 2000 or 2001;
 tab cuname year if cunit==1760|cunit==1650;
 drop if cunit==1760|cunit==1650;

 * drop selective schools;
 summ cu_* cumag;
 tab cunit if cu_hstst==1;
 tabstat cu_hstst, by(year);
 drop if cu_hstst==1;
 drop cu_hstst;

 * drop remaining schools that have <95% non-missing disposition codes;
 summ cu_* cumag if goodcode==0;
 egen tmp=mean(goodcode), by(cunit year);
 summ tmp, detail;
 tab cuname year if tmp<0.95;
 tabstat tmp outvar if tmp<0.95, by(cuname);
 drop if tmp<0.95;
 drop tmp;
 count if goodcode==0;
 tab cunit year if goodcode==0; 
 drop goodcode;

 * schools in our refined sample;
 tab year;
 tab cuname year;
 tab uF1name if gdF1==1;

** create # of applications and acceptances to this refined set;

 descr napp*;
 rename napp nappvalid;
 egen byte napp=count(cunit), by(newid);
  label var napp "# appl to refined set of schools";

 egen byte nacc=sum(accept), by(newid);
 gen byte dacc=(nacc>=1&nacc~=.);
  label var nacc "# acceptances to refined set of schools";
  label var dacc "accepted at school in our refined set";


********************************;
*** Identify Analysis Sample ***;
********************************;

** Identify lotteries with variation in outcomes;

 * which lotteries with variation are very small?;
  egen tmp=sum(lottery) if sublotto~="", by(sublotto);
  tab sublotto year if outvar==1 & tmp<10;
  drop tmp;

 * indicators for applications and lotteries in analysis sample;
  gen byte sampleS=(lottery==1 & outvar==1);
   label var sampleS "application is in analysis sample";
  egen byte taglot=tag(sublotto);
  replace taglot=0 if sublotto==""; 
   label var taglot "marker for each sublottery";
  gen byte sampleL=taglot if outvar==1;
   label var sampleL "marker for each sublottery in analysis sample";
  replace sampleL=0 if sampleL==.;
  summ sampleS taglot sampleL;

 * information on inside options and AA by application school;
  for any comp8 ach8 va8 vanorm univnorm: corr insX sbX aaX;
  tabstat inscomp8 insach8 insva8 insvanorm insunivnorm 
   sbcomp8 sbach8 sbva8 sbvanorm sbunivnorm cuscrtsub if culott==1, by(cunit);
  tabstat inscomp8 insach8 insva8 insvanorm insunivnorm 
   sbcomp8 sbach8 sbva8 sbvanorm sbunivnorm cuscrtsub 
   if culott==1 & sampleS==1, by(cunit);

** Identify lotteries where selection rates differ by race or gender;

 * Indicator of race-sex variation within the lottery;
  gen tmpsx=0 if sx=="M";
  replace tmpsx=1 if sx=="F";
  gen tmprcsx=(rc*10)+tmpsx;
  egen tmpsd=sd(tmprcsx), by(sublotto);
  gen byte rcsxvar=(tmpsd~=0&tmpsd~=.) if lottery==1;
  summ rcsxvar if taglot==1;
  summ rcsxvar if sampleS==1;
  summ rcsxvar if sampleL==1;
   label var rcsxvar "race-sex variation w/in sublottery";
  drop tmp*;

** Finding lotteries with significantly different selection rates;

  * first using probit-- although we have a small numbers issue;
  * making sure identify same problem cases regardless of method;
  for var xxmale xxblk xxwhi xxhisp xxnatam xxasian: getp_p X;
  gen diff5pct=(p_xxmale<=.05);
  gen diff10pct=(p_xxmale<=.10);
  for any blk whi hisp natam asian: replace diff5pct=1 if p_xxX<=.05 \
   replace diff10pct=1 if p_xxX<=.10;
  tabstat p_* if diff5pct==1, by(sublotto);
  tabstat p_* if diff10pct==1, by(sublotto);
  drop p_* diff5pct diff10pct;

  for var xxmale xxblk xxwhi xxhisp xxnatam xxasian: getp_f X;
  gen diff5pct=(p_xxmale<=.05);
  gen diff10pct=(p_xxmale<=.10);
  for any blk whi hisp natam asian: replace diff5pct=1 if p_xxX<=.05 \
   replace diff10pct=1 if p_xxX<=.10;
  for var diff*: summ rcsxvar if X==1 \ tab sublotto if X==1;
  tabstat p_* if diff10pct==1, by(sublotto);
  drop diff5pct diff10pct;
 
 * For one lottery (1390AE0) there were a few asian and hispanic students 
  mixed into what appears to be a black lottery;
  summ xx* if sublotto=="1390AE0";
  for any blk asian hisp: summ select if xxX==1 & sublotto=="1390AE0";
  gen tmp1=(sublotto=="1390AE0" & xxblk==0);
  egen tmp2=max(tmp1), by(newid);
  sort newid;
  list newid xxblk xxasian xxhisp xxwhi sublotto if tmp2==1;
  * pull Hispanics out into another lottery;
  descr sublotto;
  gen str8 tmp3=sublotto;
  drop sublotto;
  rename tmp3 sublotto;
   label var sublotto "admin lottery code";
  replace sublotto="1390AE0H" if sublotto=="1390AE0" & xxhisp==1;
  replace rcsxvar=0 if sublotto=="1390AE0H";
  * will fix taglot and sampleL below;
  drop tmp*;

 * For 2 sublotteries (1640AA0 1790AA0) males and females are mixed and there 
 are different selection rates across gender;
  summ xx* if sublotto=="1640AA0";
  for any male female: summ select if xxX==1 & sublotto=="1640AA0";
  summ xx* if sublotto=="1790AA0";
  for any male female: summ select if xxX==1 & sublotto=="1790AA0";
  * fix this by breaking each lottery into 2 separate lotteries; 
  replace sublotto="1640AA0M" if sublotto=="1640AA0" & xxmale==1;
  replace sublotto="1640AA0F" if sublotto=="1640AA0" & xxmale==0;
  replace sublotto="1790AA0M" if sublotto=="1790AA0" & xxmale==1;
  replace sublotto="1790AA0F" if sublotto=="1790AA0" & xxmale==0;

  * adjust variables affected by this change;
   for any "1640AA0M" "1640AA0F" "1790AA0M" "1790AA0F": 
    count if sublotto=="X" \ replace rcsxvar=0 if sublotto=="X";
   drop taglot;
   egen taglot=tag(sublotto);
   replace taglot=0 if sublotto=="";
    label var taglot "marker for each sublottery";
   sort sublotto;
   replace sampleL=0 if sublotto=="1390AE0"|sublotto=="1390AE0H"|
    sublotto=="1640AA0M"|sublotto=="1640AA0F"|
    sublotto=="1790AA0M"|sublotto=="1790AA0F";
   replace sampleL=1 if sublotto~=sublotto[_n-1] & (sublotto=="1390AE0"|
    sublotto=="1390AE0H"|sublotto=="1640AA0M"|sublotto=="1640AA0F"|
    sublotto=="1790AA0M"|sublotto=="1790AA0F");

 tabstat xxwhi xxblk xxhis xxas xxnat xxmale if rcsxvar==1 & sampleS==1, 
  by(sublotto);
 drop rcsxvar p_*;

** Create some additional sublottery variables;

 * create variable with separate number for each lottery;
 egen subgroup=group(sublotto) if sampleS==1;
 summ subgroup;
  label var subgroup "separate # identifies each analysis lottery";
 
 * Average selection rate by lottery;
  egen mnselect=mean(select) if lottery==1, by(sublotto);
   label var mnselect "% selected within sublottery";
  tab mnselect if outvar==0;
  summ mnselect if outvar==1, detail;

 * Total number of participants and number by outcome within lottery;
  egen int nt=sum(lottery) if lottery==1, by(sublotto);
  egen int nr=sum(reject) if lottery==1, by(sublotto);
  egen int ns=sum(select) if lottery==1, by(sublotto);
   label var nt "number of students w/in sublottery";
   label var nr "number rejected w/in sublottery";
   label var ns "number selected w/in sublottery";
  gen tmp=(ns+nr)/nt;
  summ tmp;
  drop tmp;

 * Outcome variables based on analysis sample;
  egen byte nlot=sum(lottery*sampleS), by(newid);
  gen byte dlot=(nlot>=1);
  egen byte nsel=sum(select*sampleS), by(newid);
  gen byte dsel=(nsel>=1);
   label var nlot "# of our analysis lotteries student is in";
   label var dlot "student involved in an analysis lottery";
   label var nsel "# of analysis lotteries selected in";
   label var dsel "selected in an analysis lottery";

 * indicator for 1 obs per student;
  * in full sample;
  gen tmp=sampleS*-1;
  sort newid tmp;
  gen byte tagkid=0;
  replace tagkid=1 if newid~=newid[_n-1];
   label var tagkid "indicator for 1 obs/stud in full sample";
  * in analysis sample;
  gen byte tagkidlot=tagkid;
  replace tagkidlot=0 if sampleS==0;
   label var tagkidlot "indicator for 1 obs/stud in analysis sample";
  count if tagkid==1;
  count if tagkidlot==1;
  * check these variables;
  sort newid sampleS;
  count if newid~=newid[_n-1];
  count if (newid~=newid[_n-1]&sampleS==1)|(newid==newid[_n-1]&sampleS==1&
   sampleS[_n-1]==0);
  drop tmp;


***************************************************;
*** Create variables for heterogeneity analysis ***;
***************************************************;

 * Number of other applications that were accepted;
   tab nacc if tagkid==1, miss;
   gen byte other_0=(nacc-select==0);
   gen byte other_1p=(nacc-select>=1);
   summ other_* if tagkid==1;
    label var other_0 "no other acceptances";
    label var other_1p "1 or more other acceptances";

 * Lottery competitiveness;
   summ mnselect, detail;
   summ mnselect if taglot==1, detail;
   gen byte ls_0010=(mnselect<.1) if mnselect~=.;
   gen byte ls_1099=(mnselect>=.1) if mnselect~=.;
   summ mnselect if ls_1099==1;
   summ ls_*;
    label var ls_0010 "<10% selected";
    label var ls_1099 "10-99% selected";

 * Create indicator for prior achievement; 
  summ iscore if sampleS==1, detail;
  gen q1=iscore<=.25;
  gen q2=iscore>.25 & iscore<=.5;
  gen q3=iscore>.5 & iscore<=.75;
  gen q4=iscore>.75;
  gen q12=q1+q2;
  gen q34=q3+q4;
  summ q1 q2 q3 q4 q12 q34 if sampleS==1;
   label var q1 "prior achievement below 25th pctile";
   label var q2 "prior achievement 25-50th pctile";
   label var q3 "prior achievement 50-75th pctile";
   label var q4 "prior achievement 75th-100th pctile";
   label var q12 "prior achievement below 50th pctile";
   label var q34 "prior achievement above 50th pctile";

drop _merge;
qui compress;
order
newid sid year badmatch baddemog
tagkid tagkidlot sampleS sampleL dc rc sx gr
lottery outvar select reject accept napptot nappvalid napp nacc dacc 
other_0 other_1p nlot dlot nsel dsel
taglot sublotto subgroup mnselect ls_* nt nr ns
pri_* rdxilS0 mtxilS0 rdxil_1 mtxil_1 zz* iscore izz* q* yy* xx* nn* 
tractS0 latS0 longS0
unitS0 uS0* mtou9 mfromu8 cu*
insch dinsch enrollF1* retainF1 moveF1 dropF1 privF1 leftF1 gradeF1 tractF1 
unitF1 aaF1 cschF1 magF1 lottF1 gdF1 badF1 hivaF1 lovaF1 hirsF1 lorsF1
uF1* f_hs* ins* sb* aa*
enrollS1 gradeS1 unitS1 aS1* privS1 leftS1 dropS1
rdgeS1 rdxilS1 msrdxilS1 rdq1S1 rdq4S1 bioS1 msbioS1 wldS1 mswldS1 algS1 
msalgS1 algS1bot algS1top eng1S1 mseng1S1
mstranS1 gpaS1 mabsS1 tcrdS1 crd28S1 anyfS1 numfS1 crankS1 missoutS1
enrollS2 retainS2 gradeS2 unitS2 privS2 leftS2 dropS2
rdgeS2 rdxilS2 msrdxilS2 rdq1S2 rdq4S2 hisS2 mshisS2 geoS2 msgeoS2 eng2S2 
mseng2S2 
mstranS2 gpaS2 mabsS2 tcrdS2 crd28S2 anyfS2 numfS2 crankS2 missoutS2
enrollS3 retainS3 gradeS3 unitS3 privS3 leftS3 dropS3 dieS3 pregS3 jailS3
lvreaS3 lvexpS3
enrollS4 retainS4 gradeS4 unitS4 privS4 leftS4 dropS4 
enrollF5 retainF5 gradeF5 privF5 leftF5 dropF5 dieF5 pregF5 jailF5 gradF5 
lvreaF5 lvexpF5
survey ss_* mm_* cc_* surveyel vv_*;

save maganal_hs, replace;
log close;



***********************************************************************;
***************************** PART 2 **********************************;
*********************** TEST RANDOMIZATION ****************************;
***********************************************************************;

log using part2.log, replace;

use maganal_hs;

keep if sampleS==1;
keep newid year unitS0
 sampleS sampleL select sublotto nt ns nr subgroup cugd cuhiva cuhipop
 rdxilS0 rdxil_1 mtxilS0 mtxil_1 yy* xxage nn* uS0itbs uS0mnotaa napp
 surveyel vv_humr vv_like vv_pars vv_psup vv_sch06q02 vv_par15* 
 vv_sbk16 vv_sbk18 vv_sbk23 vv_trob vv_bothpar vv_momsc;

** order variables to match tables;
order yyflunch yyrlunch yysped yybil yypar yyaa
 nnpblkS0 nnphisS0 nnpovS0 nnhsgdS0 nnownhS0 nnnilfS0 nncrimS0 
 nnpr912S0;

** create composite measure of school resources;
descr vv_par15*;
summ vv_par15*;
egen vv_partot=rsum(vv_par15*) if vv_par15q01~=.;
tab vv_partot;
drop vv_par15*;

descr;

** check how often background variables are not defined;
count;
summ rdxil* mtxil* yy* xxage nn* uS0itbs uS0mnotaa napp;
summ surveyel;
gen tmp1=surveyel==.;
tab tmp1 year;
egen tmp2=mean(surveyel) if year==2001, by(unitS0);
summ tmp2, detail;
summ tmp2 if tmp2~=0, detail;
drop unitS0 tmp*;

*** TESTING THE RANDOMIZATION OF LOTTERIES;

disp "*** TABLE 3 ***";
disp "** regressing background variables on select **";

 qui tab sublotto, gen(LL);
 qui compress;

 ** "continuous" variables;
 * note: move mtxil_1 and rdxil_1 to the end of the list since these
  are not reported in the table due to space constraints;
 foreach grp of varlist sampleS{;
 foreach var of varlist mtxilS0 rdxilS0 xxage napp uS0itbs uS0mnotaa 
  nn* vv_humr vv_like vv_pars vv_psup vv_partot mtxil_1 rdxil_1 {;
  disp "DEP VAR= `var' , SAMPLE = `grp'==1 ";
  descr `var';
  qui egen tmpincl=sd(`var'), by(sublotto);
  qui replace tmpincl=(tmpincl~=0&tmpincl~=.);
  qui replace tmpincl=0 if `var'==.;
  qui replace tmpincl=. if `grp'==0;
  qui summ tmpincl;
  disp " share of obs included: " %5.3f r(mean);
  qui areg `var' select if tmpincl==1, a(subgroup) robust cl(newid);
  qui summ `var' if select==0 & e(sample);
  if _b[select]>0{;
   local p=2*ttail(e(df_r),_b[select]/_se[select]);
  };
  if _b[select]<0{;
   local p=2*(1-ttail(e(df_r),_b[select]/_se[select]));
  };
  disp " coeff on select: " %5.3f _b[select] "   se: " %5.3f _se[select]
   "   p-value: " %5.3f `p'; 
  disp "  dep var mean: " %5.3f r(mean) "   st dev: " %5.3f r(sd);
  drop tmpincl;
  };
  };

 ** binary variables;
 foreach grp of varlist sampleS{;
 foreach var of varlist yy* surveyel vv_sch06q02 vv_sbk16 
  vv_sbk18 vv_sbk23 vv_trob vv_bothpar vv_momsc{;
  disp "DEP VAR= `var' , SAMPLE = `grp'==1 ";
  descr `var';
  qui egen tmpincl=sd(`var'), by(sublotto);
  qui replace tmpincl=(tmpincl~=0&tmpincl~=.);
  qui replace tmpincl=0 if `var'==.;
  qui replace tmpincl=. if `grp'==0;
  qui summ tmpincl;
  disp " share of obs used: " %5.3f r(mean);
  qui probit `var' select LL* if tmpincl==1, robust cl(newid);
  prmeavg `var';
  drop tmpincl;
  };
  };

drop LL*;

*** Identify lotteries not well-balanced on background char ***;

 ** calculating p-values for diff in means for the background vars
  and the absolute value of the difference in means;
 * continuous variables and proportions;
 * note: exclude mtxil_1 and rdxil_1 since these are not reported in
  the tables;
 for var mtxilS0 rdxilS0 xxage napp uS0itbs uS0mnotaa nn*
  vv_humr vv_like vv_pars vv_psup vv_partot, noheader: 
   qui egen tmp1=mean(X) if select==0, by(sublotto) \
   qui egen tmp2=max(tmp1), by(sublotto) \
   qui egen tmp3=mean(X) if select==1, by(sublotto) \
   qui egen tmp4=max(tmp3), by(sublotto) \
   qui gen d_X=abs(tmp2-tmp4) \ drop tmp*;
 * binary variables;
 for var yy* surveyel vv_sch06q02 vv_sbk16 vv_sbk18 vv_sbk23 vv_trob 
  vv_bothpar vv_momsc, noheader:
   qui egen tmp1=mean(X) if select==0, by(sublotto) \
   qui egen tmp2=max(tmp1), by(sublotto) \
   qui egen tmp3=mean(X) if select==1, by(sublotto) \
   qui egen tmp4=max(tmp3), by(sublotto) \
   qui gen d_X=abs(tmp2-tmp4) \ drop tmp*;
 
qui compress;
save maganal_rndm1, replace;

/*

*** How often would we expect to find significant differences?;

 ** Here we are going to use a Monte Carlo approximation to a 
  permutation test to see whether the pattern of actual p-values is 
  consistent with true randomization, so that the significant 
  differences found between treatments and controls can be attributed 
  to chance;
  * how it works: have two iid samples, X of size n (winners in our 
  case) and Y of size m (losers).  If these are from the same 
  distribution, then any permutation of elements in X and Y are equally 
  probable.  Rather than enumerating every possible permutation, can 
  implement an approximate randomization test by drawing two samples of 
  size n amd m from the n+m observations w/o replacement. Then compute 
  the statistics interested in, repeat a large # of times, and the % of 
  times the statistics exceed the values in the original sample gives 
  the significance level.;

*** Running the repetitions;

 ** First, create a dataset w/actual measures for each sublottery;

  use maganal_rndm1;
  keep if sampleL==1;
  keep sublotto nt ns nr d_*;
  gen byte n=0;
  save maganal_rndm2, replace;
  
 ** Then, recalculate the absolute value of differences between selected 
  and rejected students by repeatedly randomly assigning the 
  participants to one of these outcomes given that actual selection rate;

  use maganal_rndm1;
  qui tab sublotto, gen(LL);
  sort newid sublotto;
  set seed 11072004;
  forval num = 1/1000{;
    display `num';
    preserve;
    drop d_* select;

    ** randomly assign students w/in lottery to be selected at actual rate;
    qui gen tmp=uniform();
    qui egen select=rank(tmp) if sublotto~="", by(sublotto);
    qui replace select=(select<=ns) if sublotto~="";
    drop tmp;

    ** find number of p-values would expect to be significant at the 
     5% and 10% levels for our analysis of the average effect of winning 
     across lotteries;
    * ignore mtxil_1 and rdxil_1 since these are not reported in the tables;
    qui gen sim_5pct=0;
    qui gen sim_10pct=0;
    foreach var of varlist mtxilS0 rdxilS0 xxage napp uS0itbs uS0mnotaa 
    nn* vv_humr vv_like vv_pars vv_psup vv_partot{;
     qui egen tmpincl=sd(`var'), by(sublotto);
     qui replace tmpincl=(tmpincl~=0&tmpincl~=.);
     qui replace tmpincl=0 if `var'==.;
     qui areg `var' select if tmpincl==1, a(subgroup) robust cl(newid);
     if _b[select]>0{;
      local p=2*ttail(e(df_r),_b[select]/_se[select]); };
     if _b[select]<0{;
      local p=2*(1-ttail(e(df_r),_b[select]/_se[select])); };
     qui replace sim_5pct=sim_5pct+1 if `p'<=.05;
     qui replace sim_10pct=sim_10pct+1 if `p'<=.10;
     drop tmpincl;
    };
    foreach var of varlist yy* surveyel vv_sch06q02 vv_sbk16 vv_sbk18 
    vv_sbk23 vv_trob vv_bothpar vv_momsc{;
     qui egen tmpincl=sd(`var'), by(sublotto);
     qui replace tmpincl=(tmpincl~=0&tmpincl~=.);
     qui replace tmpincl=0 if `var'==.;
     qui dprobit `var' select LL* if tmpincl==1, robust cl(newid);
     qui prme select;
     qui replace sim_5pct=sim_5pct+1 if `p'<=.05;
     qui replace sim_10pct=sim_10pct+1 if `p'<=.10;
     drop tmpincl;
    };

    ** find abs(difference) for each variable for each lottery;
    for var mtxilS0 rdxilS0 xxage napp uS0itbs uS0mnotaa nn* 
     vv_humr vv_like vv_pars vv_psup vv_partot yy* surveyel vv_sch06q02 
     vv_sbk16 vv_sbk18 vv_sbk23 vv_trob vv_bothpar vv_momsc, noheader: 
     qui egen tmp1=mean(X) if select==0, by(sublotto) \
     qui egen tmp2=max(tmp1), by(sublotto) \
     qui egen tmp3=mean(X) if select==1, by(sublotto) \
     qui egen tmp4=max(tmp3), by(sublotto) \
     qui gen d_X=abs(tmp2-tmp4) \ drop tmp*;
    qui keep if sampleL==1;
    keep sublotto d_* sim_5pct sim_10pct;
    qui gen n=`num';    
    qui append using maganal_rndm2;
    qui compress;
    qui save maganal_rndm2, replace;
    restore;

  };
  if ${n}==0{; !gzip maganal_rndm2.dta; };
  drop _all;
  
*/

*** Compare actual to expected distributions;

 if ${n}==0{; !gzip -d maganal_rndm2.dta; };
 use maganal_rndm2;
 if ${n}==0{; !gzip maganal_rndm2.dta; };

 summ;
  
 * create indicator for year;
 descr sublotto;
 qui gen str1 tmp=substr(sublotto,-1,.);
 qui gen year=2000 if tmp=="0";
 qui replace year=2001 if tmp=="1";
 tab year, miss;
 tab sublotto if year==.;
 replace year=2000 if year==.;
 drop tmp;

 ** how often should we find significant differences in Table 3?;
 * these should be constant within iterations;
 egen tmp1=sd(sim_5pct), by(n);
 summ tmp1;
 sort n;
 gen tmp2=n~=n[_n-1] & n~=0;
 count if tmp2==1;
 summ sim* if tmp2==1;
 tab sim_5pct if tmp2==1;
 tab sim_10pct if tmp2==1;
 drop sim_* tmp*;

 * translate absolute values of the differences into placement
 within the distribution;
 for var d_*, noheader:
  qui gen tmp1=X*-1 \
  sort sublotto tmp1 \
  qui gen tmp2=1 if sublotto~=sublotto[_n-1] & X~=. \
  qui replace tmp2=tmp2[_n-1]+1 if sublotto==sublotto[_n-1] & X~=. \ 
  qui egen tmp3=count(X), by(sublotto) \
  qui replace tmp2=tmp2/tmp3 \
  qui egen p_X=max(tmp2), by(sublotto X) \ drop tmp*;
 for var p_*: summ X if n==0, detail;

 ** look lottery by lottery at the distribution of p-values across
 background variables;
 gen num_5pct=0;
 gen num_10pct=0;
 for var p_*, noheader: qui replace num_5pct=num_5pct+(X<=.05) \
  qui replace num_10pct=num_10pct+(X<=.10);
 for var num_5pct num_10pct, noheader:
  qui gen tmp1=X*-1 \
  sort sublotto tmp1 \
  qui gen tmp2=1 if sublotto~=sublotto[_n-1] & X~=. \
  qui replace tmp2=tmp2[_n-1]+1 if sublotto==sublotto[_n-1] & X~=. \ 
  qui egen tmp3=count(X), by(sublotto) \
  qui replace tmp2=tmp2/tmp3 \
  qui egen p_X=max(tmp2), by(sublotto X) \ drop tmp*;
 summ p_num* if n==0, detail;
 for var p_num*: tab sublotto year if X<=.05 & n==0 \
  tab sublotto year if X<=.10 & n==0;
 
 ** now aggregate information across lotteries-- do we find a 
 surprising number of lotteries with many significant differences 
 across variables?;
 sort n;
 gen tmp=n~=n[_n-1] & n~=0;
 for var p_num*: 
  egen pagg5=sum(X<=.05), by(n year) \ tab pagg5 year if tmp==1, col \
  egen pagg10=sum(X<=.10), by(n year) \ tab pagg10 year if tmp==1, col\
  drop pagg*;
 
drop _all;
log close;



********************************************;
****************** PART 3 ******************;
********** DESCRIPTIVE STATISTICS **********;
********************************************;

log using part3.log, replace;

use maganal_hs;

***REFINED SAMPLE***;

 ** 8th Graders Applying from within CPS;
  * Excludes:
   (a) choice schools with <10 applicants or that do not serve 9th graders
   (b) test-based schools
   (c) special ed schools
   (c) schools w/<95% valid disposition codes ;
  * We kept this broad set of applications in our initial sample in order to
   calculate a more complete measure of the # of applications and acceptances 
   for each student;

 ** FACTS;
  *# apps;
   count;
   tab year;
  * # kids;
   count if tagkid==1;
  * # schools;
   egen tagunit=tag(cunit);
   count if tagunit==1;
   drop tagunit;

***SAMPLE WITH LOTTERY INFO***;

* Excludes cases where sublotto is missing. It appears that the CPS kept 
 application and outcome info for these schools, but did not run a lottery 
 for them (if they even held one);

* FACTS; 

  *# apps;
   count if sublotto!="";
  *# lotteries;
   count if taglot==1;
  *# students;
   egen tmp=tag(newid) if sublotto!="";
   count if tmp==1;
   drop tmp;
  *# schools;
   egen tagunit=tag(cunit) if sublotto!="";
   count if tagunit==1;
   drop tagunit;

  *# lotteries and # apps with no winners;
   count if mnselect==0 & taglot==1;
   count if mnselect==0 & sublotto!="";
 
  *# lotteries and # apps with all winners;
   count if mnselect==1 & taglot==1;
   count if mnselect==1 & sublotto!="";

***ANALYSIS SAMPLE***;

* Excludes lotteries with no variation;

  count if sampleS==1;
  tab year if sampleS==1;
  count if sampleL==1;
  count if tagkidlot==1;
  egen tmp=tag(cunit) if sampleL==1;
  count if tmp==1;
  drop tmp;
 
* How many different schools do students in our analysis lotteries end up 
  attending the following year;

  sort sampleS enrollF1 unitF1 gradeF1;
  gen tmp1=1 if unitF1~=unitF1[_n+1] & sampleS==1 & enrollF1==1;
  count if tmp1==1;
  tab gradeF1 if sampleS==1;
  count if tmp1==1 & gradeF1<9;
  tab unitF1 uF1name if tmp1==1 & gradeF1<9 & unitF1<2000;
  tab gradeF1 if tmp1==1 & unitF1>=2000 & unitF1~=.;
  * fraction enrolled in CPS;
  summ enrollF1 if sampleS==1;
  * fraction retained in CPS;
  tab gradeF1 if retainF1==1 & sampleS==1;
  tab gradeF1 gradeS1 if retainF1==0 & sampleS==1;
  summ retainF1 if sampleS==1; 
 
  * focus on students who are not retained;
  * we find that over 95% of these students attend 69 schools (15.4% attend
    10 (of the 11) vocational schools, 11.9% attend the 7 selective schools,
    8.9% attend the 3 magnet schools, and 59.5% attend the 49 regular high
    schools);
  count if tmp1==1 & gradeF1>=9;
  summ f_* if tmp1==1 & gradeF1>=9;
  summ f_* if sampleS==1 & gradeF1>=9 & enrollF1==1;
  * number of schools by type;
  for var f_*: count if tmp1==1 & gradeF1>=9 & X==1;
  * note: none attend Flower vocational;
  tab uF1name if f_hsvoc==1 & gradeF1>=9 & sampleS==1;
  tab unitF1 if f_hschrt==1 & sampleS==1 & gradeF1>=9;
  * how many attending "other" schools are in regular h.s.'s?;
  * note: this includes the two military academies;
  gen tmp2=0;
  for num 1850 1800 1210 1220 1020 1230 1240 5640 1840 1880 1860 1270
   6630 1280 8070 1680 1310 1330 1340 1200 1350 1360 1380 4130 1670
   1390 1890 1870 1400 1410 1420 1710 1430 1620 1470 1480 1490 1830
   1510 1320 1520 1530 1540 1550 1560 1570 1580 1630 1640:
   replace tmp2=1 if unitF1==X;
  * Dyett is also 1600, so will be counted twice;
  replace tmp2=1 if unitF1==1600;
  * how many regular h.s.'s are represented?;
  count if tmp1==1 & tmp2==1; 
  tab tmp2 if f_hsoth==1 & sampleS==1 & gradeF1>=9;
  * which non-regular h.s.'s are represented;
  tab unitF1 if f_hsoth==1 & tmp2==0 & sampleS==1 & gradeF1>=9;
  tab uF1name if f_hsoth==1 & tmp2==0 & sampleS==1 & gradeF1>=9 
   & unitF1<2000;
  tab uF1name if f_hsoth==1 & tmp2==0 & sampleS==1 & gradeF1>=9 
   & unitF1>=2000;
  drop tmp*;

  * what fraction of Fall enrollment is at one of the schools in the
  analysis sample;
  summ lottF1;
  summ lottF1 insch select if sampleS==1;
  summ lottF1 insch select if sampleS==1 & gradeF1>=9;

disp "*** TABLE 2 ***";
*** CHARACTERISTICS OF APPLICANTS VS OTHER CPS STUDENTS;

** Get characteristics for applicants in our analysis lotteries;

 * replace school type to missing if not in h.s. following year;
 replace uF1type="" if retainF1==1|enrollF1==0|unitF1<1000;

 for var f_*: tab uF1type if X==1;
 tab uF1name if uF1type=="College Prep" & f_hsoth==1;
 tab uF1name if uF1type=="Magnet" & f_hsoth==1;
 tab uF1name if uF1type=="Military Academy" & f_hsoth==1;
 replace f_hsoth=0 if uF1type~="General" & uF1type~="Year Round" &
  uF1type~="College Prep" & uF1type~="Magnet" & uF1type~="Military Academy";
 gen f_hsalt=(uF1type=="Academic Prep Center"|
  uF1type=="Alt-Pregnant Girls"|uF1type=="Alternative"|
  uF1type=="Jail/Juv Detention"|uF1type=="Special Education"|
  uF1type=="Special Needs");
 for var f_*: replace X=. if uF1type=="";
 summ f_*;
 gen tmp=f_hschrt+f_hsvoc+f_hstst+f_hsmag+f_hsoth+f_hsalt;
 tab tmp;
 drop tmp;

 disp "*** TABLE 2: Data for column for lottery participants ***";
 tabstat xxwhi xxblk xxhisp xxmale mtxilS0 rdxilS0 
  yyflunch yysped yybil yypar nnpovS0 nnhsgdS0 
  enrollF1 privF1 leftF1 retainF1 
  f_hstst f_hsmag f_hsvoc f_hschrt f_hsalt f_hsoth 
  if tagkidlot==1, s(count mean semean) columns(statistics);

 * save data set with IDs for all of our applicants to the refined set;
 preserve;
 keep sid year;
 sort sid year;
 drop if sid==sid[_n-1]&year==year[_n-1];
 save temp_comp2no, replace;
 restore;

 * keep analysis students;
 keep if tagkidlot==1;
 keep newid year sid xxwhi xxblk xxhisp xxmale mtxilS0 rdxilS0 
  yyflunch yysped yybil yypar nnpovS0 nnhsgdS0
  enrollF1 privF1 leftF1 retainF1
  f_hstst f_hsmag f_hsvoc f_hschrt f_hsalt f_hsoth; 
 sort newid;
 count if newid==newid[_n-1];
 drop newid; 
 save temp_comp1, replace;

** Get characteristics of other 8th graders;

 * get data from Spring masterfiles;
  if ${n}==0{; global src=""; !gzip -d allm500.dta.gz; };
  if ${n}==1{; global src="e:\data\masterfiles\"; };
  use sid centract granu statu ethni lunch sped guard gend bcat 
   if granu==8 & (statu==1|statu==2) using ${src}allm500;
  if ${n}==0{; !gzip allm500.dta; };
  for any granu statu ethni lunch sped guard gend bcat, noheader: 
   rename X500 X;
  qui gen year=2000;
  save temp_comp2, replace;
  
  if ${n}==0{; !gzip -d allm501full.dta.gz; };
  if ${n}==1{; global src="e:\fullmasterfiles\"; };
  use sid centract granu statu ethni lunch sped guard gend bcat 
   if granu==8 & (statu==1|statu==2) using ${src}allm501full;
  if ${n}==0{; !gzip allm501full.dta; };
  for any granu statu ethni lunch sped guard gend bcat, noheader: 
   rename X501 X;
  qui gen temp=real(bcat);
  drop bcat;
  rename temp bcat;
  qui gen year=2001;
  append using temp_comp2;

 * exclude students submitting applications;
  sort sid year;
  count if sid==sid[_n-1] & year==year[_n-1];
  merge sid using temp_comp2no;
  tab year _merge, row;
  keep if _merge==1;

 * create background variables;
  gen xxwhi=ethni==1;
  gen xxblk=ethni==2;
  gen xxhisp=ethni==5;
  gen xxmale=gend==1;
  gen yyflunch=lunch=="F";
  gen yysped=sped!="";
  gen yypar=guard=="1"|guard=="2" if guard~=""; 
  gen yybil=(bcat>=1&bcat<=4);
  rename centract tractS0_90;
  keep sid year tractS0_90 xx* yy*;

 * convert 1990 tract numbers to 2000 numbers;
  summ tractS0_90 if year==2000;
  summ tractS0_90 if year==2001;
  replace tractS0_90=tractS0_90-170310000;
  summ tractS0_90;
  list tractS0_90 if tractS0_90<0;
  if ${n}==0{; global src="CEN_RELN\"; !gzip -d ${src}rel_trcts.dta; };
  if ${n}==1{; global src="c:\projects\magnet schools\cen_reln\"; };
  capture label drop __MERGE;
  mmerge tractS0_90 using "${src}rel_trcts", type(n:1) unmatched(master)
   umatch(trct90s) ukeep(trct00s) urename(trct00s tractS0_2);
  if ${n}==0{; !gzip ${src}rel_trcts.dta; };
  count if tractS0_90!=tractS0_2;
  * turns out the tracts are always the same;
  rename tractS0_90 tractS0;
  drop tractS0_2;

 * get 2000 Census variables;
  if ${n}==0{; global src="CENSUS\"; !gzip -d ${src}cens00tr.dta; };
  if ${n}==1{; global src="c:\projects\magnet schools\census\"; };
  capture label drop __MERGE;
  mmerge tractS0 using "${src}cens00tr", type(n:1) unmatched(master)
   umatch(trct00s) ukeep(povrate phsgrad)
   urename(povrate nnpovS0 \ phsgrad nnhsgdS0); 
  if ${n}==0{; !gzip ${src}cens00tr.dta; };
  drop _merge;

  sort sid year;
  save temp_comp2, replace;

 * get Spring test scores;

  if ${n}==0{; global src=""; !gzip -d itbs2000b.dta; };
  if ${n}==1{; global src="e:\data\itbs\"; };
  use sid readxil mathtxil using "${src}itbs2000b";
  if ${n}==0{; !gzip itbs2000b.dta; };
  gen year=2000;
  save temp_hold, replace;

  if ${n}==0{; !gzip -d itbs2001b.dta; };
  use sid readxil mathtxil using "${src}itbs2001b";
  if ${n}==0{; !gzip itbs2001b.dta; };
  gen year=2001;
  append using temp_hold;
  rename readxil rdxilS0;
  rename mathtxil mtxilS0;
  for var rdxilS0 mtxilS0: summ X \ replace X=X/100;

  sort sid year;
  count if sid==sid[_n-1] & year==year[_n-1];
  merge sid year using temp_comp2;
  tab _merge;
  keep if _merge~=1;
  save temp_comp2, replace;

 * get Fall masterfile data;

  if ${n}==0{; global src=""; !gzip -d allm900full.dta; };
  if ${n}==1{; global src="e:\fullmasterfiles\"; };
  use sid statu lvrea granu cursc using "${src}allm900full";
  if ${n}==0{; !gzip allm900full.dta; };
  for any statu lvrea granu cursc: rename X900 X;
  sort sid;
  count if sid==sid[_n-1];
  gen year=2000;
  save temp_hold, replace;
  use temp_comp2;  
  capture label drop __MERGE;
  mmerge sid year using temp_hold, type(1:1) unmatched(master)
   ukeep(statu lvrea granu cursc);
  save temp_comp2, replace;

  if ${n}==0{; !gzip -d allm901full.dta; };
  use sid statu lvrea granu cursc using "${src}allm901full";
  if ${n}==0{; !gzip allm901full.dta; };
  sort sid;
  count if sid==sid[_n-1];
  gen year=2001;
  save temp_hold, replace;
  use temp_comp2;
  capture label drop __MERGE;
  mmerge sid year using temp_hold, type(1:1) unmatched(master)
   ukeep(statu lvrea granu cursc);
  for any statu lvrea granu cursc: replace X=X901 if X==. \ drop X901;

  rename cursc curscF1;
  rename granu gradeF1;
  gen enrollF1=statu==1|statu==2;
  tab gradeF1 if enrollF1==1;
  gen retainF1=(gradeF1<9|gradeF1>12) if gradeF1~=. & enrollF1==1;
  tab lvrea if enrollF1==0, m;
  gen privF1=enrollF1==0&lvrea==32;
  gen leftF1=enrollF1==0&lvrea==33; 
  gen unitF1=int(curscF1/10)*10 if enrollF1==1;
  drop statu lvrea;
  for var curscF1 unitF1:
   replace X=. if retainF1==1|enrollF1==0|unitF1<1000;
 
 * get school type info;
  gen tempunit=curscF1;
  * Dyett is normally 8070;
  replace tempunit=8070 if curscF1==1600;
  if ${n}==0{; global src=""; !gzip -d schl01.dta; };
  if ${n}==1{; global src="e:\data\school_level\misc\"; };
  capture label drop __MERGE;
  mmerge tempunit using "${src}schl01", type(n:1) umatch(unit)
   unmatched(master) ukeep(schlname schltype) urename(schlname uF1name \
   schltype uF1type);
  if ${n}==0{; !gzip schl01.dta; };
  tab _merge enrollF1;
  tab unitF1 if _merge==1;
  drop tempunit;

 * create indicators for vocational, selective, magnet and charter schools;
  gen byte f_hsvoc=uF1type=="Career Academy" if unitF1~=.;
   tab unitF1 if f_hsvoc==1;
   replace f_hsvoc=0 if unitF1==1820;
  gen byte f_hstst=0 if unitF1~=.;
   for num 1060 1440 1450 1740 1500 1090 1810: replace f_hstst=1 if 
   unitF1==X;
  gen byte f_hsmag=0 if unitF1~=.;
   for num 1790 1820 1610: replace f_hsmag=1 if unitF1==X;
  gen byte f_hschrt=uF1type=="Charter" if unitF1~=.;
 
 * identify other regular schools and alternative schools;
  gen tmp=f_hsvoc+f_hstst+f_hsmag+f_hschrt;
  tab uF1type if tmp==1;
  tab uF1type if tmp==0;
  gen f_hsoth=(uF1type=="General"|uF1type=="Year Round"|
   (uF1type=="College Prep" & tmp==0)|(uF1type=="Magnet" & tmp==0)|
    uF1type=="Military Academy") if unitF1~=.;
  gen f_hsalt=(uF1type=="Academic Prep Center"|uF1type=="Alt-Pregnant Girls"|
   uF1type=="Alternative"|uF1type=="Jail/Juv Detention"|
   uF1type=="Special Education") if unitF1~=.;
  replace tmp=f_hsvoc+f_hstst+f_hsmag+f_hschrt+f_hsoth+f_hsalt;
  tab tmp;
  summ f_*;
  drop tmp;

 disp "*** TABLE 2: Data for column for non-applicants ***";
 * get summary stats;
  tabstat xxwhi xxblk xxhisp xxmale mtxilS0 rdxilS0 
   yyflunch yysped yybil yypar nnpovS0 nnhsgdS0
   enrollF1 privF1 leftF1 retainF1 
   f_hstst f_hsmag f_hsvoc f_hschrt f_hsalt f_hsoth, s(count mean semean) 
   columns(statistics);

 disp "*** TABLE 2: Find standard error on difference ***";
 keep xxwhi xxblk xxhisp xxmale mtxilS0 rdxilS0 
  yyflunch yysped yybil yypar nnpovS0 nnhsgdS0 
  enrollF1 privF1 leftF1 retainF1
  f_hstst f_hsmag f_hsvoc f_hschrt f_hsalt f_hsoth; 
 gen applicant=0;
 append using temp_comp1;
 replace applicant=1 if applicant==.;
 for var xxwhi xxblk xxhisp xxmale mtxilS0 rdxilS0 
  yyflunch yysped yybil yypar nnpovS0 nnhsgdS0 
  enrollF1 privF1 leftF1 retainF1
  f_hstst f_hsmag f_hsvoc f_hschrt f_hsalt f_hsoth:
  reg X applicant;

!del temp_comp*.dta; 
!del temp_hold.dta;
drop _all;
log close;



**************************************************;
******************* PART 4 ***********************;
********** ANALYSIS OF STUDENT OUTCOMES **********;
**************************************************;

******************************************************;
*** (4.1) KEEP ANALYSIS SAMPLE AND SET UP GLOBALS ***;
*****************************************************;

*** KEEP ANALYSIS SAMPLE;

use maganal_hs;

keep if sampleS==1;

** check tags;
 sort sublotto;
 count if sublotto~=sublotto[_n-1];
 count if sampleL==1;
 count if taglot==1;
 sort newid;
 count if newid~=newid[_n-1];
 count if tagkidlot==1;
 count if tagkid==1;
 drop sampleL tagkidlot;

** what are our sample sizes?;
 count;
 count if enrollF1==1;
 count if enrollF1==1 & tagkid==1;
 for num 2000 2001: count if year==X \ count if enrollF19==1 & year==X \ 
  count if enrollF19==1 & tagkid==1 & year==X \ 
  count if taglot==1 & year==X;

** drop unneeded variables;
 drop sid napptot nappvalid dacc dlot lottery outvar;
 summ accept select;
 drop accept;
 drop xxwhi xxasian xxnatam xxfemale;
 summ yyflunch yyrlunch;
 rename yyrlunch hold_yyrlunch;
 drop dc sx rc gr latS0 longS0 tractF1 aaF1
 uS0pwhi uS0pblk uS0phisp uS0ploinc uS0pmin uS0type
 cutype cu_hsvoc cu_hsoth
 cupwhi cupblk cuphisp cuplep cuploinc cupattnd cupdrop cupgrad cusize
 cumnotaa cucrim cumedy cupov cutract cuppe cupsped cupar cuptr 
 cuuniv1 cumstpls cuscrths cuscrtsub cutcrt cupmin
 uF1pwhi uF1plep uF1size uF1tract uF1par;

** adjust/create a few variables; 

 * convert # absences to share of days absent;
  summ mabsS1, detail;
  replace mabsS1=mabsS1/90;
  summ mabsS2, detail;
  replace mabsS2=mabsS2/90;

 * convert credits in Spring Yr 2 to incoporate earlier credits;
  replace tcrdS2=tcrdS2+tcrdS1;
   label var tcrdS2 "cumulative credits Spr Yrs 1-2";

 * convert class rank into fractions where .99 is best and 0.01 is worst;
  sum crankS*;
  for num 1/2: replace crankSX=1-(crankSX/100);
  sum crankS*;
  pwcorr crankS1 crankS2 zzrdxilS0 zzmtxilS0;

 * use imputed test scores since so few missing, and these incorporate
  7th grade test scores if 8th grade scores are missing;
  summ zz*;
  drop zz*;
  rename izzrdxilS0 zzrdxilS0;
  rename izzmtxilS0 zzmtxilS0;

 * create standardized reading achievement scores (mean 0, std dev 1)
  to attempt to get estimates comparable to Hanushek et al. (2004);
  egen srd9=std(rdxilS1);
  egen srd8=std(rdxilS0);
  gen srd89=srd9-srd8;
  drop srd8;
   label var srd89 "gain in std reading scores 8th-9th";
   label var srd9 "std 9th grade reading score";

 * create composite home resource variable;
  descr vv_par15*;
  summ vv_par15*;
  egen vv_partot=rsum(vv_par15*) if vv_par15q01~=.;
  tab vv_partot;
  drop vv_par15*;
   label var vv_partot "# of home ed resources";

 * create composite measures of parental involvement;
  descr ss_par*;
  egen ss_help=rmax(ss_par12q01 ss_par12q02);
  egen ss_talk=rmax(ss_par11q01 ss_par11q02 ss_par11q03 ss_par11q04);
   label var ss_help "parents regularly help w/schoolwork";
   label var ss_talk "parents regularly discuss class/sch issues";

 * create indicators for potential gains in peer quality;
  qui gen dins8=cucomp8-inscomp8;
  qui xtile qdins8=dins8, nq(4);
  qui gen byte botq=qdins8==1 if qdins8~=.;
  qui gen byte topq=qdins8==4 if qdins8~=.;
   label var botq "bot quartile in pot gains in peer quality";
   label var topq "top quartile in pot gains in peer quality";
  drop dins8;

*** CREATING GLOBALS;

* those ending with "co" are continuous variables (including proportions);
* those ending with "01" are dummies;

** Control set including predetermined characteristics;

 global cntrls zz* xx* yy* nn*;
 summ ${cntrls};

 * set w/o prior achievement for comparison to Hanushek et al. (2004);
 global cntrls2 "xx* yy* nn*";

** Student background characteristics;
   
 * note: currently including only those background variables reported 
   in the tables in Appendix C to ease data entry;
 global bck_co "mtxilS0 rdxilS0 nnpov";
 global bcks_co "vv_pars vv_psup";
 global bck_01 "yyflunch yysped";
 global bcks_01 "vv_sbk23 vv_trob vv_momsc";

 /*
 * globals with comprehensive background variable lists;
 global bck_co "mtxilS0 rdxilS0 xxage napp uS0itbs uS0mnotaa nnpblkS0
  nnphisS0 nnpov nnhsgdS0 nnownhS0 nnnilfS0 nncrimS0 nnpr912S0";
 global bcks_co "vv_humr vv_like vv_pars vv_psup vv_partot";
 global bck_01 "yyflunch yyrlunch yysped yybil yypar yyaa";
 global bcks_01 "surveyel vv_sch06q02 vv_sbk16 vv_sbk18 
  vv_sbk23 vv_trob vv_bothpar vv_momsc";
 */
  
** School characteristics;

 global trt_01 "insch cschF1 gdF1 hivaF1 f_hstst f_hsvoc uF1maj uF1clmaj";
 global trt_co "uF1pnorms uF1pgrad uF1comp8 uF1clmn8 uF1va8 
  uF1pmin uF1clpmin uF1ploinc uF1lmedy uF1crim
  uF1miles mtou9 mfromu8 uF1pdiff uF1clpdiff";


******************************************;
*** (4.2) TEST FOR SELECTIVE ATTRITION ***;
******************************************;

*** Is there differential attrition? ***;
*** Might the differential attrition bias our results? ***;

* To answer the first question, we run models with enrollment and 
missing test score indicators on the LHS (using all students). To 
answer the second question, we run models with 8th grade observables 
on the LHS using a sample that only contains students who enrolled or 
who took the 9th/10th grade exams or survey.;

*** PROGRAM;

* first global is a background/outcome variable
  the second varies the empirical model depending on the nature
     of the dependent variable:
     1 = continuous variable
     2 = binary
  the third is for additional restrictions on the if statement;

program define dosel;
 disp "** DEPVAR = `1' , SAMPLE = `3' **";
 descr `1';
 disp " stats for dependent variable for losers in full sub-sample";
 tabstat `1' if select==0 `3', stats(mean semean sd n);
 tempvar tmpsmp tmpnum;
 qui egen `tmpsmp'=sd(`1') if select~=. `3', by(sublotto);
 qui replace `tmpsmp'=(`tmpsmp'~=0 & `tmpsmp'~=.) if select~=. `3';
 qui replace `tmpsmp'=0 if `tmpsmp'==1 & `1'==.;
 qui summ `tmpsmp';
 disp " share of obs used: " %5.3f r(mean);
 if `2'==1{;
  qui areg `1' select if `tmpsmp'==1, a(subgroup) cl(newid);
  if _b[select]>0{;
   local p=2*ttail(e(df_r),_b[select]/_se[select]); };
  if _b[select]<0{;
   local p=2*(1-ttail(e(df_r),_b[select]/_se[select])); };
  disp " Coeff: " %5.3f _b[select] "   s.e.: " %5.3f _se[select]
   "   p-value: " %5.3f `p';
 };
 if `2'==2{;
  qui tab sublotto if `tmpsmp==1', gen(LL);
  qui egen `tmpnum'=nvals(sublotto) if `tmpsmp'==1;
  qui summ `tmpnum';
  if r(mean)>1{; drop LL1; };
  if r(mean)==1{; qui replace LL1=0; };
  if r(mean)>=1{;
   qui probit `1' select LL* if `tmpsmp'==1, cl(newid);
   capture noisily prmeavg `1';
   drop LL*; };
 };
end;

*** RUNNING PROGRAM;

capture log close;
log using results_sel.log, replace;

foreach s of varlist sampleS cugd cuhiva cuhipop{;

disp "*** TABLE 3 ***";
disp "*** TABLE C1: PANELS A AND A' ***";
disp "*** Initial Selection and enrollment effects in Fall Yr 1 ***"; 

 disp "** is there differential attrition? **";
 disp "*** TABLE 3 -- bottom rows (full sample) ***";
 disp "*** TABLE C1: PANEL A ***"; 
 disp "number in sample";
  count if `s'==1;
  disp "number of losers in sample";
  count if select==0 & `s'==1;
   for var enrollF19 privF1, noheader: dosel X 2 &`s'==1;

 disp "** any observable diffs cond'l on enrolling in Fall Yr 1? **";
 disp "*** TABLE 3 -- last two columns (full sample) ***";
 disp "*** TABLE C1: PANEL A' ***";
  * use the full set used in the earlier analysis testing for the
  validity of the lotteries in Part 2 shown in the first panel
  of Table 3;
  disp "number in sample enrolled in 9th Fall Yr 1";
  count if enrollF19==1&`s'==1;
  disp "number of losers in this sample";
  count if select==0 & enrollF19==1&`s'==1;
  for var mtxilS0 rdxilS0 xxage napp uS0itbs uS0mnotaa nnpblkS0
   nnphisS0 nnpov nnhsgdS0 nnownhS0 nnnilfS0 nncrimS0 nnpr912S0
   vv_humr vv_like vv_pars vv_psup vv_partot, noheader:
   dosel X 1 &enrollF19==1&`s'==1;
  for var yyflunch hold_yyrlunch yysped yybil yypar yyaa surveyel vv_sch06q02 
   vv_sbk16 vv_sbk18 vv_sbk23 vv_trob vv_bothpar vv_momsc, noheader:
   dosel X 2 &enrollF19==1&`s'==1;

disp "*** TABLE C1: PANELS B AND B' ***";

 disp "*** Outcome Attrition in Spring Year 1 ***";
  * create positive versions of these variables so easier to interpret
  without inverting;
  for var missoutS1 msrdxilS1 msalgS1 mseng1S1 mstranS1, noheader:
   qui gen noX=1-X;
  for var enrollS1 nomissoutS1 nomsrdxilS1 nomsalgS1 nomseng1S1 nomstranS1,
   noheader: dosel X 2 &enrollF19==1&`s'==1;

 disp "*** Selectivity of Yr1 Outcome Attrition ***";
  disp "number in Spr Yr1 outcome sample";
  count if enrollF19==1&missoutS1==0&`s'==1;
  disp "number of losers in this sample";
  count if select==0 & enrollF19==1&missoutS1==0&`s'==1;
  for var ${bck_co} ${bcks_co}, noheader: 
   dosel X 1 &enrollF19==1&missoutS1==0&`s'==1;
  for var ${bck_01} ${bcks_01}, noheader:
   dosel X 2 &enrollF19==1&missoutS1==0&`s'==1;
 drop nomiss* noms*;

disp "*** TABLE C1: PANELS C AND C' ***";
disp "*** Survey Attrition ***";

 disp "** first examine 2000 cohort separately **";
  dosel enrollF19 2 &year==2000&`s'==1;
  for var ${bck_co}, noheader: 
   dosel X 1 &enrollF19==1&year==2000&`s'==1;
  for var ${bck_01}, noheader: 
   dosel X 2 &enrollF19==1&year==2000&`s'==1;
  for any enrollS1 missoutS1: 
   dosel X 2 &enrollF19==1&year==2000&`s'==1;
  for var ${bck_co}, noheader:
   dosel X 1 &enrollF19==1&missoutS1==0&year==2000&`s'==1;
  for var ${bck_01}, noheader:
   dosel X 2 &enrollF19==1&missoutS1==0&year==2000&`s'==1;
 
 disp "** are winners more likely to respond to the survey? **";
  * note: no analysis schools have very low non-zero response rates;
  tab cunit if enrollF19==1&cumsurv==0;
  tab cunit if enrollF19==1&cumsurv>0&cumsurv<=0.1;
  disp "number in survey schools";
  count if enrollF19==1&cumsurv~=0&year==2000&`s'==1;
  disp "number of losers in this sample";
  count if select==0 & enrollF19==1&cumsurv~=0&year==2000&`s'==1;
  dosel survey 2 &enrollF19==1&cumsurv~=0&`s'==1;

 disp "** are winners systematically different among responders? **";
  disp "number of survey respondents";
  count if enrollF19==1&cumsurv~=0&survey==1&`s'==1;
  disp "number of losers in this sample";
  count if select==0 & enrollF19==1&cumsurv~=0&survey==1&`s'==1;
  for var ${bck_co}, noheader: 
   dosel X 1 &enrollF19==1&cumsurv~=0&survey==1&`s'==1;
  for var ${bck_01}, noheader: capture noisily 
   dosel X 2 &enrollF19==1&cumsurv~=0&survey==1&`s'==1;

disp "*** TABLE C1: PANELS D and D' ***";

 disp "*** Enrollment and outcome Attrition in Spring Yr 2 ***";
 * note: for the 2001 cohort, we only have enrollment and 
  transcript data, but	no test score data, so limit all to 2000;
 * create positive versions of these variables so easier to interpret
 without inverting;
 for var missoutS2 msrdxilS2 msgeoS2 mseng2S2 mstranS2, noheader: 
  qui gen noX=1-X;
 * are losers more likely to be missing outcome data cond'l on enr?;
 disp "number enrolled in Fall and Spr Yr 1 in 2000 cohort";
 count if year==2000&enrollF19==1&enrollS1==1&`s'==1;
 disp "number of losers in this sample";
 count if select==0 & year==2000&enrollF19==1&enrollS1==1&`s'==1;
 for var enrollS2 nomissoutS2 nomsrdxilS2 nomsgeoS2 nomseng2S2 nomstranS2, 
  noheader: dosel X 2 &year==2000&enrollF19==1&enrollS1==1&`s'==1;

 disp "*** Selective Attrition in Spring Yr 2 ***";
 * any observable diff conditional on having outcome data in Spr Yr 2?;
  disp "number with complete Spr Yr 2 outcome data";
  count if enrollF19==1&missoutS2==0&year==2000&`s'==1;
  disp "number of losers in this sample";
  count if select==0 & enrollF19==1&missoutS2==0&year==2000&`s'==1;
  for var ${bck_co}, noheader: 
   dosel X 1 &enrollF19==1&missoutS2==0&year==2000&`s'==1;
  for var ${bck_01}, noheader:
   dosel X 2 &enrollF19==1&missoutS2==0&year==2000&`s'==1;

 drop nomiss* noms*;

};

log close;


******************************************************;
*** (4.3) PROGRAMS TO RUN REDUCED FORM REGRESSIONS ***;
******************************************************;

** RF_CO : continuous variables (w/o interactions);
 * 1 = dependent variable
   2 = cluster variable
   3 = for restrictions on the if statement (start w/&);
 * note: includes one specification that doesn't include prior 
   achievement controls to run models with the standardized gain 
   score on the LHS to be comparable with Hanushek et al. (2004);

 program define rf_co;
  disp "DEPVAR = `1' , SAMPLE =`3'";
  disp "METHOD = OLS";
  descr `1';
  tempvar tmpsmp;
  qui egen `tmpsmp'=sd(`1') if sampleS==1 `3', by(sublotto);
  qui replace `tmpsmp'=(`tmpsmp'~=0&`tmpsmp'~=.) if sampleS==1 `3';
  qui replace `tmpsmp'=0 if `tmpsmp'==1 & `1'==.;
  qui summ `tmpsmp';
  disp " share of obs used: " r(mean);
  qui summ `1' if sampleS==1 `3';
  disp " # obs w/non-missing dep var: " r(N);
  disp " control mean for sample w/non-missing dep var";
  tabstat `1' if select==0 `3', stats(mean semean sd);
  qui summ `1' if `tmpsmp'==1;
  disp " # obs for analysis sample: " r(N);
  disp "* regression with full set of control variables *";
  qui areg `1' select ${cntrls} if `tmpsmp'==1, a(subgroup) cl(`2');
   if _b[select]>0{;
    local p=2*ttail(e(df_r),_b[select]/_se[select]); };
   if _b[select]<0{;
    local p=2*(1-ttail(e(df_r),_b[select]/_se[select])); };
   disp " Coeff    s.e.    p-value";
   disp " " %5.3f _b[select] "    "  %5.3f _se[select] "    "  %5.3f `p';
  if "`1'"=="srd9"|"`1'"=="srd89"{;
   disp "* regression excluding controls for prior achievement *";
    qui areg `1' select ${cntrls2} if `tmpsmp'==1, a(subgroup) cl(`2');
     if _b[select]>0{;
      local p=2*ttail(e(df_r),_b[select]/_se[select]); };
     if _b[select]<0{;
      local p=2*(1-ttail(e(df_r),_b[select]/_se[select])); };
    disp " Coeff    s.e.    p-value";
    disp " " %5.3f _b[select] "    "  %5.3f _se[select] "    "  %5.3f `p';
   };
 end;

** RF_01 : dummy variables --  reporting the mean marginal effect; 
 * 1 = dependent variable
   2 = cluster variable
   3 = for restrictions on the if statement (start with &);

 program define rf_01;
  disp "DEPVAR = `1' , SAMPLE =`3'";
  disp "METHOD = PROBIT";
  descr `1';
  tempvar tmpsmp;
  qui egen `tmpsmp'=sd(`1') if sampleS==1 `3', by(sublotto);
  qui replace `tmpsmp'=(`tmpsmp'~=0&`tmpsmp'~=.) if sampleS==1 `3';
  qui replace `tmpsmp'=0 if `tmpsmp'==1 & `1'==.;
  qui summ `tmpsmp';
  disp " share of obs used: " r(mean);
  qui summ `1' if sampleS==1 `3';
  disp " # obs w/non-missing dep var: " r(N);
  disp " control mean for sample w/non-missing dep var";
  tabstat `1' if select==0 `3', stats(mean semean sd);
  qui summ `1' if `tmpsmp'==1;
  disp " # obs for analysis sample: " r(N);
  qui tab sublotto if `tmpsmp'==1, gen(LL);
  disp "* regression with full set of control variables *";
  qui probit `1' select LL* ${cntrls} if `tmpsmp'==1, cl(`2');
  capture noisily prmeavg `1';
  drop LL*;
 end;


****************************************************;
*** (4.4) BASELINE TREATMENT AND OUTCOME EFFECTS ***;
****************************************************;

/*** TEST FOR PERSISTENCE ***/

 * will help in evaluating the treatment effect;
 tabstat insch, by(select);
 tabstat insch if enrollF19==1, by(select);
 gen tmp1=(unitF1==unitS1) if unitS1~=.&enrollF19==1;
 gen tmp2=(unitF1==unitS2) if unitS2~=.&enrollF19==1;
 gen tmp3=(unitF1==unitS3) if unitS3~=.&enrollF19==1;
 gen tmp4=(unitF1==unitS4) if unitS4~=.&enrollF19==1;
 * for winners, what fraction stay in that choice school?;
 summ tmp* if insch==1 & select==1;
 * what fraction remain in high school began in?;
 tabstat tmp*, by(select);
 * losers are slightly more likely to switch than winners;
 for var tmp*, noheader: qui egen tmpsmp=sd(X), by(sublotto) \
  qui replace tmpsmp=(tmpsmp~=0&tmpsmp~=.) \
  qui tab sublotto if tmpsmp==1, gen(LL) \
  drop LL1 \
  qui probit X select LL* if tmpsmp==1, robust cl(newid) \
  prmeavg X \
  drop tmpsmp LL*;
 drop tmp*;


/*** RESULTS BY SCHOOL TYPE ***/

capture log close;
log using "results_schooltype.log", replace;

 disp "*** TABLE 4 ***";

 disp "** TREATMENT EFFECTS";
 * note: do not cluster on unitF1 for "treatment" variables
   since these are defined at the school level;
 foreach s of varlist sampleS cugd cuhiva cuhipop {;
  for var ${trt_01}: rf_01 X newid &enrollF19==1&`s'==1;
  for var ${trt_co}: rf_co X newid &enrollF19==1&`s'==1;
 };

 disp "*** ESTIMATES FOR HANUSHEK ET AL. (2004) COMPARISON ***";
 foreach s of varlist sampleS cugd cuhiva cuhipop {;
  for var srd9 srd89: rf_co X unitF1 &enrollF19==1&`s'==1;
 };

 disp "*** TABLE 5 ***";

 foreach s of varlist sampleS cugd cuhiva cuhipop {;

  disp "** OUTCOMES AT THE END OF 4 YEARS";
  for var gradF5 enrollF5 dropF5 privF5 leftF5:
   rf_01 X unitF1 &enrollF19==1&`s'==1; 

  disp "** 9TH GRADE OUTCOMES";
  for var rdxilS1 algS1 eng1S1 mabsS1 tcrdS1 crankS1: 
   rf_co X unitF1 &enrollF19==1&`s'==1;

  disp "** 10TH GRADE OUTCOMES";
  * note: 10th grade exam scores (rdxilS2, geoS2, eng2S2) are 
    only available for 2000 cohort;
  for var rdxilS2 geoS2 eng2S2 mabsS2 tcrdS2 crankS2: 
   rf_co X unitF1 &enrollF19==1&`s'==1;

  disp "** 11TH GRADE OUTCOMES";
  for var dropS3 retainS3: rf_01 X unitF1 &enrollF19==1&`s'==1;

 disp "** TRADITIONAL OUTCOMES FOR COHORT 2000 SAMPLE ONLY **";

 * run the basic academic outcomes restricting the sample to 
   students from the 2000 cohort.  This will help us interpret the 
   results for the outcome measures that apply only to this sample, 
   such as rdxilS2, eng2S2, geoS2 and all of the F5 outcomes;

  disp "** TREATMENT EFFECTS";
  for var ${trt_01}: rf_01 X newid &enrollF19==1&year==2000&`s'==1;
  for var ${trt_co}: rf_co X newid &enrollF19==1&year==2000&`s'==1;

  disp "** 9TH GRADE OUTCOMES";
  for var rdxilS1 algS1 eng1S1 mabsS1 tcrdS1 crankS1: 
   rf_co X unitF1 &enrollF19==1&year==2000&`s'==1;

  disp "** 10TH GRADE OUTCOMES";
  for var mabsS2 tcrdS2 crankS2: 
   rf_co X unitF1 &enrollF19==1&year==2000&`s'==1;

  disp "** 11TH GRADE OUTCOMES";
  for var dropS3 retainS3:
   rf_01 X unitF1 &enrollF19==1&year==2000*`s'==1;

 };

log close;


/*** RESULTS BY STUDENT CHARACTERISTIC ***/

capture log close;
log using "results_studgroup.log", replace;

 disp "** ATTRITION **";

 foreach s of varlist xxblk xxhisp xxmale q12 botq topq{;
  for var enrollF19, noheader: dosel X 2 &`s'==1;
  for var msrdxilS1 msalgS1 mseng1S1 mstranS1 msrdxilS2 msgeoS2
   mseng2S2 mstranS2, noheader: qui gen noX=1-X;
  for var nomsrdxilS1 nomsalgS1 nomseng1S1 nomstranS1, noheader:
   dosel X 2 &enrollF19==1&`s'==1;
  for var nomsrdxilS2 nomsgeoS2 nomseng2S2 nomstranS2, noheader:
   dosel X 2 &enrollF19==1&enrollS1==1&`s'==1;
  drop noms*;
 };

 disp "*** TABLE 6 ***";

 disp "** TREATMENT EFFECTS";
 foreach s of varlist xxblk xxhisp xxmale q12 botq topq{;
  for var insch uF1maj uF1clmaj: rf_01 X newid &enrollF19==1&`s'==1;
  for var uF1comp8 uF1clmn8 uF1va8 uF1miles mtou9: 
   rf_co X newid &enrollF19==1&`s'==1;
 };

 disp "*** TABLE 7 ***";

 foreach s of varlist xxblk xxhisp xxmale q12 botq topq{;

  disp "** OUTCOMES AT THE END OF 4 YEARS";
  for var gradF5 enrollF5 dropF5 privF5 leftF5:
   rf_01 X unitF1 &enrollF19==1&`s'==1;

  disp "** 9TH GRADE OUTCOMES";
  for var rdxilS1 algS1 eng1S1 mabsS1 tcrdS1 crankS1: 
   rf_co X unitF1 &enrollF19==1&`s'==1;

  disp "** 10TH GRADE OUTCOMES";
  for var rdxilS2 geoS2 eng2S2 mabsS2 tcrdS2 crankS2: 
   rf_co X unitF1 &enrollF19==1&`s'==1;

  disp "** 11TH GRADE OUTCOMES";
  for var dropS3 retainS3: rf_01 X unitF1 &enrollF19==1&`s'==1;

 };

 disp "*** MOBILITY EFFECTS ***";

 * examine whether the number of one's 8th grade peers that attend
  the student's high school mediates outcomes.;
  * mtou9 = % of 8th grade peers who went to the student's h.s.;
  * mfromu8 = % of 9th grade peers from the student's 8th grade school;

 * Find groups for which winning a lottery induces a large change
   in peer quality but a small disruption in peers, or vice versa;
  for any mfromu8 mtou9 comp8, noheader: 
   qui gen dX=cuX-insX \ qui xtile qdX=dX, nq(2);
  table qdmfromu8 qdcomp8,
   c(mean dmfromu8 mean dmtou9 mean dcomp8 count enrollF19);
  table qdmtou9 qdcomp8, 
   c(mean dmfromu8 mean dmtou9 mean dcomp8 count enrollF19);
   
 foreach s in qdmtou9==2&qdcomp8==2 qdmtou9==1&qdcomp8==2
  qdmfromu8==2&qdcomp8==2 qdmfromu8==1&qdcomp8==2 {;

  * Treatment;
  for var uF1comp8 uF1clmn8 mtou9 mfromu8: 
   rf_co X newid &enrollF19==1&`s';
  for var insch: rf_01 X newid &enrollF19==1&`s';
 
  * Outcomes;
  for var rdxilS1 algS1 eng1S1 mabsS1 tcrdS1 mabsS2 tcrdS2 geoS2 eng2S2: 
   rf_co X unitF1 &enrollF19==1&`s';
  for var gradF5 enrollF5 dropF5 privF5 leftF5 dropS3 retainS3 leftF5: 
   rf_01 X unitF1 &enrollF19==1&`s';

 };

 drop dmfromu8 dmtou9 dcomp8 qdmfromu8 qdmtou9 qdcomp8;

log close;


/*** SURVEY RESULTS BY SCHOOL AND STUDENT TYPE ***/

capture log close;
log using results_survey.log, replace;

 disp "*** TABLE 8 ***";
 disp "*** IMPACT ON SURVEY OUTCOMES ***";

 foreach s of varlist sampleS cugd {;
  for var ss_help ss_talk mm_trob ss_jus17q04 ss_fut07q01 mm_safe
   ss_tec30q04: rf_01 X unitF1 &enrollF19==1&cumsurv~=0&`s'==1;
  for var cc_psup cc_like cc_trts cc_peer:
   rf_co X unitF1 &enrollF19==1&cumsurv~=0&`s'==1;
  };

 disp "*** REPEATING BASIC ANALYSIS FOR SURVEY SAMPLE ***";

 * run the basic academic outcomes restricting the sample to the 
   students from the 2000 cohort who applied to choice schools in
   which the survey was administered. This is a relatively small 
   sample, so we will not have much precision, but we can see if 
   the pattern of point estimates tells the same story as the 
   results for the full sample;
 
 foreach s of varlist sampleS {; 

  disp "*** TREATMENT EFFECTS - SURVEY SAMPLE ***";
   for var ${trt_01}: 
    rf_01 X newid &enrollF19==1&cumsurv~=0&year==2000&`s'==1;
   for var ${trt_co}: 
    rf_co X newid &enrollF19==1&cumsurv~=0&year==2000&`s'==1;

  disp "*** OUTCOME EFFECTS - SURVEY SAMPLE ***";

   disp "** OUTCOMES AT THE END OF 4 YEARS";
   for var gradF5 enrollF5 dropF5 privF5 leftF5:
    rf_01 X unitF1 &enrollF19==1&cumsurv~=0&year==2000&`s'==1;

   disp "** 9TH GRADE OUTCOMES";
   for var rdxilS1 algS1 eng1S1 mabsS1 tcrdS1 crankS1: 
    rf_co X unitF1 &enrollF19==1&cumsurv~=0&year==2000&`s'==1;

   disp "** 10TH GRADE OUTCOMES";
   for var rdxilS2 geoS2 eng2S2 mabsS2 tcrdS2 crankS2: 
    rf_co X unitF1 &enrollF19==1&cumsurv~=0&year==2000&`s'==1;

   disp "** 11TH GRADE OUTCOMES";
   for var dropS3 retainS3: 
    rf_01 X unitF1 &enrollF19==1&cumsurv~=0&year==2000&`s'==1;
 
  };

 disp "*** DIFFERENCES IN MEAN OUTCOMES FOR JAIL ***";

  for any sampleS cugd cuhiva cuhipop xxblk xxhisp xxmale q12 botq topq: 
   sum jailS3 if X==1&select==0 \ 
   sum jailS3 if X==1&select==1 \
   areg jailS3 select ${cntrls} if enrollF19==1&X==1, a(subgroup) cl(unitF1) \
   rf_co jailS3 unitF1 &enrollF19==1&X==1 \
   rf_01 jailS3 unitF1 &enrollF19==1&X==1 \
  
   sum jailF5 if X==1&select==0 \ 
   sum jailF5 if X==1&select==1 \
   areg jailF5 select ${cntrls} if enrollF19==1&X==1, a(subgroup) cl(unitF1) \
   rf_co jailF5 unitF1 &enrollF19==1&X==1 \ 
   rf_01 jailF5 unitF1 &enrollF19==1&X==1;

log close;


*************************************************;
*** (4.5) CREATE FIGURES OF EFFECTS BY SCHOOL ***;
*************************************************;

capture log close;
log using results_figures.log, replace;

** This program creates school-level estimates for
 continuous outcomes;

 program define figc;
  tempvar tmpsmp;
  qui gen b_`1'=.;
  qui gen s_`1'=.;
  qui egen `tmpsmp'=sd(`1') if enrollF19==1 `2', by(sublotto);
  qui replace `tmpsmp'=(`tmpsmp'~=0&`tmpsmp'~=.) if enrollF19==1 `2';
  qui replace `tmpsmp'=0 if `tmpsmp'==1 & `1'==.;
  qui vallist cunit if `tmpsmp'==1, global(cu);
  for any ${cu}, noheader:
   qui areg `1' select ${cntrls} if `tmpsmp'==1&cunit==X,
    a(subgroup) cl(unitF1) \
   qui replace b_`1'=_b[select] if e(sample) \ 
   qui replace s_`1'=_se[select] if e(sample);
  macro drop cu;
 end;
   
** This program creates school-level estimates for 
  binary outcomes;
 
 program define fig01;
  global var `1';
  global r `2';

  qui gen b_${var}=.;
  qui gen s_${var}=.;
  tempvar tmpsmp;
  qui egen `tmpsmp'=sd(${var}) if enrollF19==1 ${r}, by(sublotto);
  qui replace `tmpsmp'=(`tmpsmp'~=0&`tmpsmp'~=.) if enrollF19==1 ${r};
  qui replace `tmpsmp'=0 if `tmpsmp'==1 & ${var}==.;
  qui vallist cunit if `tmpsmp'==1, global(cu);

  foreach x in ${cu}{;

   tempvar tmpnum onelot skip xb xb1 xb0 db1 dbcons;
   tempname v0 V Vs matd VAR var;

   ** getting probit estimates;
   qui egen `tmpnum'=nvals(sublotto) if `tmpsmp'==1&cunit==`x';
   qui summ `tmpnum';
   gen `onelot'=(r(N)==1);
   qui tab sublotto if `tmpsmp'==1&cunit==`x', gen(LL);
   if `onelot'==1{; qui replace LL1=0; };
   if `onelot'>1{; drop LL1; };
   capture probit ${var} select LL* ${cntrls} 
    if `tmpsmp'==1&cunit==`x', cl(unitF1);
   qui gen `skip'=e(N);
   qui replace `skip'=(`skip'==.);

   ** deal with special cases that end up crashing because of too 
    little variation once control variables are included (i.e. the
    select variable is dropped);
   qui replace `skip'=1 if `x'==1390 & "${var}"=="privF5";
   qui replace `skip'=1 if `x'==1520 & "${var}"=="privF5";
   qui replace `skip'=1 if `x'==1830 & "${var}"=="mm_trob";
   qui replace `skip'=1 if `x'==1210 & "${var}"=="ss_jus17q04";

   if `skip'==0{;

    ** set standard error and marginal effect to missing if any
     element of the variance covariance matrix is equal to 0;
    matrix `v0'=diag0cnt(e(V));
    local z=`v0'[1,1];
    
    if `z'==0{; 

     ** calculating mean marginal effect;
     qui predict `xb', xb;
     qui gen `xb1'=`xb'-_b[select]*select+_b[select];
     qui gen `xb0'=`xb'-_b[select]*select; 
     * note: we get the mean marginal effect below when we collapse
      the data;
     qui replace b_${var}=norm(`xb1')-norm(`xb0') if e(sample);
   
     ** calculating it's standard error;
     qui gen `db1'=normd(`xb1');
     qui gen `dbcons'=normd(`xb1')-normd(`xb0');
     mat `V'=e(V);
     local ntot=rowsof(`V')-1;
     mat `Vs'=`V'[2..`ntot',1];
     local vlist : rownames(`Vs');
     tokenize `vlist';
     local nd=1;
     while "`1'"~="" {;
      tempvar DB`nd';
      qui gen `DB`nd''=(normd(`xb1')-normd(`xb0'))*`1';
      local nd=`nd'+1;
      macro shift;
     };
     local nd=`nd'-1;
     preserve;
     collapse (mean) `db1' `DB1'-`DB`nd'' `dbcons' if e(sample);
     mkmat `db1' `DB1'-`DB`nd'' `dbcons', matrix(`matd');
     matrix `VAR'=`matd'*`V'*`matd'';
     scalar `var'=`VAR'[1,1];
     local se_select=sqrt(`var');
     qui restore;
     qui replace s_${var}=`se_select' if e(sample);
    };
   };

   tempvar drop tmpnum onelot skip xb xb1 xb0 db1 dbcons;
   tempname v0 drop V Vs matd VAR var;
   drop LL*;

  };
  
  macro drop cu;

 end;
   
** Calculate effects;

 for var gradF5 enrollF5 dropF5 privF5 leftF5: fig01 X &year==2000;
 for var rdxilS1 algS1 eng1S1 mabsS1 tcrdS1 crankS1: figc X;
 for var rdxilS2 geoS2 eng2S2: figc X &year==2000; 
 for var mabsS2 tcrdS2 crankS2: figc X;
 for var dropS3 retainS3: fig01 X;
 for var ss_help ss_talk mm_trob ss_jus17q04 ss_fut07q01 mm_safe
   ss_tec30q04: fig01 X &cumsurv~=0&year==2000;
 for var cc_psup cc_like cc_trts cc_peer:
  figc X &cumsurv~=0&year==2000;

** saving dataset with these results;

preserve;

 qui replace cuname="WELLS HIGH" if cuname=="WELLS COMMTY ACAD HS";
 qui replace cuname="CHICAGO AG SC HIGH"
  if cuname=="CHICAGO AGR SCI HIGH";
 qui egen tmp1=nvals(cuname), by(cunit);
 tab tmp1;
 * create application-weighted average of cucomp8 across years
   to match classifications of schools in Table 1;
 sort cunit year;
 qui replace cucomp8=. if year==year[_n-1] & cunit==cunit[_n-1];
 qui egen tmp2=count(cunit), by(cunit year); 
 qui egen tmp3=count(cunit), by(cunit);
 qui egen tmp4=sum(cucomp8*tmp2/tmp3), by(cunit);
 qui replace cucomp8=tmp4;

 sort cunit sublotto;
 qui replace nt=. if cunit==cunit[_n-1] & sublotto==sublotto[_n-1]; 
 collapse (sum) nt (mean) b_* s_* cucomp8, by(cunit cuname);

 * add variable indicating significance at 5% or 10% level;
 for any gradF5 enrollF5 dropF5 privF5 leftF5
  rdxilS1 algS1 eng1S1 mabsS1 tcrdS1 crankS1 
  rdxilS2 geoS2 eng2S2 mabsS2 tcrdS2 crankS2 dropS3 retainS3
  ss_help ss_talk mm_trob ss_jus17q04 ss_fut07q01 mm_safe ss_tec30q04:
  qui gen p_X=0 if b_X~=. & s_X~=. \
  qui replace p_X=5 if (b_X+1.96*s_X)*(b_X-1.96*s_X)>0 & b_X~=. & s_X~=. \
  qui replace p_X=10 if p_X==. & (b_X+1.645*s_X)*(b_X-1.645*s_X)>0
   & b_X~=. & s_X~=.;

 save figures, replace;

** Creating graphs;

 * 9th grade reading: -0.06 to 0.06;
  summ b_rdxilS1;
  serrbar b_rdxilS1 s_rdxilS1 cucomp, scale(1.96) 
   xtitle("Average Peer Ability in School", margin(top) size(small))
   ytitle("Estimated Effect - 95% CI", margin(right) size(small))
   title("9th Grade Reading Score", size(medium)) 
   yline(0) xscale(r(0.25 0.65)) xlabel(0.25(0.05)0.65) 
   saving(fig1_rdxilS1, replace);
  
 * 9th grade algebra: -0.03 to 0.07;
  summ b_algS1;
  serrbar b_algS1 s_algS1 cucomp, scale(1.96)
   xtitle("Average Peer Ability in School", margin(top) size(small)) 
   ytitle("Estimated Effect - 95% CI", margin(right) size(small))
   title("9th Grade Algebra Score", size(medium)) 
   yline(0) xscale(r(0.25 0.65)) xlabel(0.25(0.05)0.65) 
   saving(fig1_algS1, replace);

 * Gets into trouble: -0.47 to 0.07;
  summ b_mm_trob;
  serrbar b_mm_trob s_mm_trob cucomp, scale(1.96)
   xtitle("Average Peer Ability in School", margin(top) size(small)) 
   ytitle("Estimated Effect - 95% CI", margin(right) size(small))
   title("Gets into Trouble at School", size(medium)) 
   subtitle("(9th Grade Survey Measure)", size(small)) 
   yline(0) xscale(r(0.25 0.65)) xlabel(0.25(0.05)0.65) 
   saving(fig1_mm_trob, replace);

 * 12th grade dropout: -0.06 to 0.17;
  summ b_dropF5;
  serrbar b_dropF5 s_dropF5 cucomp, scale(1.96)
   xtitle("Average Peer Ability in School", margin(top) size(small)) 
   ytitle("Estimated Effect - 95% CI", margin(right) size(small))
   title("Probability of Dropping Out", size(medium)) 
   yline(0) xscale(r(0.25 0.65)) xlabel(0.25(0.05)0.65) 
   saving(fig1_dropF5, replace);

 graph combine fig1_rdxilS1.gph fig1_algS1.gph fig1_dropF5.gph 
  fig1_mm_trob.gph, xsize(6.5) ysize(5) 
  title("FIGURE 1--THE EFFECTS OF WINNING A LOTTERY BY SCHOOL", 
   margin(bottom) size(medium)) 
  note("Note: Each bar represents the effect for a separate school.", 
   size(vsmall))
  saving(fig1_comb.gph, replace);

** presenting the data;

 sort cucomp;
 disp "p_* reports statistical sig at 5% or 10% level";
 set linesize 110;
 list cuname cucomp b_rdxilS1 p_rdxilS1 b_algS1 p_algS1 b_dropF5 p_dropF5;

** Correlation across measures;

 pwcorr b_rdxilS1 b_algS1 b_dropF5 b_mm_trob, sig;
 pwcorr b_rdxilS1 b_algS1 b_dropF5 b_mm_trob [aw=nt], sig;

 pwcorr b_rdxilS1 b_algS1 b_dropF5 b_mm_trob if
  b_rdxilS1~=.&b_algS1~=.&b_dropF5~=., sig;
 pwcorr b_rdxilS1 b_algS1 b_dropF5 b_mm_trob if
  b_rdxilS1~=.&b_algS1~=.&b_dropF5~=. [aw=nt], sig;

** Regression with school fixed effects for key measures;

 * First standardizing measures to have mean 0 and standard deviation
  of 1 in the weighted sample (weighting using the inverse
  of the standard error of the coefficient estimates);
 gen tmpsmp=1;
 for any dropF5 rdxilS1 algS1 eng1S1 rdxilS2 geoS2 eng2S2, noheader:  
  qui replace tmpsmp=0 if b_X==.|s_X==.;
 for any dropF5 rdxilS1 algS1 eng1S1 rdxilS2 geoS2 eng2S2, noheader:
  qui gen w_X=1/s_X if tmpsmp==1 \
  qui egen tmp1=sum(w_X) if tmpsmp==1 \
  qui egen tmp2=sum(b_X*w_X/tmp1) if tmpsmp==1 \
  qui egen tmp3=sum(w_X*(b_X-tmp2)^2) if tmpsmp==1 \
  qui replace tmp3=(tmp3/(tmp1-1))^.5 \
  qui replace b_X=(b_X-tmp2)/tmp3 \ summ b_X [aw=w_X] \
  drop tmp1-tmp3;
 * disp "** dropF5 redefined so has positive interpretation **";
 qui replace b_dropF5=b_dropF5*-1;
 for any dropF5 rdxilS1 algS1 eng1S1 rdxilS2 geoS2 eng2S2 \
  num 1/7, noheader: rename b_X bY \ rename w_X wY;
 reshape long b w, i(cunit) j(var);
 qui tab cunit if b~=., gen(cc);
 reg b cc* [aw=w], nocons;
 testparm cc*;
 for var cc*: tab cunit cuname if X==1;

restore;
drop s_* b_*;
descr;

log close;


**********************************************************;
*** (4.6) BOUNDING ANALYSIS TO TEST FOR ATTRITION BIAS ***;
**********************************************************;

disp "*** TABLE C2 ***";
disp "*** Implementing series of strategies for Spr Yr 1 Reading ***";

capture log close;
log using results_bound1.log, replace;

foreach s in sampleS cugd cuhiva cuhipop{;

 disp "*** Baseline estimates ***";
  areg rdxilS1 select ${cntrls} if enrollF19==1&`s'==1, 
   a(subgroup) cl(unitF1);

 disp "*** Strategy (1) - Generic bounds ***";

  * for the generic and worst-case bounding strategies, we cluster
   by unitF1 for those who enroll, and by unitS0 for those who do not;
  gen tmpunit=unitF1;
  replace tmpunit=unitS0 if tmpunit==.;
  count if tmpunit==.;

  ** Here we assign anyone who is missing an outcome the same value, 
   regardless of whether they were a winner or a loser;

  disp "** Level test scores **";
  * assume kids with missing values score at the 10th, 25th, 75th 
   and 90th percentile of all kids in the sample; 
  for var rdxilS1, noheader:
   disp "** missing to 10th percentile **" \
   qui gen holdX=X \ qui egen tmp=pctile(X), p(10) \ summ tmp \ 
   qui replace holdX=tmp if holdX==. \
   areg holdX select ${cntrls} if `s'==1, a(subgroup) cl(tmpunit) \
   drop tmp \ 
   disp "** missing to 25th percentile **" \
   qui replace holdX=X \ qui egen tmp=pctile(X), p(25) \ summ tmp \ 
   qui replace holdX=tmp if holdX==. \
   areg holdX select ${cntrls} if `s'==1, a(subgroup) cl(tmpunit) \
   drop tmp \ 
   disp "** missing to 75th percentile **" \
   qui replace holdX=X \ qui egen tmp=pctile(X), p(75) \ summ tmp \ 
   qui replace holdX=tmp if holdX==. \
   areg holdX select ${cntrls} if `s'==1, a(subgroup) cl(tmpunit) \
   drop tmp \ 
   disp "** missing to 90th percentile **" \
   qui replace holdX=X \ qui egen tmp=pctile(X), p(90) \ summ tmp \ 
   qui replace holdX=tmp if holdX==. \
   areg holdX select ${cntrls} if `s'==1, a(subgroup) cl(tmpunit) \
   drop tmp holdX;

  disp "** Test score gains **"; 
  * Assume kids with missing values make gains at the 10th, 25th, 
   75th and 90th percentile of all kids in the sample; 
  for X in var rdxilS1 \ Y in var zzrdxilS0, noheader: 
   qui gen tmpg=X-Y \
   disp "** missing to 10th percentile **" \ 
   qui gen holdX=X \ qui egen tmp=pctile(tmpg), p(10) \ summ tmp \ 
   qui replace holdX=Y+tmp if holdX==. \
   areg holdX select ${cntrls} if `s'==1, a(subgroup) cl(tmpunit) \
   drop tmp \ 
   disp "** missing to 25th percentile **" \
   qui replace holdX=X \ qui egen tmp=pctile(tmpg), p(25) \ summ tmp \ 
   qui replace holdX=Y+tmp if holdX==. \
   areg holdX select ${cntrls} if `s'==1, a(subgroup) cl(tmpunit) \
   drop tmp \ 
   disp "** missing to 75th percentile **" \
   qui replace holdX=X \ qui egen tmp=pctile(tmpg), p(75) \ summ tmp \ 
   qui replace holdX=Y+tmp if holdX==. \
   areg holdX select ${cntrls} if `s'==1, a(subgroup) cl(tmpunit) \
   drop tmp \ 
   disp "** missing to 90th percentile **" \
   qui replace holdX=X \ qui egen tmp=pctile(tmpg), p(90) \ summ tmp \ 
   qui replace holdX=Y+tmp if holdX==. \
   areg holdX select ${cntrls} if `s'==1, a(subgroup) cl(tmpunit) \
   drop tmp holdX tmpg;

 disp "*** Strategy (2) - Worst case Bounding Approach ***";

  ** Here, we assume maximal differences between winners and losers
   with missing information in both directions;
 
  * Assign "missing persons" that were selected and not-selected to the 
   top and bottom 10% in turn;

  disp "** Level Scores **";
  for var rdxilS1, noheader:
   qui egen tmp10=pctile(X), p(10) \
   qui egen tmp90=pctile(X), p(90) \
   qui gen holdX=X \ 
   disp "** losers to bot decile, winners to top decile **" \
   qui replace holdX=tmp10 if holdX==.&select==0 \
   qui replace holdX=tmp90 if holdX==.&select==1 \
   areg holdX select ${cntrls} if `s'==1, a(subgroup) cl(tmpunit) \
   qui replace holdX=X \ 
   disp "** losers to top decile, winners to bot decile **" \
   qui replace holdX=tmp90 if holdX==.&select==0 \
   qui replace holdX=tmp10 if holdX==.&select==1 \
   areg holdX select ${cntrls} if `s'==1, a(subgroup) cl(tmpunit) \ 
   drop holdX tmp10 tmp90;

  disp "** Test score gains **";
  for X in var rdxilS1 \ Y in var zzrdxilS0, noheader:
   qui gen tmpg=X-Y \
   qui egen tmp10=pctile(tmpg), p(10) \
   qui egen tmp90=pctile(tmpg), p(90) \
   qui gen holdX=X \
   disp "** losers to bot decile, winners to top decile **" \
   qui replace holdX=Y+tmp10 if holdX==.&select==0 \
   qui replace holdX=Y+tmp90 if holdX==.&select==1 \
   areg holdX select ${cntrls} if `s'==1, a(subgroup) cl(tmpunit) \
   replace holdX=X \
   disp "** losers to top decile, winners to bot decile **" \
   replace holdX=Y+tmp90 if holdX==.&select==0 \
   replace holdX=Y+tmp10 if holdX==.&select==1 \
   areg holdX select ${cntrls} if `s'==1, a(subgroup) cl(tmpunit) \
   drop tmpg tmp10 tmp90 holdX;  

  drop tmpunit;

 disp "*** Strategy (3) - Optimistic Bounds ***";

  ** Here we implement a trimming method based on Lee (2002, 2005).  
   We check for differential attrition, always assuming it will be 
   greater for losers than winners (we need this monotonicity assumption).
   If the NON-missing data rate is x% among winners and y% among losers, 
   we then trim a fraction K=(x-y)/x from the bottom or top of the less 
   attrited sample (the winners) in turn;

  * we do this both with and without control variables.  With control 
   variables, we run an initial regression to get a predicted value for all 
   observations of the dependent variable in question, we then divide the 
   sample into bins according to this predicted value, and perform the 
   trimming procedure within bins.;

  * Note that we avoid over-trimming when we trim from the top by determining 
   winners' fractile rankings by dividing ranks by N+1 rather than N-- 
   otherwise the top winner with a fractile rank of 1 will almost always get 
   dropped while the bottom winner will have a fractile ranking above 0
   and not be as automatically excluded;

  for var rdxilS1, noheader:

   disp "** Optimistic bounds without control variables **" \

   qui egen tmp1=mean(X~=.&enrollF19==1) if select==1&`s'==1, by(sublotto) \
   qui egen tmp2=mean(X~=.&enrollF19==1) if select==0&`s'==1, by(sublotto) \
   qui egen tmp3=max(tmp1), by(sublotto) \
   qui egen tmp4=max(tmp2), by(sublotto) \
   qui gen tmp5=(tmp3-tmp4)/tmp3 \ 
   qui gen tmpchk=(tmp5>=0&tmp5~=.)|(tmp3==0&tmp4==0) if tmp3~=.&tmp4~=. \
   disp "** share of cases with excess attrition among losers **" \
   summ tmpchk if `s'==1 \
   summ tmpchk if taglot==1 & `s'==1 \
   qui replace tmp5=0 if tmp5<0 \
   qui egen tmp6=rank(X) if X~=. & enrollF19==1&`s'==1, by(sublotto select) unique \
   qui egen tmp7=count(X) if X~=. & enrollF19==1&`s'==1, by(sublotto select) \
   qui gen tmp8=tmp6/(tmp7+1) if select==1 \ summ tmp8 \

   disp "** trim the worst winners **" \
    qui gen holdX=X \ 
    replace holdX=. if tmp8<=tmp5 & tmp5~=. & select==1 & enrollF19==1&`s'==1 \
    areg holdX select if enrollF19==1&`s'==1, a(subgroup) cl(unitF1) \
    
   disp "** trim the best winners **" \
    qui replace holdX=X \ 
    replace holdX=. if (1-tmp8)<=tmp5 & tmp5~=. & select==1 & enrollF19==1&`s'==1 \
    areg holdX select if enrollF19==1&`s'==1, a(subgroup) cl(unitF1) \
 
   drop tmp* \

   disp "** Optimistic bounds with control variables **" \

   qui reg X ${cntrls} if `s'==1 \
   qui predict fitX if `s'==1 \
   qui egen tmp1=rank(fitX) if fitX~=., by(sublotto) \
   qui egen tmp2=count(fitX) if fitX~=., by(sublotto) \
   qui replace tmp1=tmp1/tmp2 \
   qui gen tmp3=.2*_n in 1/4 \
   qui xtile tmpgrp=tmp1, cutpoint(tmp3) \
   tab tmpgrp \
   qui replace tmpgrp=1 if nt<100 & tmpgrp~=. \
   qui replace tmpgrp=subgroup*10+tmpgrp \
   drop fitX tmp1 tmp2 tmp3 \
   
   qui egen tmp1=mean(X~=.&enrollF19==1) if select==1&`s'==1, by(tmpgrp) \
   qui egen tmp2=mean(X~=.&enrollF19==1) if select==0&`s'==1, by(tmpgrp) \
   qui egen tmp3=max(tmp1), by(tmpgrp) \
   qui egen tmp4=max(tmp2), by(tmpgrp) \
   qui gen tmp5=(tmp3-tmp4)/tmp3 \ 
   qui gen tmpchk=(tmp5>=0&tmp5~=.)|(tmp3==0&tmp4==0) if tmp3~=.&tmp4~=. \
   disp "** share of cases with excess attrition among losers **" \
   summ tmpchk if `s'==1 \
   summ tmp5 if `s'==1, d \ 
   sort tmpgrp \
   summ tmpchk if tmpgrp~=tmpgrp[_n-1] \
   qui replace tmp5=0 if tmp5<0 \
   qui egen tmp6=rank(X) if X~=. & enrollF19==1&`s'==1, 
    by(tmpgrp select) unique \
   qui egen tmp7=count(X) if X~=. & enrollF19==1&`s'==1, by(tmpgrp select) \
   qui gen tmp8=tmp6/(tmp7+1) if select==1 \ summ tmp8 \
      
   disp "** trim the worst winners **" \
    qui replace holdX=X \
    replace holdX=. if tmp8<=tmp5 & tmp5~=. & select==1 & enrollF19==1&`s'==1 \
    areg holdX select ${cntrls} if enrollF19==1&`s'==1, a(subgroup) cl(unitF1) \
    areg holdX select if enrollF19==1&`s'==1, a(tmpgrp) cl(unitF1) \

   disp "** trim the best winners **" \
    qui replace holdX=X \ 
    replace holdX=. 
     if (1-tmp8)<=tmp5 & tmp5~=. & select==1 & enrollF19==1&`s'==1 \
    areg holdX select ${cntrls} if enrollF19==1&`s'==1, a(subgroup) cl(unitF1) \
    areg holdX select if enrollF19==1&`s'==1, a(tmpgrp) cl(unitF1) \

   drop holdX tmp*;

 disp "*** Strategy (4) - Control Function Approach ***";

  * In this strategy, we create an index function that captures the 
   difference in the rates at which winners and losers enroll in the CPS 
   by lottery.  We want to evaluate at the point where an equal number of 
   winners and losers stay, which means we can simply evaluate at the 
   point where the added variables are zero;
 
  qui egen tmp0=mean(enrollF19) if select==0 & `s'==1, by(sublotto);
  qui egen tmp00=max(tmp0), by(sublotto);
  qui egen tmp1=mean(enrollF19) if select==1 & `s'==1, by(sublotto);
  qui egen tmp11=max(tmp1), by(sublotto);
  qui gen penr=tmp00-tmp11;
  sum tmp* penr if `s'==1;
  sum tmp* penr if taglot==1 & `s'==1;
  qui gen penr2=penr^2;
  qui gen penr3=penr^3;
  for var penr*, noheader: qui gen Xs=X*select;
 
  for any rdxilS1:
   areg X select pen* ${cntrls} if enrollF19==1&`s'==1, 
    a(sublotto) cl(unitF1);

  drop penr* tmp0 tmp00 tmp1 tmp11;

};

log close;


disp "*** TABLE C3 ***";
disp "*** Calculating optimistic bounds for full set of outcome measures ***";

capture log close;
log using results_bound2.log, replace;

** first find excess attrition for all of our outcome measures;

 * assigning to bins according to predicted values so that we can
  incoporate control variables when trimming;
 for var rdxilS1 algS1 eng1S1 mabsS1 tcrdS1 crankS1 mabsS2 tcrdS2 
 crankS2, noheader: 
  qui reg X ${cntrls} \ qui predict fitX;
 for var rdxilS2 geoS2 eng2S2 cc_psup cc_like cc_trts cc_peer, noheader:
  qui reg X ${cntrls} \ qui predict fitX if year==2000;
 for var dropS3 retainS3, noheader:
  qui probit X ${cntrls} \ qui predict fitX, xb;
 for var gradF5 enrollF5 dropF5 privF5 leftF5 ss_help ss_talk mm_trob
 ss_jus17q04 ss_fut07q01 mm_safe ss_tec30q04, noheader:
  qui probit X ${cntrls} \ qui predict fitX if year==2000, xb;
 for var rdxilS1 algS1 eng1S1 mabsS1 tcrdS1 crankS1 
 rdxilS2 geoS2 eng2S2 mabsS2 tcrdS2 crankS2
 gradF5 enrollF5 dropF5 privF5 leftF5
 dropS3 retainS3 cc_psup cc_like cc_trts cc_peer ss_help 
 ss_talk mm_trob ss_jus17q04 ss_fut07q01 mm_safe ss_tec30q04, noheader: 
  qui egen tmp1=rank(fitX) if fitX~=., by(sublotto) \
  qui egen tmp2=count(fitX) if fitX~=., by(sublotto) \
  qui replace tmp1=tmp1/tmp2 \
  qui gen tmp3=.2*_n in 1/4 \
  qui xtile tgrpX=tmp1, cutpoint(tmp3) \
  qui replace tgrpX=1 if nt<100 & tgrpX~=. \
  drop fitX tmp* \ qui compress;

 * finding excess attrition within bins;
 for var rdxilS1 algS1 eng1S1 mabsS1 tcrdS1 crankS1 
 rdxilS2 geoS2 eng2S2 mabsS2 tcrdS2 crankS2
 gradF5 enrollF5 dropF5 privF5 leftF5
 dropS3 retainS3 cc_psup cc_like cc_trts cc_peer ss_help 
 ss_talk mm_trob ss_jus17q04 ss_fut07q01 mm_safe ss_tec30q04, noheader: 
  disp "** finding excess attrition for X within bins **" \
  qui egen tmp1=mean(X~=.&enrollF19==1) if select==1, by(sublotto tgrpX) \
  qui egen tmp2=mean(X~=.&enrollF19==1) if select==0, by(sublotto tgrpX) \
  qui egen tmp3=max(tmp1), by(sublotto tgrpX) \
  qui egen tmp4=max(tmp2), by(sublotto tgrpX) \
  qui gen tmp5=(tmp3-tmp4)/tmp3 \ 
  qui gen tmpchk=(tmp5>=0&tmp5~=.)|(tmp3==0&tmp4==0) if tmp3~=.&tmp4~=. \
  disp "share of cases excess attrition among losers" \
  summ tmpchk if sampleS==1 \
  sort sublotto tgrpX \
  summ tmpchk if sublotto~=sublotto[_n-1]|tgrpX~=tgrpX[_n-1] \
  qui replace tmp5=0 if tmp5<0 \
  qui egen tmp6=rank(X) if X~=.&enrollF19==1, by(sublotto select tgrpX) unique \
  qui egen tmp7=count(X) if X~=.&enrollF19==1, by(sublotto select tgrpX) \
  qui gen tmp8=tmp6/(tmp7+1) if select==1 \
  rename tmp5 txX \ rename tmp8 tpX \ drop tmp*;

** trimming and running regressions; 

 tab year if cumsurv==.;
 tab year if cumsurv~=.;

foreach s in sampleS cugd cuhiva cuhipop{;

 display "** SAMPLE == `s'==1 **";

 ** 0/1 variables;

 for var gradF5 enrollF5 dropF5 privF5 leftF5 dropS3 retainS3 
 ss_help ss_talk mm_trob ss_jus17q04 ss_fut07q01 mm_safe ss_tec30q04 \
  num 1 1 1 1 1 1 1 0 0 0 0 0 0 0, noheader:
  disp "** dependent variable: X **" \ descr X \
  qui egen tmpsmp=sd(X) if enrollF19==1&`s'==1, by(sublotto) \
  qui replace tmpsmp=(tmpsmp~=0&tmpsmp~=.) if enrollF19==1&`s'==1 \
  qui replace tmpsmp=0 if tmpsmp==1 & X==. \
  qui replace tmpsmp=Y if tmpsmp==1 & cumsurv==0 \
  disp " * baseline results *" \
  qui tab sublotto if tmpsmp==1, gen(LL) \
  qui probit X select ${cntrls} LL* if tmpsmp==1, cl(unitF1) \
  capture noisily prmeavg X \
  drop LL* tmpsmp \
  qui gen str10 tmpgrp=sublotto+string(tgrpX) \
  qui egen tmpsmp=sd(X) if enrollF19==1&`s'==1, by(tmpgrp) \
  qui replace tmpsmp=(tmpsmp~=0&tmpsmp~=.) if enrollF19==1&`s'==1 \
  qui replace tmpsmp=0 if tmpsmp==1 & X==. \
  qui replace tmpsmp=Y if tmpsmp==1 & cumsurv==0 \
  qui tab tmpgrp if tmpsmp==1, gen(LQ) \
  qui probit X select LQ* if tmpsmp==1, cl(unitF1) \
  capture noisily prmeavg X \
  qui gen holdX=X \
  disp " * trimming from bot *" \
  replace holdX=. if tpX<=txX & txX~=. & select==1 & enrollF19==1&`s'==1 \
  qui probit holdX select LQ* if tmpsmp==1, cl(unitF1) \
  capture noisily prmeavg X \
  qui replace holdX=X \ 
  disp " * trimming from top *" \
  replace holdX=. if (1-tpX)<=txX & txX~=. & select==1 & enrollF19==1&`s'==1 \
  qui probit holdX select LQ* if tmpsmp==1, cl(unitF1) \
  capture noisily prmeavg X \
  drop LQ* holdX tmpsmp tmpgrp;

 ** continuous variables;

 for var rdxilS1 algS1 eng1S1 mabsS1 tcrdS1 crankS1 rdxilS2 geoS2 
 eng2S2 mabsS2 tcrdS2 crankS2 cc_psup cc_like cc_trts cc_peer \
 num 1 1 1 1 1 1 1 1 1 1 1 1 0 0 0 0, noheader:
  disp "** dependent variable: X **" \ descr X \
  qui egen tmpsmp=sd(X) if enrollF19==1&`s'==1, by(sublotto) \
  qui replace tmpsmp=(tmpsmp~=0&tmpsmp~=.) if enrollF19==1&`s'==1 \
  qui replace tmpsmp=0 if tmpsmp==1 & X==. \
  qui replace tmpsmp=Y if tmpsmp==1 & cumsurv==0 \
  disp " * baseline results *" \
  qui areg X select ${cntrls} if tmpsmp==1, a(subgroup) cl(unitF1) \
  disp "  Coeff: " %5.3f _b[select] "  s.e.: " %5.3f _se[select] "  p-value if +: " 
   %5.3f 2*ttail(e(df_r),_b[select]/_se[select]) "  p-value if -: " 
   %5.3f 2*(1-ttail(e(df_r),_b[select]/_se[select])) \
  drop tmpsmp \
  qui gen tmpgrp=subgroup*10+tgrpX \
  qui egen tmpsmp=sd(X) if enrollF19==1&`s'==1, by(tmpgrp) \
  qui replace tmpsmp=(tmpsmp~=0&tmpsmp~=.) if enrollF19==1&`s'==1 \
  qui replace tmpsmp=0 if tmpsmp==1 & X==. \
  qui replace tmpsmp=Y if tmpsmp==1 & cumsurv==0 \
  qui areg X select if tmpsmp==1, a(tmpgrp) cl(unitF1) \
  disp "  Coeff: " %5.3f _b[select] "  s.e.: " %5.3f _se[select] "  p-value if +: " 
   %5.3f 2*ttail(e(df_r),_b[select]/_se[select]) "  p-value if -: " 
   %5.3f 2*(1-ttail(e(df_r),_b[select]/_se[select])) \
  qui gen holdX=X \
  disp " * trimming from bot *" \
  replace holdX=. if tpX<=txX & txX~=. & select==1 & enrollF19==1&`s'==1 \
  qui areg holdX select if tmpsmp==1, a(tmpgrp) cl(unitF1) \
  disp "  Coeff: " %5.3f _b[select] "  s.e.: " %5.3f _se[select] "  p-value if +: " 
   %5.3f 2*ttail(e(df_r),_b[select]/_se[select]) "  p-value if -: " 
   %5.3f 2*(1-ttail(e(df_r),_b[select]/_se[select])) \
  qui replace holdX=X \ 
  disp " * trimming from top *" \
  replace holdX=. if (1-tpX)<=txX & txX~=. & select==1 & enrollF19==1&`s'==1 \
  qui areg holdX select if tmpsmp==1, a(tmpgrp) cl(unitF1) \
  disp "  Coeff: " %5.3f _b[select] "  s.e.: " %5.3f _se[select] "  p-value if +: " 
   %5.3f 2*ttail(e(df_r),_b[select]/_se[select]) "  p-value if -: " 
   %5.3f 2*(1-ttail(e(df_r),_b[select]/_se[select])) \
  drop holdX tmpsmp tmpgrp;  

};

drop tgrp* tx* tp*;

log close;
